# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: tecton_proto/cli/repo_diff.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from tecton_proto.common import id_pb2 as tecton__proto_dot_common_dot_id__pb2
from tecton_proto.data import state_update_pb2 as tecton__proto_dot_data_dot_state__update__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='tecton_proto/cli/repo_diff.proto',
  package='tecton_proto.cli',
  syntax='proto2',
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n tecton_proto/cli/repo_diff.proto\x12\x10tecton_proto.cli\x1a\x1ctecton_proto/common/id.proto\x1a$tecton_proto/data/state_update.proto\"w\n\x15TectonRepoDiffSummary\x12\x45\n\x0cobject_diffs\x18\x01 \x03(\x0b\x32\".tecton_proto.cli.TectonObjectDiffR\x0bobjectDiffs\x12\x17\n\x07plan_id\x18\x02 \x01(\tR\x06planId\"\xce\x01\n\x10TectonObjectDiff\x12M\n\x0ftransition_type\x18\x01 \x01(\x0e\x32$.tecton_proto.data.FcoTransitionTypeR\x0etransitionType\x12O\n\x0fobject_metadata\x18\x02 \x01(\x0b\x32&.tecton_proto.cli.TectonObjectMetadataR\x0eobjectMetadata\x12\x1a\n\x08warnings\x18\x03 \x03(\tR\x08warnings\"\xa7\x01\n\x14TectonObjectMetadata\x12\x12\n\x04name\x18\x01 \x01(\tR\x04name\x12\x43\n\x0bobject_type\x18\x02 \x01(\x0e\x32\".tecton_proto.cli.TectonObjectTypeR\nobjectType\x12\x14\n\x05owner\x18\x03 \x01(\tR\x05owner\x12 \n\x0b\x64\x65scription\x18\x04 \x01(\tR\x0b\x64\x65scription*\x8a\x01\n\x10TectonObjectType\x12\x1e\n\x1aTECTON_OBJECT_TYPE_UNKNOWN\x10\x00\x12\n\n\x06\x45NTITY\x10\x01\x12\x0f\n\x0b\x44\x41TA_SOURCE\x10\x02\x12\x12\n\x0eTRANSFORMATION\x10\x03\x12\x10\n\x0c\x46\x45\x41TURE_VIEW\x10\x04\x12\x13\n\x0f\x46\x45\x41TURE_SERVICE\x10\x05'
  ,
  dependencies=[tecton__proto_dot_common_dot_id__pb2.DESCRIPTOR,tecton__proto_dot_data_dot_state__update__pb2.DESCRIPTOR,])

_TECTONOBJECTTYPE = _descriptor.EnumDescriptor(
  name='TectonObjectType',
  full_name='tecton_proto.cli.TectonObjectType',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='TECTON_OBJECT_TYPE_UNKNOWN', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='ENTITY', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='DATA_SOURCE', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='TRANSFORMATION', index=3, number=3,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='FEATURE_VIEW', index=4, number=4,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='FEATURE_SERVICE', index=5, number=5,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=623,
  serialized_end=761,
)
_sym_db.RegisterEnumDescriptor(_TECTONOBJECTTYPE)

TectonObjectType = enum_type_wrapper.EnumTypeWrapper(_TECTONOBJECTTYPE)
TECTON_OBJECT_TYPE_UNKNOWN = 0
ENTITY = 1
DATA_SOURCE = 2
TRANSFORMATION = 3
FEATURE_VIEW = 4
FEATURE_SERVICE = 5



_TECTONREPODIFFSUMMARY = _descriptor.Descriptor(
  name='TectonRepoDiffSummary',
  full_name='tecton_proto.cli.TectonRepoDiffSummary',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='object_diffs', full_name='tecton_proto.cli.TectonRepoDiffSummary.object_diffs', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='objectDiffs', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='plan_id', full_name='tecton_proto.cli.TectonRepoDiffSummary.plan_id', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='planId', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=122,
  serialized_end=241,
)


_TECTONOBJECTDIFF = _descriptor.Descriptor(
  name='TectonObjectDiff',
  full_name='tecton_proto.cli.TectonObjectDiff',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='transition_type', full_name='tecton_proto.cli.TectonObjectDiff.transition_type', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='transitionType', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='object_metadata', full_name='tecton_proto.cli.TectonObjectDiff.object_metadata', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='objectMetadata', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='warnings', full_name='tecton_proto.cli.TectonObjectDiff.warnings', index=2,
      number=3, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='warnings', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=244,
  serialized_end=450,
)


_TECTONOBJECTMETADATA = _descriptor.Descriptor(
  name='TectonObjectMetadata',
  full_name='tecton_proto.cli.TectonObjectMetadata',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='name', full_name='tecton_proto.cli.TectonObjectMetadata.name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='name', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='object_type', full_name='tecton_proto.cli.TectonObjectMetadata.object_type', index=1,
      number=2, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='objectType', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='owner', full_name='tecton_proto.cli.TectonObjectMetadata.owner', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='owner', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='description', full_name='tecton_proto.cli.TectonObjectMetadata.description', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='description', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=453,
  serialized_end=620,
)

_TECTONREPODIFFSUMMARY.fields_by_name['object_diffs'].message_type = _TECTONOBJECTDIFF
_TECTONOBJECTDIFF.fields_by_name['transition_type'].enum_type = tecton__proto_dot_data_dot_state__update__pb2._FCOTRANSITIONTYPE
_TECTONOBJECTDIFF.fields_by_name['object_metadata'].message_type = _TECTONOBJECTMETADATA
_TECTONOBJECTMETADATA.fields_by_name['object_type'].enum_type = _TECTONOBJECTTYPE
DESCRIPTOR.message_types_by_name['TectonRepoDiffSummary'] = _TECTONREPODIFFSUMMARY
DESCRIPTOR.message_types_by_name['TectonObjectDiff'] = _TECTONOBJECTDIFF
DESCRIPTOR.message_types_by_name['TectonObjectMetadata'] = _TECTONOBJECTMETADATA
DESCRIPTOR.enum_types_by_name['TectonObjectType'] = _TECTONOBJECTTYPE
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

TectonRepoDiffSummary = _reflection.GeneratedProtocolMessageType('TectonRepoDiffSummary', (_message.Message,), {
  'DESCRIPTOR' : _TECTONREPODIFFSUMMARY,
  '__module__' : 'tecton_proto.cli.repo_diff_pb2'
  # @@protoc_insertion_point(class_scope:tecton_proto.cli.TectonRepoDiffSummary)
  })
_sym_db.RegisterMessage(TectonRepoDiffSummary)

TectonObjectDiff = _reflection.GeneratedProtocolMessageType('TectonObjectDiff', (_message.Message,), {
  'DESCRIPTOR' : _TECTONOBJECTDIFF,
  '__module__' : 'tecton_proto.cli.repo_diff_pb2'
  # @@protoc_insertion_point(class_scope:tecton_proto.cli.TectonObjectDiff)
  })
_sym_db.RegisterMessage(TectonObjectDiff)

TectonObjectMetadata = _reflection.GeneratedProtocolMessageType('TectonObjectMetadata', (_message.Message,), {
  'DESCRIPTOR' : _TECTONOBJECTMETADATA,
  '__module__' : 'tecton_proto.cli.repo_diff_pb2'
  # @@protoc_insertion_point(class_scope:tecton_proto.cli.TectonObjectMetadata)
  })
_sym_db.RegisterMessage(TectonObjectMetadata)


# @@protoc_insertion_point(module_scope)
