# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: tecton_proto/common/fco_locator.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from tecton_proto.common import id_pb2 as tecton__proto_dot_common_dot_id__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='tecton_proto/common/fco_locator.proto',
  package='tecton_proto.common',
  syntax='proto2',
  serialized_options=b'\n\021com.tecton.commonP\001',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n%tecton_proto/common/fco_locator.proto\x12\x13tecton_proto.common\x1a\x1ctecton_proto/common/id.proto\"v\n\nFcoLocator\x12\x14\n\x04name\x18\x01 \x01(\tH\x00R\x04name\x12)\n\x02id\x18\x02 \x01(\x0b\x32\x17.tecton_proto.common.IdH\x00R\x02id\x12\x1c\n\tworkspace\x18\x03 \x01(\tR\tworkspaceB\t\n\x07locatorB\x15\n\x11\x63om.tecton.commonP\x01'
  ,
  dependencies=[tecton__proto_dot_common_dot_id__pb2.DESCRIPTOR,])




_FCOLOCATOR = _descriptor.Descriptor(
  name='FcoLocator',
  full_name='tecton_proto.common.FcoLocator',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='name', full_name='tecton_proto.common.FcoLocator.name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='name', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='id', full_name='tecton_proto.common.FcoLocator.id', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='id', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='workspace', full_name='tecton_proto.common.FcoLocator.workspace', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='workspace', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='locator', full_name='tecton_proto.common.FcoLocator.locator',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=92,
  serialized_end=210,
)

_FCOLOCATOR.fields_by_name['id'].message_type = tecton__proto_dot_common_dot_id__pb2._ID
_FCOLOCATOR.oneofs_by_name['locator'].fields.append(
  _FCOLOCATOR.fields_by_name['name'])
_FCOLOCATOR.fields_by_name['name'].containing_oneof = _FCOLOCATOR.oneofs_by_name['locator']
_FCOLOCATOR.oneofs_by_name['locator'].fields.append(
  _FCOLOCATOR.fields_by_name['id'])
_FCOLOCATOR.fields_by_name['id'].containing_oneof = _FCOLOCATOR.oneofs_by_name['locator']
DESCRIPTOR.message_types_by_name['FcoLocator'] = _FCOLOCATOR
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

FcoLocator = _reflection.GeneratedProtocolMessageType('FcoLocator', (_message.Message,), {
  'DESCRIPTOR' : _FCOLOCATOR,
  '__module__' : 'tecton_proto.common.fco_locator_pb2'
  # @@protoc_insertion_point(class_scope:tecton_proto.common.FcoLocator)
  })
_sym_db.RegisterMessage(FcoLocator)


DESCRIPTOR._options = None
# @@protoc_insertion_point(module_scope)
