# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: tecton_proto/common/pair.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor.FileDescriptor(
  name='tecton_proto/common/pair.proto',
  package='tecton_proto.common',
  syntax='proto2',
  serialized_options=b'\n\021com.tecton.commonP\001',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n\x1etecton_proto/common/pair.proto\x12\x13tecton_proto.common\"4\n\x04Pair\x12\x14\n\x05\x66irst\x18\x01 \x01(\tR\x05\x66irst\x12\x16\n\x06second\x18\x02 \x01(\tR\x06secondB\x15\n\x11\x63om.tecton.commonP\x01'
)




_PAIR = _descriptor.Descriptor(
  name='Pair',
  full_name='tecton_proto.common.Pair',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='first', full_name='tecton_proto.common.Pair.first', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='first', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='second', full_name='tecton_proto.common.Pair.second', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='second', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=55,
  serialized_end=107,
)

DESCRIPTOR.message_types_by_name['Pair'] = _PAIR
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

Pair = _reflection.GeneratedProtocolMessageType('Pair', (_message.Message,), {
  'DESCRIPTOR' : _PAIR,
  '__module__' : 'tecton_proto.common.pair_pb2'
  # @@protoc_insertion_point(class_scope:tecton_proto.common.Pair)
  })
_sym_db.RegisterMessage(Pair)


DESCRIPTOR._options = None
# @@protoc_insertion_point(module_scope)
