# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: tecton_proto/feature_server/configuration/feature_server_configuration.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import duration_pb2 as google_dot_protobuf_dot_duration__pb2
from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2
from tecton_proto.args import user_defined_function_pb2 as tecton__proto_dot_args_dot_user__defined__function__pb2
from tecton_proto.args import pipeline_pb2 as tecton__proto_dot_args_dot_pipeline__pb2
from tecton_proto.common import aggregation_function_pb2 as tecton__proto_dot_common_dot_aggregation__function__pb2
from tecton_proto.common import column_type_pb2 as tecton__proto_dot_common_dot_column__type__pb2
from tecton_proto.common import id_pb2 as tecton__proto_dot_common_dot_id__pb2
from tecton_proto.data import feature_service_pb2 as tecton__proto_dot_data_dot_feature__service__pb2
from tecton_proto.data import feature_view_pb2 as tecton__proto_dot_data_dot_feature__view__pb2
from tecton_proto.data import tecton_api_key_pb2 as tecton__proto_dot_data_dot_tecton__api__key__pb2
from tecton_proto.data import new_transformation_pb2 as tecton__proto_dot_data_dot_new__transformation__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='tecton_proto/feature_server/configuration/feature_server_configuration.proto',
  package='tecton_proto.feature_server.configuration',
  syntax='proto2',
  serialized_options=b'\n(com.tecton.feature_service.configurationP\001Z>github.com/tecton-ai/tecton_proto/feature_server/configuration',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\nLtecton_proto/feature_server/configuration/feature_server_configuration.proto\x12)tecton_proto.feature_server.configuration\x1a\x1egoogle/protobuf/duration.proto\x1a\x1fgoogle/protobuf/timestamp.proto\x1a-tecton_proto/args/user_defined_function.proto\x1a tecton_proto/args/pipeline.proto\x1a.tecton_proto/common/aggregation_function.proto\x1a%tecton_proto/common/column_type.proto\x1a\x1ctecton_proto/common/id.proto\x1a\'tecton_proto/data/feature_service.proto\x1a$tecton_proto/data/feature_view.proto\x1a&tecton_proto/data/tecton_api_key.proto\x1a*tecton_proto/data/new_transformation.proto\"\xeb\x01\n\x0c\x46\x65\x61turesPlan\x12[\n\x0c\x66\x65\x61ture_plan\x18\x01 \x01(\x0b\x32\x36.tecton_proto.feature_server.configuration.FeaturePlanH\x00R\x0b\x66\x65\x61turePlan\x12x\n\x17on_demand_features_plan\x18\x02 \x01(\x0b\x32?.tecton_proto.feature_server.configuration.OnDemandFeaturesPlanH\x00R\x14onDemandFeaturesPlanB\x04\n\x02\x66p\"\xdf\x01\n\x06\x43olumn\x12\x33\n\x04type\x18\x01 \x01(\x0e\x32\x1f.tecton_proto.common.ColumnTypeR\x04type\x12\x35\n\x17\x66\x65\x61ture_view_space_name\x18\x02 \x01(\tR\x14\x66\x65\x61tureViewSpaceName\x12;\n\x1a\x66\x65\x61ture_service_space_name\x18\x03 \x01(\tR\x17\x66\x65\x61tureServiceSpaceName\x12,\n\x12\x66\x65\x61ture_view_index\x18\x04 \x01(\x05R\x10\x66\x65\x61tureViewIndex\"\xe9\n\n\x0b\x46\x65\x61turePlan\x12V\n\routput_column\x18\x04 \x01(\x0b\x32\x31.tecton_proto.feature_server.configuration.ColumnR\x0coutputColumn\x12V\n\rinput_columns\x18\x01 \x03(\x0b\x32\x31.tecton_proto.feature_server.configuration.ColumnR\x0cinputColumns\x12[\n\x14\x61ggregation_function\x18\x03 \x01(\x0e\x32(.tecton_proto.common.AggregationFunctionR\x13\x61ggregationFunction\x12n\n\x1b\x61ggregation_function_params\x18\x06 \x01(\x0b\x32..tecton_proto.common.AggregationFunctionParamsR\x19\x61ggregationFunctionParams\x12H\n\x12\x61ggregation_window\x18\x05 \x01(\x0b\x32\x19.google.protobuf.DurationR\x11\x61ggregationWindow\x12N\n\tjoin_keys\x18\x07 \x03(\x0b\x32\x31.tecton_proto.feature_server.configuration.ColumnR\x08joinKeys\x12_\n\x12wildcard_join_keys\x18\x08 \x03(\x0b\x32\x31.tecton_proto.feature_server.configuration.ColumnR\x10wildcardJoinKeys\x12\x1d\n\ntable_name\x18\t \x01(\tR\ttableName\x12|\n\x19\x64\x61ta_table_timestamp_type\x18\x0f \x01(\x0e\x32\x41.tecton_proto.feature_server.configuration.DataTableTimestampTypeR\x16\x64\x61taTableTimestampType\x12\x82\x01\n\x1bstatus_table_timestamp_type\x18\x10 \x01(\x0e\x32\x43.tecton_proto.feature_server.configuration.StatusTableTimestampTypeR\x18statusTableTimestampType\x12#\n\rtimestamp_key\x18\x0c \x01(\tR\x0ctimestampKey\x12<\n\x0cslide_period\x18\r \x01(\x0b\x32\x19.google.protobuf.DurationR\x0bslidePeriod\x12:\n\x0bserving_ttl\x18\x0e \x01(\x0b\x32\x19.google.protobuf.DurationR\nservingTtl\x12\x30\n\x14refresh_status_table\x18\x11 \x01(\x08R\x12refreshStatusTable\x12*\n\x11\x66\x65\x61ture_view_name\x18\x15 \x01(\tR\x0f\x66\x65\x61tureViewName\x12?\n\x1c\x66\x65\x61ture_store_format_version\x18\x12 \x01(\x05R\x19\x66\x65\x61tureStoreFormatVersion\x12T\n\x13online_store_params\x18\x13 \x01(\x0b\x32$.tecton_proto.data.OnlineStoreParamsR\x11onlineStoreParams\x12\x1a\n\x08\x64\x65ltaTTL\x18\x14 \x01(\x03R\x08\x64\x65ltaTTLJ\x04\x08\x02\x10\x03J\x04\x08\n\x10\x0bJ\x04\x08\x0b\x10\x0c\"g\n\x11\x46\x65\x61tureVectorPlan\x12R\n\x08\x66\x65\x61tures\x18\x01 \x03(\x0b\x32\x36.tecton_proto.feature_server.configuration.FeaturePlanR\x08\x66\x65\x61tures\"\x9c\x05\n\x14OnDemandFeaturesPlan\x12l\n\x19\x61rgs_from_request_context\x18\x02 \x03(\x0b\x32\x31.tecton_proto.feature_server.configuration.ColumnR\x16\x61rgsFromRequestContext\x12K\n\x07outputs\x18\x03 \x03(\x0b\x32\x31.tecton_proto.feature_server.configuration.ColumnR\x07outputs\x12\x83\x01\n\x12\x66\x65\x61ture_set_inputs\x18\x05 \x03(\x0b\x32U.tecton_proto.feature_server.configuration.OnDemandFeaturesPlan.FeatureSetInputsEntryR\x10\x66\x65\x61tureSetInputs\x12\x37\n\x08pipeline\x18\x06 \x01(\x0b\x32\x1b.tecton_proto.args.PipelineR\x08pipeline\x12N\n\x0ftransformations\x18\x07 \x03(\x0b\x32$.tecton_proto.data.NewTransformationR\x0ftransformations\x12*\n\x11\x66\x65\x61ture_view_name\x18\x08 \x01(\tR\x0f\x66\x65\x61tureViewName\x1a\x81\x01\n\x15\x46\x65\x61tureSetInputsEntry\x12\x10\n\x03key\x18\x01 \x01(\tR\x03key\x12R\n\x05value\x18\x02 \x01(\x0b\x32<.tecton_proto.feature_server.configuration.FeatureVectorPlanR\x05value:\x02\x38\x01J\x04\x08\x01\x10\x02J\x04\x08\x04\x10\x05\"\x81\x01\n\rLoggingConfig\x12\x1f\n\x0bsample_rate\x18\x01 \x01(\x02R\nsampleRate\x12.\n\x13log_effective_times\x18\x02 \x01(\x08R\x11logEffectiveTimes\x12\x1f\n\x0b\x61vro_schema\x18\x03 \x01(\tR\navroSchema\"\x8d\x05\n\x12\x46\x65\x61tureServicePlan\x12\x45\n\x12\x66\x65\x61ture_service_id\x18\x04 \x01(\x0b\x32\x17.tecton_proto.common.IdR\x10\x66\x65\x61tureServiceId\x12?\n\x0f\x66\x65\x61ture_view_id\x18\n \x01(\x0b\x32\x17.tecton_proto.common.IdR\rfeatureViewId\x12\x30\n\x14\x66\x65\x61ture_service_name\x18\x02 \x01(\tR\x12\x66\x65\x61tureServiceName\x12*\n\x11\x66\x65\x61ture_view_name\x18\t \x01(\tR\x0f\x66\x65\x61tureViewName\x12%\n\x0eworkspace_name\x18\x08 \x01(\tR\rworkspaceName\x12^\n\x0e\x66\x65\x61tures_plans\x18\r \x03(\x0b\x32\x37.tecton_proto.feature_server.configuration.FeaturesPlanR\rfeaturesPlans\x12N\n\x11join_key_template\x18\x05 \x01(\x0b\x32\".tecton_proto.data.JoinKeyTemplateR\x0fjoinKeyTemplate\x12\x41\n\x10\x66\x65\x61ture_view_ids\x18\x06 \x03(\x0b\x32\x17.tecton_proto.common.IdR\x0e\x66\x65\x61tureViewIds\x12_\n\x0elogging_config\x18\x0c \x01(\x0b\x32\x38.tecton_proto.feature_server.configuration.LoggingConfigR\rloggingConfigJ\x04\x08\x01\x10\x02J\x04\x08\x03\x10\x04J\x04\x08\x07\x10\x08J\x04\x08\x0b\x10\x0c\"\x80\x04\n\x11GlobalTableConfig\x12?\n\x0f\x66\x65\x61ture_view_id\x18\x04 \x01(\x0b\x32\x17.tecton_proto.common.IdR\rfeatureViewId\x12<\n\x0cslide_period\x18\x02 \x01(\x0b\x32\x19.google.protobuf.DurationR\x0bslidePeriod\x12\x12\n\x04size\x18\x03 \x01(\x05R\x04size\x12\x82\x01\n\x1bstatus_table_timestamp_type\x18\x06 \x01(\x0e\x32\x43.tecton_proto.feature_server.configuration.StatusTableTimestampTypeR\x18statusTableTimestampType\x12\x30\n\x14refresh_status_table\x18\x07 \x01(\x08R\x12refreshStatusTable\x12?\n\x1c\x66\x65\x61ture_store_format_version\x18\x08 \x01(\x05R\x19\x66\x65\x61tureStoreFormatVersion\x12T\n\x13online_store_params\x18\t \x01(\x0b\x32$.tecton_proto.data.OnlineStoreParamsR\x11onlineStoreParamsJ\x04\x08\x01\x10\x02J\x04\x08\x05\x10\x06\"\xc6\x04\n\x1a\x46\x65\x61tureServerConfiguration\x12?\n\rcomputed_time\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.TimestampR\x0c\x63omputedTime\x12h\n\x10\x66\x65\x61ture_services\x18\x01 \x03(\x0b\x32=.tecton_proto.feature_server.configuration.FeatureServicePlanR\x0f\x66\x65\x61tureServices\x12\xa0\x01\n\x1bglobal_table_config_by_name\x18\x03 \x03(\x0b\x32\x62.tecton_proto.feature_server.configuration.FeatureServerConfiguration.GlobalTableConfigByNameEntryR\x17globalTableConfigByName\x12O\n\x13\x61uthorized_api_keys\x18\x04 \x03(\x0b\x32\x1f.tecton_proto.data.TectonApiKeyR\x11\x61uthorizedApiKeys\x1a\x88\x01\n\x1cGlobalTableConfigByNameEntry\x12\x10\n\x03key\x18\x01 \x01(\tR\x03key\x12R\n\x05value\x18\x02 \x01(\x0b\x32<.tecton_proto.feature_server.configuration.GlobalTableConfigR\x05value:\x02\x38\x01*\x90\x01\n\x16\x44\x61taTableTimestampType\x12%\n!DATA_TABLE_TIMESTAMP_TYPE_UNKNOWN\x10\x00\x12&\n\"DATA_TABLE_TIMESTAMP_TYPE_SORT_KEY\x10\x01\x12\'\n#DATA_TABLE_TIMESTAMP_TYPE_ATTRIBUTE\x10\x02*\x98\x01\n\x18StatusTableTimestampType\x12\'\n#STATUS_TABLE_TIMESTAMP_TYPE_UNKNOWN\x10\x00\x12(\n$STATUS_TABLE_TIMESTAMP_TYPE_SORT_KEY\x10\x01\x12)\n%STATUS_TABLE_TIMESTAMP_TYPE_ATTRIBUTE\x10\x02\x42l\n(com.tecton.feature_service.configurationP\x01Z>github.com/tecton-ai/tecton_proto/feature_server/configuration'
  ,
  dependencies=[google_dot_protobuf_dot_duration__pb2.DESCRIPTOR,google_dot_protobuf_dot_timestamp__pb2.DESCRIPTOR,tecton__proto_dot_args_dot_user__defined__function__pb2.DESCRIPTOR,tecton__proto_dot_args_dot_pipeline__pb2.DESCRIPTOR,tecton__proto_dot_common_dot_aggregation__function__pb2.DESCRIPTOR,tecton__proto_dot_common_dot_column__type__pb2.DESCRIPTOR,tecton__proto_dot_common_dot_id__pb2.DESCRIPTOR,tecton__proto_dot_data_dot_feature__service__pb2.DESCRIPTOR,tecton__proto_dot_data_dot_feature__view__pb2.DESCRIPTOR,tecton__proto_dot_data_dot_tecton__api__key__pb2.DESCRIPTOR,tecton__proto_dot_data_dot_new__transformation__pb2.DESCRIPTOR,])

_DATATABLETIMESTAMPTYPE = _descriptor.EnumDescriptor(
  name='DataTableTimestampType',
  full_name='tecton_proto.feature_server.configuration.DataTableTimestampType',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='DATA_TABLE_TIMESTAMP_TYPE_UNKNOWN', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='DATA_TABLE_TIMESTAMP_TYPE_SORT_KEY', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='DATA_TABLE_TIMESTAMP_TYPE_ATTRIBUTE', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=5066,
  serialized_end=5210,
)
_sym_db.RegisterEnumDescriptor(_DATATABLETIMESTAMPTYPE)

DataTableTimestampType = enum_type_wrapper.EnumTypeWrapper(_DATATABLETIMESTAMPTYPE)
_STATUSTABLETIMESTAMPTYPE = _descriptor.EnumDescriptor(
  name='StatusTableTimestampType',
  full_name='tecton_proto.feature_server.configuration.StatusTableTimestampType',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='STATUS_TABLE_TIMESTAMP_TYPE_UNKNOWN', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='STATUS_TABLE_TIMESTAMP_TYPE_SORT_KEY', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='STATUS_TABLE_TIMESTAMP_TYPE_ATTRIBUTE', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=5213,
  serialized_end=5365,
)
_sym_db.RegisterEnumDescriptor(_STATUSTABLETIMESTAMPTYPE)

StatusTableTimestampType = enum_type_wrapper.EnumTypeWrapper(_STATUSTABLETIMESTAMPTYPE)
DATA_TABLE_TIMESTAMP_TYPE_UNKNOWN = 0
DATA_TABLE_TIMESTAMP_TYPE_SORT_KEY = 1
DATA_TABLE_TIMESTAMP_TYPE_ATTRIBUTE = 2
STATUS_TABLE_TIMESTAMP_TYPE_UNKNOWN = 0
STATUS_TABLE_TIMESTAMP_TYPE_SORT_KEY = 1
STATUS_TABLE_TIMESTAMP_TYPE_ATTRIBUTE = 2



_FEATURESPLAN = _descriptor.Descriptor(
  name='FeaturesPlan',
  full_name='tecton_proto.feature_server.configuration.FeaturesPlan',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='feature_plan', full_name='tecton_proto.feature_server.configuration.FeaturesPlan.feature_plan', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='featurePlan', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='on_demand_features_plan', full_name='tecton_proto.feature_server.configuration.FeaturesPlan.on_demand_features_plan', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='onDemandFeaturesPlan', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='fp', full_name='tecton_proto.feature_server.configuration.FeaturesPlan.fp',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=550,
  serialized_end=785,
)


_COLUMN = _descriptor.Descriptor(
  name='Column',
  full_name='tecton_proto.feature_server.configuration.Column',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='type', full_name='tecton_proto.feature_server.configuration.Column.type', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='type', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='feature_view_space_name', full_name='tecton_proto.feature_server.configuration.Column.feature_view_space_name', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='featureViewSpaceName', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='feature_service_space_name', full_name='tecton_proto.feature_server.configuration.Column.feature_service_space_name', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='featureServiceSpaceName', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='feature_view_index', full_name='tecton_proto.feature_server.configuration.Column.feature_view_index', index=3,
      number=4, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='featureViewIndex', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=788,
  serialized_end=1011,
)


_FEATUREPLAN = _descriptor.Descriptor(
  name='FeaturePlan',
  full_name='tecton_proto.feature_server.configuration.FeaturePlan',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='output_column', full_name='tecton_proto.feature_server.configuration.FeaturePlan.output_column', index=0,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='outputColumn', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='input_columns', full_name='tecton_proto.feature_server.configuration.FeaturePlan.input_columns', index=1,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='inputColumns', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='aggregation_function', full_name='tecton_proto.feature_server.configuration.FeaturePlan.aggregation_function', index=2,
      number=3, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='aggregationFunction', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='aggregation_function_params', full_name='tecton_proto.feature_server.configuration.FeaturePlan.aggregation_function_params', index=3,
      number=6, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='aggregationFunctionParams', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='aggregation_window', full_name='tecton_proto.feature_server.configuration.FeaturePlan.aggregation_window', index=4,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='aggregationWindow', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='join_keys', full_name='tecton_proto.feature_server.configuration.FeaturePlan.join_keys', index=5,
      number=7, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='joinKeys', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='wildcard_join_keys', full_name='tecton_proto.feature_server.configuration.FeaturePlan.wildcard_join_keys', index=6,
      number=8, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='wildcardJoinKeys', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='table_name', full_name='tecton_proto.feature_server.configuration.FeaturePlan.table_name', index=7,
      number=9, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='tableName', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='data_table_timestamp_type', full_name='tecton_proto.feature_server.configuration.FeaturePlan.data_table_timestamp_type', index=8,
      number=15, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='dataTableTimestampType', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='status_table_timestamp_type', full_name='tecton_proto.feature_server.configuration.FeaturePlan.status_table_timestamp_type', index=9,
      number=16, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='statusTableTimestampType', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='timestamp_key', full_name='tecton_proto.feature_server.configuration.FeaturePlan.timestamp_key', index=10,
      number=12, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='timestampKey', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='slide_period', full_name='tecton_proto.feature_server.configuration.FeaturePlan.slide_period', index=11,
      number=13, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='slidePeriod', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='serving_ttl', full_name='tecton_proto.feature_server.configuration.FeaturePlan.serving_ttl', index=12,
      number=14, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='servingTtl', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='refresh_status_table', full_name='tecton_proto.feature_server.configuration.FeaturePlan.refresh_status_table', index=13,
      number=17, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='refreshStatusTable', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='feature_view_name', full_name='tecton_proto.feature_server.configuration.FeaturePlan.feature_view_name', index=14,
      number=21, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='featureViewName', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='feature_store_format_version', full_name='tecton_proto.feature_server.configuration.FeaturePlan.feature_store_format_version', index=15,
      number=18, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='featureStoreFormatVersion', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='online_store_params', full_name='tecton_proto.feature_server.configuration.FeaturePlan.online_store_params', index=16,
      number=19, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='onlineStoreParams', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='deltaTTL', full_name='tecton_proto.feature_server.configuration.FeaturePlan.deltaTTL', index=17,
      number=20, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='deltaTTL', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1014,
  serialized_end=2399,
)


_FEATUREVECTORPLAN = _descriptor.Descriptor(
  name='FeatureVectorPlan',
  full_name='tecton_proto.feature_server.configuration.FeatureVectorPlan',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='features', full_name='tecton_proto.feature_server.configuration.FeatureVectorPlan.features', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='features', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2401,
  serialized_end=2504,
)


_ONDEMANDFEATURESPLAN_FEATURESETINPUTSENTRY = _descriptor.Descriptor(
  name='FeatureSetInputsEntry',
  full_name='tecton_proto.feature_server.configuration.OnDemandFeaturesPlan.FeatureSetInputsEntry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='tecton_proto.feature_server.configuration.OnDemandFeaturesPlan.FeatureSetInputsEntry.key', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='key', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='value', full_name='tecton_proto.feature_server.configuration.OnDemandFeaturesPlan.FeatureSetInputsEntry.value', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='value', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'8\001',
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3034,
  serialized_end=3163,
)

_ONDEMANDFEATURESPLAN = _descriptor.Descriptor(
  name='OnDemandFeaturesPlan',
  full_name='tecton_proto.feature_server.configuration.OnDemandFeaturesPlan',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='args_from_request_context', full_name='tecton_proto.feature_server.configuration.OnDemandFeaturesPlan.args_from_request_context', index=0,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='argsFromRequestContext', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='outputs', full_name='tecton_proto.feature_server.configuration.OnDemandFeaturesPlan.outputs', index=1,
      number=3, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='outputs', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='feature_set_inputs', full_name='tecton_proto.feature_server.configuration.OnDemandFeaturesPlan.feature_set_inputs', index=2,
      number=5, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='featureSetInputs', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='pipeline', full_name='tecton_proto.feature_server.configuration.OnDemandFeaturesPlan.pipeline', index=3,
      number=6, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='pipeline', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='transformations', full_name='tecton_proto.feature_server.configuration.OnDemandFeaturesPlan.transformations', index=4,
      number=7, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='transformations', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='feature_view_name', full_name='tecton_proto.feature_server.configuration.OnDemandFeaturesPlan.feature_view_name', index=5,
      number=8, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='featureViewName', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_ONDEMANDFEATURESPLAN_FEATURESETINPUTSENTRY, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2507,
  serialized_end=3175,
)


_LOGGINGCONFIG = _descriptor.Descriptor(
  name='LoggingConfig',
  full_name='tecton_proto.feature_server.configuration.LoggingConfig',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='sample_rate', full_name='tecton_proto.feature_server.configuration.LoggingConfig.sample_rate', index=0,
      number=1, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='sampleRate', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='log_effective_times', full_name='tecton_proto.feature_server.configuration.LoggingConfig.log_effective_times', index=1,
      number=2, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='logEffectiveTimes', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='avro_schema', full_name='tecton_proto.feature_server.configuration.LoggingConfig.avro_schema', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='avroSchema', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3178,
  serialized_end=3307,
)


_FEATURESERVICEPLAN = _descriptor.Descriptor(
  name='FeatureServicePlan',
  full_name='tecton_proto.feature_server.configuration.FeatureServicePlan',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='feature_service_id', full_name='tecton_proto.feature_server.configuration.FeatureServicePlan.feature_service_id', index=0,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='featureServiceId', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='feature_view_id', full_name='tecton_proto.feature_server.configuration.FeatureServicePlan.feature_view_id', index=1,
      number=10, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='featureViewId', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='feature_service_name', full_name='tecton_proto.feature_server.configuration.FeatureServicePlan.feature_service_name', index=2,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='featureServiceName', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='feature_view_name', full_name='tecton_proto.feature_server.configuration.FeatureServicePlan.feature_view_name', index=3,
      number=9, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='featureViewName', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='workspace_name', full_name='tecton_proto.feature_server.configuration.FeatureServicePlan.workspace_name', index=4,
      number=8, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='workspaceName', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='features_plans', full_name='tecton_proto.feature_server.configuration.FeatureServicePlan.features_plans', index=5,
      number=13, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='featuresPlans', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='join_key_template', full_name='tecton_proto.feature_server.configuration.FeatureServicePlan.join_key_template', index=6,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='joinKeyTemplate', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='feature_view_ids', full_name='tecton_proto.feature_server.configuration.FeatureServicePlan.feature_view_ids', index=7,
      number=6, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='featureViewIds', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='logging_config', full_name='tecton_proto.feature_server.configuration.FeatureServicePlan.logging_config', index=8,
      number=12, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='loggingConfig', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3310,
  serialized_end=3963,
)


_GLOBALTABLECONFIG = _descriptor.Descriptor(
  name='GlobalTableConfig',
  full_name='tecton_proto.feature_server.configuration.GlobalTableConfig',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='feature_view_id', full_name='tecton_proto.feature_server.configuration.GlobalTableConfig.feature_view_id', index=0,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='featureViewId', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='slide_period', full_name='tecton_proto.feature_server.configuration.GlobalTableConfig.slide_period', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='slidePeriod', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='size', full_name='tecton_proto.feature_server.configuration.GlobalTableConfig.size', index=2,
      number=3, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='size', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='status_table_timestamp_type', full_name='tecton_proto.feature_server.configuration.GlobalTableConfig.status_table_timestamp_type', index=3,
      number=6, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='statusTableTimestampType', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='refresh_status_table', full_name='tecton_proto.feature_server.configuration.GlobalTableConfig.refresh_status_table', index=4,
      number=7, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='refreshStatusTable', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='feature_store_format_version', full_name='tecton_proto.feature_server.configuration.GlobalTableConfig.feature_store_format_version', index=5,
      number=8, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='featureStoreFormatVersion', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='online_store_params', full_name='tecton_proto.feature_server.configuration.GlobalTableConfig.online_store_params', index=6,
      number=9, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='onlineStoreParams', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3966,
  serialized_end=4478,
)


_FEATURESERVERCONFIGURATION_GLOBALTABLECONFIGBYNAMEENTRY = _descriptor.Descriptor(
  name='GlobalTableConfigByNameEntry',
  full_name='tecton_proto.feature_server.configuration.FeatureServerConfiguration.GlobalTableConfigByNameEntry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='tecton_proto.feature_server.configuration.FeatureServerConfiguration.GlobalTableConfigByNameEntry.key', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='key', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='value', full_name='tecton_proto.feature_server.configuration.FeatureServerConfiguration.GlobalTableConfigByNameEntry.value', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='value', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'8\001',
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4927,
  serialized_end=5063,
)

_FEATURESERVERCONFIGURATION = _descriptor.Descriptor(
  name='FeatureServerConfiguration',
  full_name='tecton_proto.feature_server.configuration.FeatureServerConfiguration',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='computed_time', full_name='tecton_proto.feature_server.configuration.FeatureServerConfiguration.computed_time', index=0,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='computedTime', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='feature_services', full_name='tecton_proto.feature_server.configuration.FeatureServerConfiguration.feature_services', index=1,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='featureServices', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='global_table_config_by_name', full_name='tecton_proto.feature_server.configuration.FeatureServerConfiguration.global_table_config_by_name', index=2,
      number=3, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='globalTableConfigByName', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='authorized_api_keys', full_name='tecton_proto.feature_server.configuration.FeatureServerConfiguration.authorized_api_keys', index=3,
      number=4, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='authorizedApiKeys', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_FEATURESERVERCONFIGURATION_GLOBALTABLECONFIGBYNAMEENTRY, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4481,
  serialized_end=5063,
)

_FEATURESPLAN.fields_by_name['feature_plan'].message_type = _FEATUREPLAN
_FEATURESPLAN.fields_by_name['on_demand_features_plan'].message_type = _ONDEMANDFEATURESPLAN
_FEATURESPLAN.oneofs_by_name['fp'].fields.append(
  _FEATURESPLAN.fields_by_name['feature_plan'])
_FEATURESPLAN.fields_by_name['feature_plan'].containing_oneof = _FEATURESPLAN.oneofs_by_name['fp']
_FEATURESPLAN.oneofs_by_name['fp'].fields.append(
  _FEATURESPLAN.fields_by_name['on_demand_features_plan'])
_FEATURESPLAN.fields_by_name['on_demand_features_plan'].containing_oneof = _FEATURESPLAN.oneofs_by_name['fp']
_COLUMN.fields_by_name['type'].enum_type = tecton__proto_dot_common_dot_column__type__pb2._COLUMNTYPE
_FEATUREPLAN.fields_by_name['output_column'].message_type = _COLUMN
_FEATUREPLAN.fields_by_name['input_columns'].message_type = _COLUMN
_FEATUREPLAN.fields_by_name['aggregation_function'].enum_type = tecton__proto_dot_common_dot_aggregation__function__pb2._AGGREGATIONFUNCTION
_FEATUREPLAN.fields_by_name['aggregation_function_params'].message_type = tecton__proto_dot_common_dot_aggregation__function__pb2._AGGREGATIONFUNCTIONPARAMS
_FEATUREPLAN.fields_by_name['aggregation_window'].message_type = google_dot_protobuf_dot_duration__pb2._DURATION
_FEATUREPLAN.fields_by_name['join_keys'].message_type = _COLUMN
_FEATUREPLAN.fields_by_name['wildcard_join_keys'].message_type = _COLUMN
_FEATUREPLAN.fields_by_name['data_table_timestamp_type'].enum_type = _DATATABLETIMESTAMPTYPE
_FEATUREPLAN.fields_by_name['status_table_timestamp_type'].enum_type = _STATUSTABLETIMESTAMPTYPE
_FEATUREPLAN.fields_by_name['slide_period'].message_type = google_dot_protobuf_dot_duration__pb2._DURATION
_FEATUREPLAN.fields_by_name['serving_ttl'].message_type = google_dot_protobuf_dot_duration__pb2._DURATION
_FEATUREPLAN.fields_by_name['online_store_params'].message_type = tecton__proto_dot_data_dot_feature__view__pb2._ONLINESTOREPARAMS
_FEATUREVECTORPLAN.fields_by_name['features'].message_type = _FEATUREPLAN
_ONDEMANDFEATURESPLAN_FEATURESETINPUTSENTRY.fields_by_name['value'].message_type = _FEATUREVECTORPLAN
_ONDEMANDFEATURESPLAN_FEATURESETINPUTSENTRY.containing_type = _ONDEMANDFEATURESPLAN
_ONDEMANDFEATURESPLAN.fields_by_name['args_from_request_context'].message_type = _COLUMN
_ONDEMANDFEATURESPLAN.fields_by_name['outputs'].message_type = _COLUMN
_ONDEMANDFEATURESPLAN.fields_by_name['feature_set_inputs'].message_type = _ONDEMANDFEATURESPLAN_FEATURESETINPUTSENTRY
_ONDEMANDFEATURESPLAN.fields_by_name['pipeline'].message_type = tecton__proto_dot_args_dot_pipeline__pb2._PIPELINE
_ONDEMANDFEATURESPLAN.fields_by_name['transformations'].message_type = tecton__proto_dot_data_dot_new__transformation__pb2._NEWTRANSFORMATION
_FEATURESERVICEPLAN.fields_by_name['feature_service_id'].message_type = tecton__proto_dot_common_dot_id__pb2._ID
_FEATURESERVICEPLAN.fields_by_name['feature_view_id'].message_type = tecton__proto_dot_common_dot_id__pb2._ID
_FEATURESERVICEPLAN.fields_by_name['features_plans'].message_type = _FEATURESPLAN
_FEATURESERVICEPLAN.fields_by_name['join_key_template'].message_type = tecton__proto_dot_data_dot_feature__service__pb2._JOINKEYTEMPLATE
_FEATURESERVICEPLAN.fields_by_name['feature_view_ids'].message_type = tecton__proto_dot_common_dot_id__pb2._ID
_FEATURESERVICEPLAN.fields_by_name['logging_config'].message_type = _LOGGINGCONFIG
_GLOBALTABLECONFIG.fields_by_name['feature_view_id'].message_type = tecton__proto_dot_common_dot_id__pb2._ID
_GLOBALTABLECONFIG.fields_by_name['slide_period'].message_type = google_dot_protobuf_dot_duration__pb2._DURATION
_GLOBALTABLECONFIG.fields_by_name['status_table_timestamp_type'].enum_type = _STATUSTABLETIMESTAMPTYPE
_GLOBALTABLECONFIG.fields_by_name['online_store_params'].message_type = tecton__proto_dot_data_dot_feature__view__pb2._ONLINESTOREPARAMS
_FEATURESERVERCONFIGURATION_GLOBALTABLECONFIGBYNAMEENTRY.fields_by_name['value'].message_type = _GLOBALTABLECONFIG
_FEATURESERVERCONFIGURATION_GLOBALTABLECONFIGBYNAMEENTRY.containing_type = _FEATURESERVERCONFIGURATION
_FEATURESERVERCONFIGURATION.fields_by_name['computed_time'].message_type = google_dot_protobuf_dot_timestamp__pb2._TIMESTAMP
_FEATURESERVERCONFIGURATION.fields_by_name['feature_services'].message_type = _FEATURESERVICEPLAN
_FEATURESERVERCONFIGURATION.fields_by_name['global_table_config_by_name'].message_type = _FEATURESERVERCONFIGURATION_GLOBALTABLECONFIGBYNAMEENTRY
_FEATURESERVERCONFIGURATION.fields_by_name['authorized_api_keys'].message_type = tecton__proto_dot_data_dot_tecton__api__key__pb2._TECTONAPIKEY
DESCRIPTOR.message_types_by_name['FeaturesPlan'] = _FEATURESPLAN
DESCRIPTOR.message_types_by_name['Column'] = _COLUMN
DESCRIPTOR.message_types_by_name['FeaturePlan'] = _FEATUREPLAN
DESCRIPTOR.message_types_by_name['FeatureVectorPlan'] = _FEATUREVECTORPLAN
DESCRIPTOR.message_types_by_name['OnDemandFeaturesPlan'] = _ONDEMANDFEATURESPLAN
DESCRIPTOR.message_types_by_name['LoggingConfig'] = _LOGGINGCONFIG
DESCRIPTOR.message_types_by_name['FeatureServicePlan'] = _FEATURESERVICEPLAN
DESCRIPTOR.message_types_by_name['GlobalTableConfig'] = _GLOBALTABLECONFIG
DESCRIPTOR.message_types_by_name['FeatureServerConfiguration'] = _FEATURESERVERCONFIGURATION
DESCRIPTOR.enum_types_by_name['DataTableTimestampType'] = _DATATABLETIMESTAMPTYPE
DESCRIPTOR.enum_types_by_name['StatusTableTimestampType'] = _STATUSTABLETIMESTAMPTYPE
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

FeaturesPlan = _reflection.GeneratedProtocolMessageType('FeaturesPlan', (_message.Message,), {
  'DESCRIPTOR' : _FEATURESPLAN,
  '__module__' : 'tecton_proto.feature_server.configuration.feature_server_configuration_pb2'
  # @@protoc_insertion_point(class_scope:tecton_proto.feature_server.configuration.FeaturesPlan)
  })
_sym_db.RegisterMessage(FeaturesPlan)

Column = _reflection.GeneratedProtocolMessageType('Column', (_message.Message,), {
  'DESCRIPTOR' : _COLUMN,
  '__module__' : 'tecton_proto.feature_server.configuration.feature_server_configuration_pb2'
  # @@protoc_insertion_point(class_scope:tecton_proto.feature_server.configuration.Column)
  })
_sym_db.RegisterMessage(Column)

FeaturePlan = _reflection.GeneratedProtocolMessageType('FeaturePlan', (_message.Message,), {
  'DESCRIPTOR' : _FEATUREPLAN,
  '__module__' : 'tecton_proto.feature_server.configuration.feature_server_configuration_pb2'
  # @@protoc_insertion_point(class_scope:tecton_proto.feature_server.configuration.FeaturePlan)
  })
_sym_db.RegisterMessage(FeaturePlan)

FeatureVectorPlan = _reflection.GeneratedProtocolMessageType('FeatureVectorPlan', (_message.Message,), {
  'DESCRIPTOR' : _FEATUREVECTORPLAN,
  '__module__' : 'tecton_proto.feature_server.configuration.feature_server_configuration_pb2'
  # @@protoc_insertion_point(class_scope:tecton_proto.feature_server.configuration.FeatureVectorPlan)
  })
_sym_db.RegisterMessage(FeatureVectorPlan)

OnDemandFeaturesPlan = _reflection.GeneratedProtocolMessageType('OnDemandFeaturesPlan', (_message.Message,), {

  'FeatureSetInputsEntry' : _reflection.GeneratedProtocolMessageType('FeatureSetInputsEntry', (_message.Message,), {
    'DESCRIPTOR' : _ONDEMANDFEATURESPLAN_FEATURESETINPUTSENTRY,
    '__module__' : 'tecton_proto.feature_server.configuration.feature_server_configuration_pb2'
    # @@protoc_insertion_point(class_scope:tecton_proto.feature_server.configuration.OnDemandFeaturesPlan.FeatureSetInputsEntry)
    })
  ,
  'DESCRIPTOR' : _ONDEMANDFEATURESPLAN,
  '__module__' : 'tecton_proto.feature_server.configuration.feature_server_configuration_pb2'
  # @@protoc_insertion_point(class_scope:tecton_proto.feature_server.configuration.OnDemandFeaturesPlan)
  })
_sym_db.RegisterMessage(OnDemandFeaturesPlan)
_sym_db.RegisterMessage(OnDemandFeaturesPlan.FeatureSetInputsEntry)

LoggingConfig = _reflection.GeneratedProtocolMessageType('LoggingConfig', (_message.Message,), {
  'DESCRIPTOR' : _LOGGINGCONFIG,
  '__module__' : 'tecton_proto.feature_server.configuration.feature_server_configuration_pb2'
  # @@protoc_insertion_point(class_scope:tecton_proto.feature_server.configuration.LoggingConfig)
  })
_sym_db.RegisterMessage(LoggingConfig)

FeatureServicePlan = _reflection.GeneratedProtocolMessageType('FeatureServicePlan', (_message.Message,), {
  'DESCRIPTOR' : _FEATURESERVICEPLAN,
  '__module__' : 'tecton_proto.feature_server.configuration.feature_server_configuration_pb2'
  # @@protoc_insertion_point(class_scope:tecton_proto.feature_server.configuration.FeatureServicePlan)
  })
_sym_db.RegisterMessage(FeatureServicePlan)

GlobalTableConfig = _reflection.GeneratedProtocolMessageType('GlobalTableConfig', (_message.Message,), {
  'DESCRIPTOR' : _GLOBALTABLECONFIG,
  '__module__' : 'tecton_proto.feature_server.configuration.feature_server_configuration_pb2'
  # @@protoc_insertion_point(class_scope:tecton_proto.feature_server.configuration.GlobalTableConfig)
  })
_sym_db.RegisterMessage(GlobalTableConfig)

FeatureServerConfiguration = _reflection.GeneratedProtocolMessageType('FeatureServerConfiguration', (_message.Message,), {

  'GlobalTableConfigByNameEntry' : _reflection.GeneratedProtocolMessageType('GlobalTableConfigByNameEntry', (_message.Message,), {
    'DESCRIPTOR' : _FEATURESERVERCONFIGURATION_GLOBALTABLECONFIGBYNAMEENTRY,
    '__module__' : 'tecton_proto.feature_server.configuration.feature_server_configuration_pb2'
    # @@protoc_insertion_point(class_scope:tecton_proto.feature_server.configuration.FeatureServerConfiguration.GlobalTableConfigByNameEntry)
    })
  ,
  'DESCRIPTOR' : _FEATURESERVERCONFIGURATION,
  '__module__' : 'tecton_proto.feature_server.configuration.feature_server_configuration_pb2'
  # @@protoc_insertion_point(class_scope:tecton_proto.feature_server.configuration.FeatureServerConfiguration)
  })
_sym_db.RegisterMessage(FeatureServerConfiguration)
_sym_db.RegisterMessage(FeatureServerConfiguration.GlobalTableConfigByNameEntry)


DESCRIPTOR._options = None
_ONDEMANDFEATURESPLAN_FEATURESETINPUTSENTRY._options = None
_FEATURESERVERCONFIGURATION_GLOBALTABLECONFIGBYNAMEENTRY._options = None
# @@protoc_insertion_point(module_scope)
