# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: tecton_proto/data/feature_view.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import duration_pb2 as google_dot_protobuf_dot_duration__pb2
from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2
from tecton_proto.args import pipeline_pb2 as tecton__proto_dot_args_dot_pipeline__pb2
from tecton_proto.args import virtual_data_source_pb2 as tecton__proto_dot_args_dot_virtual__data__source__pb2
from tecton_proto.args import feature_view_pb2 as tecton__proto_dot_args_dot_feature__view__pb2
from tecton_proto.data import entity_pb2 as tecton__proto_dot_data_dot_entity__pb2
from tecton_proto.common import aggregation_function_pb2 as tecton__proto_dot_common_dot_aggregation__function__pb2
from tecton_proto.data import virtual_data_source_pb2 as tecton__proto_dot_data_dot_virtual__data__source__pb2
from tecton_proto.data import fv_materialization_pb2 as tecton__proto_dot_data_dot_fv__materialization__pb2
from tecton_proto.common import schema_pb2 as tecton__proto_dot_common_dot_schema__pb2
from tecton_proto.data import new_transformation_pb2 as tecton__proto_dot_data_dot_new__transformation__pb2
from tecton_proto.data import fco_metadata_pb2 as tecton__proto_dot_data_dot_fco__metadata__pb2
from tecton_proto.common import id_pb2 as tecton__proto_dot_common_dot_id__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='tecton_proto/data/feature_view.proto',
  package='tecton_proto.data',
  syntax='proto2',
  serialized_options=b'\n\017com.tecton.dataP\001',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n$tecton_proto/data/feature_view.proto\x12\x11tecton_proto.data\x1a\x1egoogle/protobuf/duration.proto\x1a\x1fgoogle/protobuf/timestamp.proto\x1a tecton_proto/args/pipeline.proto\x1a+tecton_proto/args/virtual_data_source.proto\x1a$tecton_proto/args/feature_view.proto\x1a\x1etecton_proto/data/entity.proto\x1a.tecton_proto/common/aggregation_function.proto\x1a+tecton_proto/data/virtual_data_source.proto\x1a*tecton_proto/data/fv_materialization.proto\x1a tecton_proto/common/schema.proto\x1a*tecton_proto/data/new_transformation.proto\x1a$tecton_proto/data/fco_metadata.proto\x1a\x1ctecton_proto/common/id.proto\"\xc2\x0b\n\x0b\x46\x65\x61tureView\x12?\n\x0f\x66\x65\x61ture_view_id\x18\x01 \x01(\x0b\x32\x17.tecton_proto.common.IdR\rfeatureViewId\x12\x41\n\x0c\x66\x63o_metadata\x18\x02 \x01(\x0b\x32\x1e.tecton_proto.data.FcoMetadataR\x0b\x66\x63oMetadata\x12\x36\n\nentity_ids\x18\x03 \x03(\x0b\x32\x17.tecton_proto.common.IdR\tentityIds\x12\x1b\n\tjoin_keys\x18\x04 \x03(\tR\x08joinKeys\x12?\n\x07schemas\x18\x0b \x01(\x0b\x32%.tecton_proto.data.FeatureViewSchemasR\x07schemas\x12P\n\x0b\x65nrichments\x18\xe8\x07 \x01(\x0b\x32).tecton_proto.data.FeatureViewEnrichmentsB\x02\x18\x01R\x0b\x65nrichments\x12X\n\x12temporal_aggregate\x18\x07 \x01(\x0b\x32\'.tecton_proto.data.NewTemporalAggregateH\x00R\x11temporalAggregate\x12<\n\x08temporal\x18\x08 \x01(\x0b\x32\x1e.tecton_proto.data.NewTemporalH\x00R\x08temporal\x12]\n\x16on_demand_feature_view\x18\x11 \x01(\x0b\x32&.tecton_proto.data.OnDemandFeatureViewH\x00R\x13onDemandFeatureView\x12\x46\n\rfeature_table\x18\x10 \x01(\x0b\x32\x1f.tecton_proto.data.FeatureTableH\x00R\x0c\x66\x65\x61tureTable\x12#\n\rtimestamp_key\x18\n \x01(\tR\x0ctimestampKey\x12W\n\x14online_serving_index\x18\x05 \x01(\x0b\x32%.tecton_proto.data.OnlineServingIndexR\x12onlineServingIndex\x12\x37\n\x08pipeline\x18\x06 \x01(\x0b\x32\x1b.tecton_proto.args.PipelineR\x08pipeline\x12\x62\n\x16materialization_params\x18\t \x01(\x0b\x32+.tecton_proto.data.NewMaterializationParamsR\x15materializationParams\x12\x37\n\x17materialization_enabled\x18\x0c \x01(\x08R\x16materializationEnabled\x12}\n!materialization_state_transitions\x18\r \x03(\x0b\x32\x31.tecton_proto.data.MaterializationStateTransitionR\x1fmaterializationStateTransitions\x12P\n\x11monitoring_params\x18\x0e \x01(\x0b\x32#.tecton_proto.data.MonitoringParamsR\x10monitoringParams\x12?\n\x1c\x66\x65\x61ture_store_format_version\x18\x17 \x01(\x05R\x19\x66\x65\x61tureStoreFormatVersion\x12G\n\x0esnowflake_data\x18\x18 \x01(\x0b\x32 .tecton_proto.data.SnowflakeDataR\rsnowflakeData\x12+\n\x11\x66ramework_version\x18\x13 \x01(\x05R\x10\x66rameworkVersion\x12\x17\n\x07web_url\x18\x19 \x01(\tR\x06webUrlB\x13\n\x11\x66\x65\x61ture_view_type\"\xbf\x02\n\x14NewTemporalAggregate\x12@\n\x0eslide_interval\x18\x01 \x01(\x0b\x32\x19.google.protobuf.DurationR\rslideInterval\x12\x32\n\x15slide_interval_string\x18\x05 \x01(\tR\x13slideIntervalString\x12?\n\x08\x66\x65\x61tures\x18\x02 \x03(\x0b\x32#.tecton_proto.data.AggregateFeatureR\x08\x66\x65\x61tures\x12#\n\ris_continuous\x18\x03 \x01(\x08R\x0cisContinuous\x12K\n\x10\x64\x61ta_source_type\x18\x04 \x01(\x0e\x32!.tecton_proto.args.DataSourceTypeR\x0e\x64\x61taSourceType\"\xc2\x02\n\x10\x41ggregateFeature\x12,\n\x12input_feature_name\x18\x01 \x01(\tR\x10inputFeatureName\x12.\n\x13output_feature_name\x18\x02 \x01(\tR\x11outputFeatureName\x12\x44\n\x08\x66unction\x18\x03 \x01(\x0e\x32(.tecton_proto.common.AggregationFunctionR\x08\x66unction\x12W\n\x0f\x66unction_params\x18\x05 \x01(\x0b\x32..tecton_proto.common.AggregationFunctionParamsR\x0e\x66unctionParams\x12\x31\n\x06window\x18\x04 \x01(\x0b\x32\x19.google.protobuf.DurationR\x06window\"\xf5\x01\n\x1dTrailingTimeWindowAggregation\x12\x19\n\x08time_key\x18\x01 \x01(\tR\x07timeKey\x12S\n\x18\x61ggregation_slide_period\x18\x02 \x01(\x0b\x32\x19.google.protobuf.DurationR\x16\x61ggregationSlidePeriod\x12?\n\x08\x66\x65\x61tures\x18\x03 \x03(\x0b\x32#.tecton_proto.data.AggregateFeatureR\x08\x66\x65\x61tures\x12#\n\ris_continuous\x18\x04 \x01(\x08R\x0cisContinuous\"\xff\x01\n\x0bNewTemporal\x12:\n\x0bserving_ttl\x18\x10 \x01(\x0b\x32\x19.google.protobuf.DurationR\nservingTtl\x12K\n\x10\x64\x61ta_source_type\x18\x11 \x01(\x0e\x32!.tecton_proto.args.DataSourceTypeR\x0e\x64\x61taSourceType\x12J\n\x0f\x62\x61\x63kfill_config\x18\x12 \x01(\x0b\x32!.tecton_proto.args.BackfillConfigR\x0e\x62\x61\x63kfillConfig\x12\x1b\n\tis_custom\x18\x13 \x01(\x08R\x08isCustom\"\x9a\x01\n\x0c\x46\x65\x61tureTable\x12%\n\x0eonline_enabled\x18\x01 \x01(\x08R\ronlineEnabled\x12\'\n\x0foffline_enabled\x18\x02 \x01(\x08R\x0eofflineEnabled\x12:\n\x0bserving_ttl\x18\x03 \x01(\x0b\x32\x19.google.protobuf.DurationR\nservingTtl\"*\n\x13OnDemandFeatureView\x12\x13\n\x05no_op\x18\x01 \x01(\x08R\x04noOp\"\xa6\x01\n\x12\x46\x65\x61tureViewSchemas\x12<\n\x0bview_schema\x18\x01 \x01(\x0b\x32\x1b.tecton_proto.common.SchemaR\nviewSchema\x12R\n\x16materialization_schema\x18\x02 \x01(\x0b\x32\x1b.tecton_proto.common.SchemaR\x15materializationSchema\"1\n\x12OnlineServingIndex\x12\x1b\n\tjoin_keys\x18\x01 \x03(\tR\x08joinKeys\"\xbe\x02\n\x1eMaterializationStateTransition\x12\x38\n\ttimestamp\x18\x01 \x01(\x0b\x32\x1a.google.protobuf.TimestampR\ttimestamp\x12%\n\x0eonline_enabled\x18\x02 \x01(\x08R\ronlineEnabled\x12\'\n\x0foffline_enabled\x18\x03 \x01(\x08R\x0eofflineEnabled\x12R\n\x17\x66\x65\x61ture_start_timestamp\x18\x04 \x01(\x0b\x32\x1a.google.protobuf.TimestampR\x15\x66\x65\x61tureStartTimestamp\x12>\n\x1bmaterialization_workflow_id\x18\x05 \x01(\x05R\x19materializationWorkflowId\"\xb0\x06\n\x18NewMaterializationParams\x12\x46\n\x11schedule_interval\x18\x01 \x01(\x0b\x32\x19.google.protobuf.DurationR\x10scheduleInterval\x12\x43\n\x0fstart_timestamp\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.TimestampR\x0estartTimestamp\x12^\n\x1emax_batch_aggregation_interval\x18\x03 \x01(\x0b\x32\x19.google.protobuf.DurationR\x1bmaxBatchAggregationInterval\x12\x33\n\x16writes_to_online_store\x18\x04 \x01(\x08R\x13writesToOnlineStore\x12\x35\n\x17writes_to_offline_store\x18\x05 \x01(\x08R\x14writesToOfflineStore\x12^\n\x14offline_store_config\x18\x06 \x01(\x0b\x32,.tecton_proto.args.OfflineFeatureStoreConfigR\x12offlineStoreConfig\x12U\n\x15\x62\x61tch_materialization\x18\x07 \x01(\x0b\x32 .tecton_proto.args.ClusterConfigR\x14\x62\x61tchMaterialization\x12W\n\x16stream_materialization\x18\x08 \x01(\x0b\x32 .tecton_proto.args.ClusterConfigR\x15streamMaterialization\x12U\n\x19\x61llowed_upstream_lateness\x18\t \x01(\x0b\x32\x19.google.protobuf.DurationR\x17\x61llowedUpstreamLateness\x12T\n\x13online_store_params\x18\n \x01(\x0b\x32$.tecton_proto.data.OnlineStoreParamsR\x11onlineStoreParams\"\xc7\x01\n\x11OnlineStoreParams\x12%\n\x0euser_specified\x18\x01 \x01(\x08R\ruserSpecified\x12@\n\x06\x64ynamo\x18\x02 \x01(\x0b\x32&.tecton_proto.args.DynamoDbOnlineStoreH\x00R\x06\x64ynamo\x12;\n\x05redis\x18\x03 \x01(\x0b\x32#.tecton_proto.args.RedisOnlineStoreH\x00R\x05redisB\x0c\n\nstore_type\"\xe0\x01\n\x10MonitoringParams\x12%\n\x0euser_specified\x18\x01 \x01(\x08R\ruserSpecified\x12+\n\x11monitor_freshness\x18\x02 \x01(\x08R\x10monitorFreshness\x12W\n\x1a\x65xpected_feature_freshness\x18\x03 \x01(\x0b\x32\x19.google.protobuf.DurationR\x18\x65xpectedFeatureFreshness\x12\x1f\n\x0b\x61lert_email\x18\x04 \x01(\tR\nalertEmail\"\xf5\x02\n\x16\x46\x65\x61tureViewEnrichments\x12\x39\n\x08\x65ntities\x18\x01 \x03(\x0b\x32\x19.tecton_proto.data.EntityB\x02\x18\x01R\x08\x65ntities\x12Z\n\x14virtual_data_sources\x18\x02 \x03(\x0b\x32$.tecton_proto.data.VirtualDataSourceB\x02\x18\x01R\x12virtualDataSources\x12R\n\x0ftransformations\x18\x03 \x03(\x0b\x32$.tecton_proto.data.NewTransformationB\x02\x18\x01R\x0ftransformations\x12S\n\x12\x66p_materialization\x18\x04 \x01(\x0b\x32$.tecton_proto.data.FvMaterializationR\x11\x66pMaterialization\x12\x1b\n\x07web_url\x18\x05 \x01(\tB\x02\x18\x01R\x06webUrl\"?\n\rSnowflakeData\x12.\n\x13snowflake_view_name\x18\x01 \x01(\tR\x11snowflakeViewNameB\x13\n\x0f\x63om.tecton.dataP\x01'
  ,
  dependencies=[google_dot_protobuf_dot_duration__pb2.DESCRIPTOR,google_dot_protobuf_dot_timestamp__pb2.DESCRIPTOR,tecton__proto_dot_args_dot_pipeline__pb2.DESCRIPTOR,tecton__proto_dot_args_dot_virtual__data__source__pb2.DESCRIPTOR,tecton__proto_dot_args_dot_feature__view__pb2.DESCRIPTOR,tecton__proto_dot_data_dot_entity__pb2.DESCRIPTOR,tecton__proto_dot_common_dot_aggregation__function__pb2.DESCRIPTOR,tecton__proto_dot_data_dot_virtual__data__source__pb2.DESCRIPTOR,tecton__proto_dot_data_dot_fv__materialization__pb2.DESCRIPTOR,tecton__proto_dot_common_dot_schema__pb2.DESCRIPTOR,tecton__proto_dot_data_dot_new__transformation__pb2.DESCRIPTOR,tecton__proto_dot_data_dot_fco__metadata__pb2.DESCRIPTOR,tecton__proto_dot_common_dot_id__pb2.DESCRIPTOR,])




_FEATUREVIEW = _descriptor.Descriptor(
  name='FeatureView',
  full_name='tecton_proto.data.FeatureView',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='feature_view_id', full_name='tecton_proto.data.FeatureView.feature_view_id', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='featureViewId', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='fco_metadata', full_name='tecton_proto.data.FeatureView.fco_metadata', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='fcoMetadata', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='entity_ids', full_name='tecton_proto.data.FeatureView.entity_ids', index=2,
      number=3, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='entityIds', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='join_keys', full_name='tecton_proto.data.FeatureView.join_keys', index=3,
      number=4, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='joinKeys', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='schemas', full_name='tecton_proto.data.FeatureView.schemas', index=4,
      number=11, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='schemas', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='enrichments', full_name='tecton_proto.data.FeatureView.enrichments', index=5,
      number=1000, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\030\001', json_name='enrichments', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='temporal_aggregate', full_name='tecton_proto.data.FeatureView.temporal_aggregate', index=6,
      number=7, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='temporalAggregate', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='temporal', full_name='tecton_proto.data.FeatureView.temporal', index=7,
      number=8, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='temporal', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='on_demand_feature_view', full_name='tecton_proto.data.FeatureView.on_demand_feature_view', index=8,
      number=17, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='onDemandFeatureView', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='feature_table', full_name='tecton_proto.data.FeatureView.feature_table', index=9,
      number=16, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='featureTable', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='timestamp_key', full_name='tecton_proto.data.FeatureView.timestamp_key', index=10,
      number=10, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='timestampKey', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='online_serving_index', full_name='tecton_proto.data.FeatureView.online_serving_index', index=11,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='onlineServingIndex', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='pipeline', full_name='tecton_proto.data.FeatureView.pipeline', index=12,
      number=6, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='pipeline', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='materialization_params', full_name='tecton_proto.data.FeatureView.materialization_params', index=13,
      number=9, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='materializationParams', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='materialization_enabled', full_name='tecton_proto.data.FeatureView.materialization_enabled', index=14,
      number=12, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='materializationEnabled', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='materialization_state_transitions', full_name='tecton_proto.data.FeatureView.materialization_state_transitions', index=15,
      number=13, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='materializationStateTransitions', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='monitoring_params', full_name='tecton_proto.data.FeatureView.monitoring_params', index=16,
      number=14, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='monitoringParams', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='feature_store_format_version', full_name='tecton_proto.data.FeatureView.feature_store_format_version', index=17,
      number=23, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='featureStoreFormatVersion', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='snowflake_data', full_name='tecton_proto.data.FeatureView.snowflake_data', index=18,
      number=24, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='snowflakeData', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='framework_version', full_name='tecton_proto.data.FeatureView.framework_version', index=19,
      number=19, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='frameworkVersion', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='web_url', full_name='tecton_proto.data.FeatureView.web_url', index=20,
      number=25, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='webUrl', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='feature_view_type', full_name='tecton_proto.data.FeatureView.feature_view_type',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=557,
  serialized_end=2031,
)


_NEWTEMPORALAGGREGATE = _descriptor.Descriptor(
  name='NewTemporalAggregate',
  full_name='tecton_proto.data.NewTemporalAggregate',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='slide_interval', full_name='tecton_proto.data.NewTemporalAggregate.slide_interval', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='slideInterval', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='slide_interval_string', full_name='tecton_proto.data.NewTemporalAggregate.slide_interval_string', index=1,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='slideIntervalString', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='features', full_name='tecton_proto.data.NewTemporalAggregate.features', index=2,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='features', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='is_continuous', full_name='tecton_proto.data.NewTemporalAggregate.is_continuous', index=3,
      number=3, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='isContinuous', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='data_source_type', full_name='tecton_proto.data.NewTemporalAggregate.data_source_type', index=4,
      number=4, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='dataSourceType', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2034,
  serialized_end=2353,
)


_AGGREGATEFEATURE = _descriptor.Descriptor(
  name='AggregateFeature',
  full_name='tecton_proto.data.AggregateFeature',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='input_feature_name', full_name='tecton_proto.data.AggregateFeature.input_feature_name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='inputFeatureName', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='output_feature_name', full_name='tecton_proto.data.AggregateFeature.output_feature_name', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='outputFeatureName', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='function', full_name='tecton_proto.data.AggregateFeature.function', index=2,
      number=3, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='function', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='function_params', full_name='tecton_proto.data.AggregateFeature.function_params', index=3,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='functionParams', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='window', full_name='tecton_proto.data.AggregateFeature.window', index=4,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='window', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2356,
  serialized_end=2678,
)


_TRAILINGTIMEWINDOWAGGREGATION = _descriptor.Descriptor(
  name='TrailingTimeWindowAggregation',
  full_name='tecton_proto.data.TrailingTimeWindowAggregation',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='time_key', full_name='tecton_proto.data.TrailingTimeWindowAggregation.time_key', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='timeKey', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='aggregation_slide_period', full_name='tecton_proto.data.TrailingTimeWindowAggregation.aggregation_slide_period', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='aggregationSlidePeriod', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='features', full_name='tecton_proto.data.TrailingTimeWindowAggregation.features', index=2,
      number=3, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='features', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='is_continuous', full_name='tecton_proto.data.TrailingTimeWindowAggregation.is_continuous', index=3,
      number=4, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='isContinuous', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2681,
  serialized_end=2926,
)


_NEWTEMPORAL = _descriptor.Descriptor(
  name='NewTemporal',
  full_name='tecton_proto.data.NewTemporal',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='serving_ttl', full_name='tecton_proto.data.NewTemporal.serving_ttl', index=0,
      number=16, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='servingTtl', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='data_source_type', full_name='tecton_proto.data.NewTemporal.data_source_type', index=1,
      number=17, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='dataSourceType', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='backfill_config', full_name='tecton_proto.data.NewTemporal.backfill_config', index=2,
      number=18, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='backfillConfig', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='is_custom', full_name='tecton_proto.data.NewTemporal.is_custom', index=3,
      number=19, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='isCustom', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2929,
  serialized_end=3184,
)


_FEATURETABLE = _descriptor.Descriptor(
  name='FeatureTable',
  full_name='tecton_proto.data.FeatureTable',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='online_enabled', full_name='tecton_proto.data.FeatureTable.online_enabled', index=0,
      number=1, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='onlineEnabled', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='offline_enabled', full_name='tecton_proto.data.FeatureTable.offline_enabled', index=1,
      number=2, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='offlineEnabled', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='serving_ttl', full_name='tecton_proto.data.FeatureTable.serving_ttl', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='servingTtl', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3187,
  serialized_end=3341,
)


_ONDEMANDFEATUREVIEW = _descriptor.Descriptor(
  name='OnDemandFeatureView',
  full_name='tecton_proto.data.OnDemandFeatureView',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='no_op', full_name='tecton_proto.data.OnDemandFeatureView.no_op', index=0,
      number=1, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='noOp', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3343,
  serialized_end=3385,
)


_FEATUREVIEWSCHEMAS = _descriptor.Descriptor(
  name='FeatureViewSchemas',
  full_name='tecton_proto.data.FeatureViewSchemas',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='view_schema', full_name='tecton_proto.data.FeatureViewSchemas.view_schema', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='viewSchema', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='materialization_schema', full_name='tecton_proto.data.FeatureViewSchemas.materialization_schema', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='materializationSchema', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3388,
  serialized_end=3554,
)


_ONLINESERVINGINDEX = _descriptor.Descriptor(
  name='OnlineServingIndex',
  full_name='tecton_proto.data.OnlineServingIndex',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='join_keys', full_name='tecton_proto.data.OnlineServingIndex.join_keys', index=0,
      number=1, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='joinKeys', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3556,
  serialized_end=3605,
)


_MATERIALIZATIONSTATETRANSITION = _descriptor.Descriptor(
  name='MaterializationStateTransition',
  full_name='tecton_proto.data.MaterializationStateTransition',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='timestamp', full_name='tecton_proto.data.MaterializationStateTransition.timestamp', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='timestamp', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='online_enabled', full_name='tecton_proto.data.MaterializationStateTransition.online_enabled', index=1,
      number=2, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='onlineEnabled', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='offline_enabled', full_name='tecton_proto.data.MaterializationStateTransition.offline_enabled', index=2,
      number=3, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='offlineEnabled', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='feature_start_timestamp', full_name='tecton_proto.data.MaterializationStateTransition.feature_start_timestamp', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='featureStartTimestamp', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='materialization_workflow_id', full_name='tecton_proto.data.MaterializationStateTransition.materialization_workflow_id', index=4,
      number=5, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='materializationWorkflowId', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3608,
  serialized_end=3926,
)


_NEWMATERIALIZATIONPARAMS = _descriptor.Descriptor(
  name='NewMaterializationParams',
  full_name='tecton_proto.data.NewMaterializationParams',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='schedule_interval', full_name='tecton_proto.data.NewMaterializationParams.schedule_interval', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='scheduleInterval', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='start_timestamp', full_name='tecton_proto.data.NewMaterializationParams.start_timestamp', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='startTimestamp', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='max_batch_aggregation_interval', full_name='tecton_proto.data.NewMaterializationParams.max_batch_aggregation_interval', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='maxBatchAggregationInterval', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='writes_to_online_store', full_name='tecton_proto.data.NewMaterializationParams.writes_to_online_store', index=3,
      number=4, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='writesToOnlineStore', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='writes_to_offline_store', full_name='tecton_proto.data.NewMaterializationParams.writes_to_offline_store', index=4,
      number=5, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='writesToOfflineStore', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='offline_store_config', full_name='tecton_proto.data.NewMaterializationParams.offline_store_config', index=5,
      number=6, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='offlineStoreConfig', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='batch_materialization', full_name='tecton_proto.data.NewMaterializationParams.batch_materialization', index=6,
      number=7, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='batchMaterialization', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='stream_materialization', full_name='tecton_proto.data.NewMaterializationParams.stream_materialization', index=7,
      number=8, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='streamMaterialization', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='allowed_upstream_lateness', full_name='tecton_proto.data.NewMaterializationParams.allowed_upstream_lateness', index=8,
      number=9, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='allowedUpstreamLateness', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='online_store_params', full_name='tecton_proto.data.NewMaterializationParams.online_store_params', index=9,
      number=10, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='onlineStoreParams', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3929,
  serialized_end=4745,
)


_ONLINESTOREPARAMS = _descriptor.Descriptor(
  name='OnlineStoreParams',
  full_name='tecton_proto.data.OnlineStoreParams',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='user_specified', full_name='tecton_proto.data.OnlineStoreParams.user_specified', index=0,
      number=1, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='userSpecified', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='dynamo', full_name='tecton_proto.data.OnlineStoreParams.dynamo', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='dynamo', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='redis', full_name='tecton_proto.data.OnlineStoreParams.redis', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='redis', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='store_type', full_name='tecton_proto.data.OnlineStoreParams.store_type',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=4748,
  serialized_end=4947,
)


_MONITORINGPARAMS = _descriptor.Descriptor(
  name='MonitoringParams',
  full_name='tecton_proto.data.MonitoringParams',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='user_specified', full_name='tecton_proto.data.MonitoringParams.user_specified', index=0,
      number=1, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='userSpecified', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='monitor_freshness', full_name='tecton_proto.data.MonitoringParams.monitor_freshness', index=1,
      number=2, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='monitorFreshness', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='expected_feature_freshness', full_name='tecton_proto.data.MonitoringParams.expected_feature_freshness', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='expectedFeatureFreshness', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='alert_email', full_name='tecton_proto.data.MonitoringParams.alert_email', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='alertEmail', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4950,
  serialized_end=5174,
)


_FEATUREVIEWENRICHMENTS = _descriptor.Descriptor(
  name='FeatureViewEnrichments',
  full_name='tecton_proto.data.FeatureViewEnrichments',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='entities', full_name='tecton_proto.data.FeatureViewEnrichments.entities', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\030\001', json_name='entities', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='virtual_data_sources', full_name='tecton_proto.data.FeatureViewEnrichments.virtual_data_sources', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\030\001', json_name='virtualDataSources', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='transformations', full_name='tecton_proto.data.FeatureViewEnrichments.transformations', index=2,
      number=3, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\030\001', json_name='transformations', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='fp_materialization', full_name='tecton_proto.data.FeatureViewEnrichments.fp_materialization', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='fpMaterialization', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='web_url', full_name='tecton_proto.data.FeatureViewEnrichments.web_url', index=4,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\030\001', json_name='webUrl', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=5177,
  serialized_end=5550,
)


_SNOWFLAKEDATA = _descriptor.Descriptor(
  name='SnowflakeData',
  full_name='tecton_proto.data.SnowflakeData',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='snowflake_view_name', full_name='tecton_proto.data.SnowflakeData.snowflake_view_name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='snowflakeViewName', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=5552,
  serialized_end=5615,
)

_FEATUREVIEW.fields_by_name['feature_view_id'].message_type = tecton__proto_dot_common_dot_id__pb2._ID
_FEATUREVIEW.fields_by_name['fco_metadata'].message_type = tecton__proto_dot_data_dot_fco__metadata__pb2._FCOMETADATA
_FEATUREVIEW.fields_by_name['entity_ids'].message_type = tecton__proto_dot_common_dot_id__pb2._ID
_FEATUREVIEW.fields_by_name['schemas'].message_type = _FEATUREVIEWSCHEMAS
_FEATUREVIEW.fields_by_name['enrichments'].message_type = _FEATUREVIEWENRICHMENTS
_FEATUREVIEW.fields_by_name['temporal_aggregate'].message_type = _NEWTEMPORALAGGREGATE
_FEATUREVIEW.fields_by_name['temporal'].message_type = _NEWTEMPORAL
_FEATUREVIEW.fields_by_name['on_demand_feature_view'].message_type = _ONDEMANDFEATUREVIEW
_FEATUREVIEW.fields_by_name['feature_table'].message_type = _FEATURETABLE
_FEATUREVIEW.fields_by_name['online_serving_index'].message_type = _ONLINESERVINGINDEX
_FEATUREVIEW.fields_by_name['pipeline'].message_type = tecton__proto_dot_args_dot_pipeline__pb2._PIPELINE
_FEATUREVIEW.fields_by_name['materialization_params'].message_type = _NEWMATERIALIZATIONPARAMS
_FEATUREVIEW.fields_by_name['materialization_state_transitions'].message_type = _MATERIALIZATIONSTATETRANSITION
_FEATUREVIEW.fields_by_name['monitoring_params'].message_type = _MONITORINGPARAMS
_FEATUREVIEW.fields_by_name['snowflake_data'].message_type = _SNOWFLAKEDATA
_FEATUREVIEW.oneofs_by_name['feature_view_type'].fields.append(
  _FEATUREVIEW.fields_by_name['temporal_aggregate'])
_FEATUREVIEW.fields_by_name['temporal_aggregate'].containing_oneof = _FEATUREVIEW.oneofs_by_name['feature_view_type']
_FEATUREVIEW.oneofs_by_name['feature_view_type'].fields.append(
  _FEATUREVIEW.fields_by_name['temporal'])
_FEATUREVIEW.fields_by_name['temporal'].containing_oneof = _FEATUREVIEW.oneofs_by_name['feature_view_type']
_FEATUREVIEW.oneofs_by_name['feature_view_type'].fields.append(
  _FEATUREVIEW.fields_by_name['on_demand_feature_view'])
_FEATUREVIEW.fields_by_name['on_demand_feature_view'].containing_oneof = _FEATUREVIEW.oneofs_by_name['feature_view_type']
_FEATUREVIEW.oneofs_by_name['feature_view_type'].fields.append(
  _FEATUREVIEW.fields_by_name['feature_table'])
_FEATUREVIEW.fields_by_name['feature_table'].containing_oneof = _FEATUREVIEW.oneofs_by_name['feature_view_type']
_NEWTEMPORALAGGREGATE.fields_by_name['slide_interval'].message_type = google_dot_protobuf_dot_duration__pb2._DURATION
_NEWTEMPORALAGGREGATE.fields_by_name['features'].message_type = _AGGREGATEFEATURE
_NEWTEMPORALAGGREGATE.fields_by_name['data_source_type'].enum_type = tecton__proto_dot_args_dot_virtual__data__source__pb2._DATASOURCETYPE
_AGGREGATEFEATURE.fields_by_name['function'].enum_type = tecton__proto_dot_common_dot_aggregation__function__pb2._AGGREGATIONFUNCTION
_AGGREGATEFEATURE.fields_by_name['function_params'].message_type = tecton__proto_dot_common_dot_aggregation__function__pb2._AGGREGATIONFUNCTIONPARAMS
_AGGREGATEFEATURE.fields_by_name['window'].message_type = google_dot_protobuf_dot_duration__pb2._DURATION
_TRAILINGTIMEWINDOWAGGREGATION.fields_by_name['aggregation_slide_period'].message_type = google_dot_protobuf_dot_duration__pb2._DURATION
_TRAILINGTIMEWINDOWAGGREGATION.fields_by_name['features'].message_type = _AGGREGATEFEATURE
_NEWTEMPORAL.fields_by_name['serving_ttl'].message_type = google_dot_protobuf_dot_duration__pb2._DURATION
_NEWTEMPORAL.fields_by_name['data_source_type'].enum_type = tecton__proto_dot_args_dot_virtual__data__source__pb2._DATASOURCETYPE
_NEWTEMPORAL.fields_by_name['backfill_config'].message_type = tecton__proto_dot_args_dot_feature__view__pb2._BACKFILLCONFIG
_FEATURETABLE.fields_by_name['serving_ttl'].message_type = google_dot_protobuf_dot_duration__pb2._DURATION
_FEATUREVIEWSCHEMAS.fields_by_name['view_schema'].message_type = tecton__proto_dot_common_dot_schema__pb2._SCHEMA
_FEATUREVIEWSCHEMAS.fields_by_name['materialization_schema'].message_type = tecton__proto_dot_common_dot_schema__pb2._SCHEMA
_MATERIALIZATIONSTATETRANSITION.fields_by_name['timestamp'].message_type = google_dot_protobuf_dot_timestamp__pb2._TIMESTAMP
_MATERIALIZATIONSTATETRANSITION.fields_by_name['feature_start_timestamp'].message_type = google_dot_protobuf_dot_timestamp__pb2._TIMESTAMP
_NEWMATERIALIZATIONPARAMS.fields_by_name['schedule_interval'].message_type = google_dot_protobuf_dot_duration__pb2._DURATION
_NEWMATERIALIZATIONPARAMS.fields_by_name['start_timestamp'].message_type = google_dot_protobuf_dot_timestamp__pb2._TIMESTAMP
_NEWMATERIALIZATIONPARAMS.fields_by_name['max_batch_aggregation_interval'].message_type = google_dot_protobuf_dot_duration__pb2._DURATION
_NEWMATERIALIZATIONPARAMS.fields_by_name['offline_store_config'].message_type = tecton__proto_dot_args_dot_feature__view__pb2._OFFLINEFEATURESTORECONFIG
_NEWMATERIALIZATIONPARAMS.fields_by_name['batch_materialization'].message_type = tecton__proto_dot_args_dot_feature__view__pb2._CLUSTERCONFIG
_NEWMATERIALIZATIONPARAMS.fields_by_name['stream_materialization'].message_type = tecton__proto_dot_args_dot_feature__view__pb2._CLUSTERCONFIG
_NEWMATERIALIZATIONPARAMS.fields_by_name['allowed_upstream_lateness'].message_type = google_dot_protobuf_dot_duration__pb2._DURATION
_NEWMATERIALIZATIONPARAMS.fields_by_name['online_store_params'].message_type = _ONLINESTOREPARAMS
_ONLINESTOREPARAMS.fields_by_name['dynamo'].message_type = tecton__proto_dot_args_dot_feature__view__pb2._DYNAMODBONLINESTORE
_ONLINESTOREPARAMS.fields_by_name['redis'].message_type = tecton__proto_dot_args_dot_feature__view__pb2._REDISONLINESTORE
_ONLINESTOREPARAMS.oneofs_by_name['store_type'].fields.append(
  _ONLINESTOREPARAMS.fields_by_name['dynamo'])
_ONLINESTOREPARAMS.fields_by_name['dynamo'].containing_oneof = _ONLINESTOREPARAMS.oneofs_by_name['store_type']
_ONLINESTOREPARAMS.oneofs_by_name['store_type'].fields.append(
  _ONLINESTOREPARAMS.fields_by_name['redis'])
_ONLINESTOREPARAMS.fields_by_name['redis'].containing_oneof = _ONLINESTOREPARAMS.oneofs_by_name['store_type']
_MONITORINGPARAMS.fields_by_name['expected_feature_freshness'].message_type = google_dot_protobuf_dot_duration__pb2._DURATION
_FEATUREVIEWENRICHMENTS.fields_by_name['entities'].message_type = tecton__proto_dot_data_dot_entity__pb2._ENTITY
_FEATUREVIEWENRICHMENTS.fields_by_name['virtual_data_sources'].message_type = tecton__proto_dot_data_dot_virtual__data__source__pb2._VIRTUALDATASOURCE
_FEATUREVIEWENRICHMENTS.fields_by_name['transformations'].message_type = tecton__proto_dot_data_dot_new__transformation__pb2._NEWTRANSFORMATION
_FEATUREVIEWENRICHMENTS.fields_by_name['fp_materialization'].message_type = tecton__proto_dot_data_dot_fv__materialization__pb2._FVMATERIALIZATION
DESCRIPTOR.message_types_by_name['FeatureView'] = _FEATUREVIEW
DESCRIPTOR.message_types_by_name['NewTemporalAggregate'] = _NEWTEMPORALAGGREGATE
DESCRIPTOR.message_types_by_name['AggregateFeature'] = _AGGREGATEFEATURE
DESCRIPTOR.message_types_by_name['TrailingTimeWindowAggregation'] = _TRAILINGTIMEWINDOWAGGREGATION
DESCRIPTOR.message_types_by_name['NewTemporal'] = _NEWTEMPORAL
DESCRIPTOR.message_types_by_name['FeatureTable'] = _FEATURETABLE
DESCRIPTOR.message_types_by_name['OnDemandFeatureView'] = _ONDEMANDFEATUREVIEW
DESCRIPTOR.message_types_by_name['FeatureViewSchemas'] = _FEATUREVIEWSCHEMAS
DESCRIPTOR.message_types_by_name['OnlineServingIndex'] = _ONLINESERVINGINDEX
DESCRIPTOR.message_types_by_name['MaterializationStateTransition'] = _MATERIALIZATIONSTATETRANSITION
DESCRIPTOR.message_types_by_name['NewMaterializationParams'] = _NEWMATERIALIZATIONPARAMS
DESCRIPTOR.message_types_by_name['OnlineStoreParams'] = _ONLINESTOREPARAMS
DESCRIPTOR.message_types_by_name['MonitoringParams'] = _MONITORINGPARAMS
DESCRIPTOR.message_types_by_name['FeatureViewEnrichments'] = _FEATUREVIEWENRICHMENTS
DESCRIPTOR.message_types_by_name['SnowflakeData'] = _SNOWFLAKEDATA
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

FeatureView = _reflection.GeneratedProtocolMessageType('FeatureView', (_message.Message,), {
  'DESCRIPTOR' : _FEATUREVIEW,
  '__module__' : 'tecton_proto.data.feature_view_pb2'
  # @@protoc_insertion_point(class_scope:tecton_proto.data.FeatureView)
  })
_sym_db.RegisterMessage(FeatureView)

NewTemporalAggregate = _reflection.GeneratedProtocolMessageType('NewTemporalAggregate', (_message.Message,), {
  'DESCRIPTOR' : _NEWTEMPORALAGGREGATE,
  '__module__' : 'tecton_proto.data.feature_view_pb2'
  # @@protoc_insertion_point(class_scope:tecton_proto.data.NewTemporalAggregate)
  })
_sym_db.RegisterMessage(NewTemporalAggregate)

AggregateFeature = _reflection.GeneratedProtocolMessageType('AggregateFeature', (_message.Message,), {
  'DESCRIPTOR' : _AGGREGATEFEATURE,
  '__module__' : 'tecton_proto.data.feature_view_pb2'
  # @@protoc_insertion_point(class_scope:tecton_proto.data.AggregateFeature)
  })
_sym_db.RegisterMessage(AggregateFeature)

TrailingTimeWindowAggregation = _reflection.GeneratedProtocolMessageType('TrailingTimeWindowAggregation', (_message.Message,), {
  'DESCRIPTOR' : _TRAILINGTIMEWINDOWAGGREGATION,
  '__module__' : 'tecton_proto.data.feature_view_pb2'
  # @@protoc_insertion_point(class_scope:tecton_proto.data.TrailingTimeWindowAggregation)
  })
_sym_db.RegisterMessage(TrailingTimeWindowAggregation)

NewTemporal = _reflection.GeneratedProtocolMessageType('NewTemporal', (_message.Message,), {
  'DESCRIPTOR' : _NEWTEMPORAL,
  '__module__' : 'tecton_proto.data.feature_view_pb2'
  # @@protoc_insertion_point(class_scope:tecton_proto.data.NewTemporal)
  })
_sym_db.RegisterMessage(NewTemporal)

FeatureTable = _reflection.GeneratedProtocolMessageType('FeatureTable', (_message.Message,), {
  'DESCRIPTOR' : _FEATURETABLE,
  '__module__' : 'tecton_proto.data.feature_view_pb2'
  # @@protoc_insertion_point(class_scope:tecton_proto.data.FeatureTable)
  })
_sym_db.RegisterMessage(FeatureTable)

OnDemandFeatureView = _reflection.GeneratedProtocolMessageType('OnDemandFeatureView', (_message.Message,), {
  'DESCRIPTOR' : _ONDEMANDFEATUREVIEW,
  '__module__' : 'tecton_proto.data.feature_view_pb2'
  # @@protoc_insertion_point(class_scope:tecton_proto.data.OnDemandFeatureView)
  })
_sym_db.RegisterMessage(OnDemandFeatureView)

FeatureViewSchemas = _reflection.GeneratedProtocolMessageType('FeatureViewSchemas', (_message.Message,), {
  'DESCRIPTOR' : _FEATUREVIEWSCHEMAS,
  '__module__' : 'tecton_proto.data.feature_view_pb2'
  # @@protoc_insertion_point(class_scope:tecton_proto.data.FeatureViewSchemas)
  })
_sym_db.RegisterMessage(FeatureViewSchemas)

OnlineServingIndex = _reflection.GeneratedProtocolMessageType('OnlineServingIndex', (_message.Message,), {
  'DESCRIPTOR' : _ONLINESERVINGINDEX,
  '__module__' : 'tecton_proto.data.feature_view_pb2'
  # @@protoc_insertion_point(class_scope:tecton_proto.data.OnlineServingIndex)
  })
_sym_db.RegisterMessage(OnlineServingIndex)

MaterializationStateTransition = _reflection.GeneratedProtocolMessageType('MaterializationStateTransition', (_message.Message,), {
  'DESCRIPTOR' : _MATERIALIZATIONSTATETRANSITION,
  '__module__' : 'tecton_proto.data.feature_view_pb2'
  # @@protoc_insertion_point(class_scope:tecton_proto.data.MaterializationStateTransition)
  })
_sym_db.RegisterMessage(MaterializationStateTransition)

NewMaterializationParams = _reflection.GeneratedProtocolMessageType('NewMaterializationParams', (_message.Message,), {
  'DESCRIPTOR' : _NEWMATERIALIZATIONPARAMS,
  '__module__' : 'tecton_proto.data.feature_view_pb2'
  # @@protoc_insertion_point(class_scope:tecton_proto.data.NewMaterializationParams)
  })
_sym_db.RegisterMessage(NewMaterializationParams)

OnlineStoreParams = _reflection.GeneratedProtocolMessageType('OnlineStoreParams', (_message.Message,), {
  'DESCRIPTOR' : _ONLINESTOREPARAMS,
  '__module__' : 'tecton_proto.data.feature_view_pb2'
  # @@protoc_insertion_point(class_scope:tecton_proto.data.OnlineStoreParams)
  })
_sym_db.RegisterMessage(OnlineStoreParams)

MonitoringParams = _reflection.GeneratedProtocolMessageType('MonitoringParams', (_message.Message,), {
  'DESCRIPTOR' : _MONITORINGPARAMS,
  '__module__' : 'tecton_proto.data.feature_view_pb2'
  # @@protoc_insertion_point(class_scope:tecton_proto.data.MonitoringParams)
  })
_sym_db.RegisterMessage(MonitoringParams)

FeatureViewEnrichments = _reflection.GeneratedProtocolMessageType('FeatureViewEnrichments', (_message.Message,), {
  'DESCRIPTOR' : _FEATUREVIEWENRICHMENTS,
  '__module__' : 'tecton_proto.data.feature_view_pb2'
  # @@protoc_insertion_point(class_scope:tecton_proto.data.FeatureViewEnrichments)
  })
_sym_db.RegisterMessage(FeatureViewEnrichments)

SnowflakeData = _reflection.GeneratedProtocolMessageType('SnowflakeData', (_message.Message,), {
  'DESCRIPTOR' : _SNOWFLAKEDATA,
  '__module__' : 'tecton_proto.data.feature_view_pb2'
  # @@protoc_insertion_point(class_scope:tecton_proto.data.SnowflakeData)
  })
_sym_db.RegisterMessage(SnowflakeData)


DESCRIPTOR._options = None
_FEATUREVIEW.fields_by_name['enrichments']._options = None
_FEATUREVIEWENRICHMENTS.fields_by_name['entities']._options = None
_FEATUREVIEWENRICHMENTS.fields_by_name['virtual_data_sources']._options = None
_FEATUREVIEWENRICHMENTS.fields_by_name['transformations']._options = None
_FEATUREVIEWENRICHMENTS.fields_by_name['web_url']._options = None
# @@protoc_insertion_point(module_scope)
