# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: tecton_proto/common/aggregation_function.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor.FileDescriptor(
  name='tecton_proto/common/aggregation_function.proto',
  package='tecton_proto.common',
  syntax='proto2',
  serialized_options=b'\n\021com.tecton.commonP\001Z(github.com/tecton-ai/tecton_proto/common',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n.tecton_proto/common/aggregation_function.proto\x12\x13tecton_proto.common\"\x1b\n\x0bLastNParams\x12\x0c\n\x01n\x18\x01 \x01(\x05R\x01n\"`\n\x19\x41ggregationFunctionParams\x12\x39\n\x06last_n\x18\x01 \x01(\x0b\x32 .tecton_proto.common.LastNParamsH\x00R\x05lastNB\x08\n\x06params*\x9b\x02\n\x13\x41ggregationFunction\x12 \n\x1c\x41GGREGATION_FUNCTION_UNKNOWN\x10\x00\x12\x1e\n\x1a\x41GGREGATION_FUNCTION_COUNT\x10\x01\x12\x1c\n\x18\x41GGREGATION_FUNCTION_SUM\x10\x02\x12\x1d\n\x19\x41GGREGATION_FUNCTION_MEAN\x10\x03\x12\x1d\n\x19\x41GGREGATION_FUNCTION_LAST\x10\x05\x12\x1c\n\x18\x41GGREGATION_FUNCTION_MIN\x10\x06\x12\x1c\n\x18\x41GGREGATION_FUNCTION_MAX\x10\x07\x12\x1e\n\x1a\x41GGREGATION_FUNCTION_LASTN\x10\t\"\x04\x08\x04\x10\x04\"\x04\x08\x08\x10\x08\x42?\n\x11\x63om.tecton.commonP\x01Z(github.com/tecton-ai/tecton_proto/common'
)

_AGGREGATIONFUNCTION = _descriptor.EnumDescriptor(
  name='AggregationFunction',
  full_name='tecton_proto.common.AggregationFunction',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='AGGREGATION_FUNCTION_UNKNOWN', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='AGGREGATION_FUNCTION_COUNT', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='AGGREGATION_FUNCTION_SUM', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='AGGREGATION_FUNCTION_MEAN', index=3, number=3,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='AGGREGATION_FUNCTION_LAST', index=4, number=5,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='AGGREGATION_FUNCTION_MIN', index=5, number=6,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='AGGREGATION_FUNCTION_MAX', index=6, number=7,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='AGGREGATION_FUNCTION_LASTN', index=7, number=9,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=199,
  serialized_end=482,
)
_sym_db.RegisterEnumDescriptor(_AGGREGATIONFUNCTION)

AggregationFunction = enum_type_wrapper.EnumTypeWrapper(_AGGREGATIONFUNCTION)
AGGREGATION_FUNCTION_UNKNOWN = 0
AGGREGATION_FUNCTION_COUNT = 1
AGGREGATION_FUNCTION_SUM = 2
AGGREGATION_FUNCTION_MEAN = 3
AGGREGATION_FUNCTION_LAST = 5
AGGREGATION_FUNCTION_MIN = 6
AGGREGATION_FUNCTION_MAX = 7
AGGREGATION_FUNCTION_LASTN = 9



_LASTNPARAMS = _descriptor.Descriptor(
  name='LastNParams',
  full_name='tecton_proto.common.LastNParams',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='n', full_name='tecton_proto.common.LastNParams.n', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='n', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=71,
  serialized_end=98,
)


_AGGREGATIONFUNCTIONPARAMS = _descriptor.Descriptor(
  name='AggregationFunctionParams',
  full_name='tecton_proto.common.AggregationFunctionParams',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='last_n', full_name='tecton_proto.common.AggregationFunctionParams.last_n', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='lastN', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='params', full_name='tecton_proto.common.AggregationFunctionParams.params',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=100,
  serialized_end=196,
)

_AGGREGATIONFUNCTIONPARAMS.fields_by_name['last_n'].message_type = _LASTNPARAMS
_AGGREGATIONFUNCTIONPARAMS.oneofs_by_name['params'].fields.append(
  _AGGREGATIONFUNCTIONPARAMS.fields_by_name['last_n'])
_AGGREGATIONFUNCTIONPARAMS.fields_by_name['last_n'].containing_oneof = _AGGREGATIONFUNCTIONPARAMS.oneofs_by_name['params']
DESCRIPTOR.message_types_by_name['LastNParams'] = _LASTNPARAMS
DESCRIPTOR.message_types_by_name['AggregationFunctionParams'] = _AGGREGATIONFUNCTIONPARAMS
DESCRIPTOR.enum_types_by_name['AggregationFunction'] = _AGGREGATIONFUNCTION
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

LastNParams = _reflection.GeneratedProtocolMessageType('LastNParams', (_message.Message,), {
  'DESCRIPTOR' : _LASTNPARAMS,
  '__module__' : 'tecton_proto.common.aggregation_function_pb2'
  # @@protoc_insertion_point(class_scope:tecton_proto.common.LastNParams)
  })
_sym_db.RegisterMessage(LastNParams)

AggregationFunctionParams = _reflection.GeneratedProtocolMessageType('AggregationFunctionParams', (_message.Message,), {
  'DESCRIPTOR' : _AGGREGATIONFUNCTIONPARAMS,
  '__module__' : 'tecton_proto.common.aggregation_function_pb2'
  # @@protoc_insertion_point(class_scope:tecton_proto.common.AggregationFunctionParams)
  })
_sym_db.RegisterMessage(AggregationFunctionParams)


DESCRIPTOR._options = None
# @@protoc_insertion_point(module_scope)
