# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: tecton_proto/api/featureservice/feature_service_request.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import struct_pb2 as google_dot_protobuf_dot_struct__pb2
from protoc_gen_swagger.options import annotations_pb2 as protoc__gen__swagger_dot_options_dot_annotations__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='tecton_proto/api/featureservice/feature_service_request.proto',
  package='tecton_proto.api.feature_service',
  syntax='proto2',
  serialized_options=b'Z4github.com/tecton-ai/tecton_proto/api/featureservice',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n=tecton_proto/api/featureservice/feature_service_request.proto\x12 tecton_proto.api.feature_service\x1a\x1cgoogle/protobuf/struct.proto\x1a,protoc-gen-swagger/options/annotations.proto\"\xef\x01\n\x0fMetadataOptions\x12#\n\rinclude_names\x18\x01 \x01(\x08R\x0cincludeNames\x12\x36\n\x17include_effective_times\x18\x02 \x01(\x08R\x15includeEffectiveTimes\x12\'\n\rinclude_types\x18\x03 \x01(\x08\x42\x02\x18\x01R\x0cincludeTypes\x12,\n\x12include_data_types\x18\x05 \x01(\x08R\x10includeDataTypes\x12(\n\x10include_slo_info\x18\x04 \x01(\x08R\x0eincludeSloInfo\"e\n\x12GetFeaturesRequest\x12O\n\x06params\x18\x01 \x01(\x0b\x32\x37.tecton_proto.api.feature_service.GetFeaturesParametersR\x06params\"o\n\x17GetFeaturesBatchRequest\x12T\n\x06params\x18\x01 \x01(\x0b\x32<.tecton_proto.api.feature_service.GetFeaturesBatchParametersR\x06params\"\xf5\x08\n\x15GetFeaturesParameters\x12.\n\x12\x66\x65\x61ture_service_id\x18\x01 \x01(\tH\x00R\x10\x66\x65\x61tureServiceId\x12\x32\n\x14\x66\x65\x61ture_service_name\x18\x02 \x01(\tH\x00R\x12\x66\x65\x61tureServiceName\x12.\n\x12\x66\x65\x61ture_package_id\x18\x0c \x01(\tH\x00R\x10\x66\x65\x61turePackageId\x12\x32\n\x14\x66\x65\x61ture_package_name\x18\r \x01(\tH\x00R\x12\x66\x65\x61turePackageName\x12(\n\x0f\x66\x65\x61ture_view_id\x18\x0f \x01(\tH\x00R\rfeatureViewId\x12,\n\x11\x66\x65\x61ture_view_name\x18\x10 \x01(\tH\x00R\x0f\x66\x65\x61tureViewName\x12%\n\x0eworkspace_name\x18\n \x01(\tR\rworkspaceName\x12i\n\x0cjoin_key_map\x18\x08 \x03(\x0b\x32G.tecton_proto.api.feature_service.GetFeaturesParameters.JoinKeyMapEntryR\njoinKeyMap\x12~\n\x13request_context_map\x18\t \x03(\x0b\x32N.tecton_proto.api.feature_service.GetFeaturesParameters.RequestContextMapEntryR\x11requestContextMap\x12\\\n\x10metadata_options\x18\x07 \x01(\x0b\x32\x31.tecton_proto.api.feature_service.MetadataOptionsR\x0fmetadataOptions\x12>\n\x15\x61llow_partial_results\x18\x0b \x01(\x08\x42\n\x92\x41\x07:\x05\x66\x61lseR\x13\x61llowPartialResults\x1aU\n\x0fJoinKeyMapEntry\x12\x10\n\x03key\x18\x01 \x01(\tR\x03key\x12,\n\x05value\x18\x02 \x01(\x0b\x32\x16.google.protobuf.ValueR\x05value:\x02\x38\x01\x1a\\\n\x16RequestContextMapEntry\x12\x10\n\x03key\x18\x01 \x01(\tR\x03key\x12,\n\x05value\x18\x02 \x01(\x0b\x32\x16.google.protobuf.ValueR\x05value:\x02\x38\x01:\xad\x01\x92\x41\xa9\x01\n\x17*\x15GetFeaturesParameters:\x8d\x01{\"feature_service_name\": \"ctr_prediction_service\", \"join_key_map\": { \"ad_id\": \"5417\", \"user_uuid\": \"6c423390-9a64-52c8-9bb3-bbb108c74198\" } }B\t\n\x07locatorJ\x04\x08\x03\x10\x04J\x04\x08\x04\x10\x05J\x04\x08\x05\x10\x06J\x04\x08\x06\x10\x07J\x04\x08\x0e\x10\x0f\"\x91\x06\n\x1aGetFeaturesBatchParameters\x12.\n\x12\x66\x65\x61ture_service_id\x18\x01 \x01(\tH\x00R\x10\x66\x65\x61tureServiceId\x12\x32\n\x14\x66\x65\x61ture_service_name\x18\x02 \x01(\tH\x00R\x12\x66\x65\x61tureServiceName\x12%\n\x0eworkspace_name\x18\x03 \x01(\tR\rworkspaceName\x12`\n\x0crequest_data\x18\x04 \x03(\x0b\x32=.tecton_proto.api.feature_service.GetFeaturesBatchRequestDataR\x0brequestData\x12\\\n\x10metadata_options\x18\x05 \x01(\x0b\x32\x31.tecton_proto.api.feature_service.MetadataOptionsR\x0fmetadataOptions:\x9c\x03\x92\x41\x98\x03\n\x1c*\x1aGetFeaturesBatchParameters:\xf7\x02{\"feature_service_name\": \"fraud_detection_feature_service\", \"request_data\": [{\"join_key_map\": { \"user_uuid\": \"6c423390-9a64-52c8-9bb3-bbb108c74198\" },\"request_context_map\": {\"amount\": 2000}},{\"join_key_map\": { \"user_uuid\": \"6c423390-9a64-52c8-9bb3-bbb108c74198\" },\"request_context_map\": {\"amount\": 500}}],\"workspace_name\": \"prod\",\"metadata_options\": {\"include_names\": true} }B\t\n\x07locator\"\xca\x03\n\x1bGetFeaturesBatchRequestData\x12o\n\x0cjoin_key_map\x18\x01 \x03(\x0b\x32M.tecton_proto.api.feature_service.GetFeaturesBatchRequestData.JoinKeyMapEntryR\njoinKeyMap\x12\x84\x01\n\x13request_context_map\x18\x02 \x03(\x0b\x32T.tecton_proto.api.feature_service.GetFeaturesBatchRequestData.RequestContextMapEntryR\x11requestContextMap\x1aU\n\x0fJoinKeyMapEntry\x12\x10\n\x03key\x18\x01 \x01(\tR\x03key\x12,\n\x05value\x18\x02 \x01(\x0b\x32\x16.google.protobuf.ValueR\x05value:\x02\x38\x01\x1a\\\n\x16RequestContextMapEntry\x12\x10\n\x03key\x18\x01 \x01(\tR\x03key\x12,\n\x05value\x18\x02 \x01(\x0b\x32\x16.google.protobuf.ValueR\x05value:\x02\x38\x01\x42\x36Z4github.com/tecton-ai/tecton_proto/api/featureservice'
  ,
  dependencies=[google_dot_protobuf_dot_struct__pb2.DESCRIPTOR,protoc__gen__swagger_dot_options_dot_annotations__pb2.DESCRIPTOR,])




_METADATAOPTIONS = _descriptor.Descriptor(
  name='MetadataOptions',
  full_name='tecton_proto.api.feature_service.MetadataOptions',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='include_names', full_name='tecton_proto.api.feature_service.MetadataOptions.include_names', index=0,
      number=1, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='includeNames', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='include_effective_times', full_name='tecton_proto.api.feature_service.MetadataOptions.include_effective_times', index=1,
      number=2, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='includeEffectiveTimes', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='include_types', full_name='tecton_proto.api.feature_service.MetadataOptions.include_types', index=2,
      number=3, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\030\001', json_name='includeTypes', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='include_data_types', full_name='tecton_proto.api.feature_service.MetadataOptions.include_data_types', index=3,
      number=5, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='includeDataTypes', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='include_slo_info', full_name='tecton_proto.api.feature_service.MetadataOptions.include_slo_info', index=4,
      number=4, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='includeSloInfo', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=176,
  serialized_end=415,
)


_GETFEATURESREQUEST = _descriptor.Descriptor(
  name='GetFeaturesRequest',
  full_name='tecton_proto.api.feature_service.GetFeaturesRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='params', full_name='tecton_proto.api.feature_service.GetFeaturesRequest.params', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='params', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=417,
  serialized_end=518,
)


_GETFEATURESBATCHREQUEST = _descriptor.Descriptor(
  name='GetFeaturesBatchRequest',
  full_name='tecton_proto.api.feature_service.GetFeaturesBatchRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='params', full_name='tecton_proto.api.feature_service.GetFeaturesBatchRequest.params', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='params', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=520,
  serialized_end=631,
)


_GETFEATURESPARAMETERS_JOINKEYMAPENTRY = _descriptor.Descriptor(
  name='JoinKeyMapEntry',
  full_name='tecton_proto.api.feature_service.GetFeaturesParameters.JoinKeyMapEntry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='tecton_proto.api.feature_service.GetFeaturesParameters.JoinKeyMapEntry.key', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='key', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='value', full_name='tecton_proto.api.feature_service.GetFeaturesParameters.JoinKeyMapEntry.value', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='value', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'8\001',
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1379,
  serialized_end=1464,
)

_GETFEATURESPARAMETERS_REQUESTCONTEXTMAPENTRY = _descriptor.Descriptor(
  name='RequestContextMapEntry',
  full_name='tecton_proto.api.feature_service.GetFeaturesParameters.RequestContextMapEntry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='tecton_proto.api.feature_service.GetFeaturesParameters.RequestContextMapEntry.key', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='key', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='value', full_name='tecton_proto.api.feature_service.GetFeaturesParameters.RequestContextMapEntry.value', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='value', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'8\001',
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1466,
  serialized_end=1558,
)

_GETFEATURESPARAMETERS = _descriptor.Descriptor(
  name='GetFeaturesParameters',
  full_name='tecton_proto.api.feature_service.GetFeaturesParameters',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='feature_service_id', full_name='tecton_proto.api.feature_service.GetFeaturesParameters.feature_service_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='featureServiceId', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='feature_service_name', full_name='tecton_proto.api.feature_service.GetFeaturesParameters.feature_service_name', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='featureServiceName', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='feature_package_id', full_name='tecton_proto.api.feature_service.GetFeaturesParameters.feature_package_id', index=2,
      number=12, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='featurePackageId', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='feature_package_name', full_name='tecton_proto.api.feature_service.GetFeaturesParameters.feature_package_name', index=3,
      number=13, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='featurePackageName', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='feature_view_id', full_name='tecton_proto.api.feature_service.GetFeaturesParameters.feature_view_id', index=4,
      number=15, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='featureViewId', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='feature_view_name', full_name='tecton_proto.api.feature_service.GetFeaturesParameters.feature_view_name', index=5,
      number=16, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='featureViewName', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='workspace_name', full_name='tecton_proto.api.feature_service.GetFeaturesParameters.workspace_name', index=6,
      number=10, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='workspaceName', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='join_key_map', full_name='tecton_proto.api.feature_service.GetFeaturesParameters.join_key_map', index=7,
      number=8, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='joinKeyMap', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='request_context_map', full_name='tecton_proto.api.feature_service.GetFeaturesParameters.request_context_map', index=8,
      number=9, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='requestContextMap', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='metadata_options', full_name='tecton_proto.api.feature_service.GetFeaturesParameters.metadata_options', index=9,
      number=7, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='metadataOptions', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='allow_partial_results', full_name='tecton_proto.api.feature_service.GetFeaturesParameters.allow_partial_results', index=10,
      number=11, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\222A\007:\005false', json_name='allowPartialResults', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_GETFEATURESPARAMETERS_JOINKEYMAPENTRY, _GETFEATURESPARAMETERS_REQUESTCONTEXTMAPENTRY, ],
  enum_types=[
  ],
  serialized_options=b'\222A\251\001\n\027*\025GetFeaturesParameters:\215\001{\"feature_service_name\": \"ctr_prediction_service\", \"join_key_map\": { \"ad_id\": \"5417\", \"user_uuid\": \"6c423390-9a64-52c8-9bb3-bbb108c74198\" } }',
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='locator', full_name='tecton_proto.api.feature_service.GetFeaturesParameters.locator',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=634,
  serialized_end=1775,
)


_GETFEATURESBATCHPARAMETERS = _descriptor.Descriptor(
  name='GetFeaturesBatchParameters',
  full_name='tecton_proto.api.feature_service.GetFeaturesBatchParameters',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='feature_service_id', full_name='tecton_proto.api.feature_service.GetFeaturesBatchParameters.feature_service_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='featureServiceId', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='feature_service_name', full_name='tecton_proto.api.feature_service.GetFeaturesBatchParameters.feature_service_name', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='featureServiceName', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='workspace_name', full_name='tecton_proto.api.feature_service.GetFeaturesBatchParameters.workspace_name', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='workspaceName', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='request_data', full_name='tecton_proto.api.feature_service.GetFeaturesBatchParameters.request_data', index=3,
      number=4, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='requestData', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='metadata_options', full_name='tecton_proto.api.feature_service.GetFeaturesBatchParameters.metadata_options', index=4,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='metadataOptions', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'\222A\230\003\n\034*\032GetFeaturesBatchParameters:\367\002{\"feature_service_name\": \"fraud_detection_feature_service\", \"request_data\": [{\"join_key_map\": { \"user_uuid\": \"6c423390-9a64-52c8-9bb3-bbb108c74198\" },\"request_context_map\": {\"amount\": 2000}},{\"join_key_map\": { \"user_uuid\": \"6c423390-9a64-52c8-9bb3-bbb108c74198\" },\"request_context_map\": {\"amount\": 500}}],\"workspace_name\": \"prod\",\"metadata_options\": {\"include_names\": true} }',
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='locator', full_name='tecton_proto.api.feature_service.GetFeaturesBatchParameters.locator',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=1778,
  serialized_end=2563,
)


_GETFEATURESBATCHREQUESTDATA_JOINKEYMAPENTRY = _descriptor.Descriptor(
  name='JoinKeyMapEntry',
  full_name='tecton_proto.api.feature_service.GetFeaturesBatchRequestData.JoinKeyMapEntry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='tecton_proto.api.feature_service.GetFeaturesBatchRequestData.JoinKeyMapEntry.key', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='key', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='value', full_name='tecton_proto.api.feature_service.GetFeaturesBatchRequestData.JoinKeyMapEntry.value', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='value', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'8\001',
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1379,
  serialized_end=1464,
)

_GETFEATURESBATCHREQUESTDATA_REQUESTCONTEXTMAPENTRY = _descriptor.Descriptor(
  name='RequestContextMapEntry',
  full_name='tecton_proto.api.feature_service.GetFeaturesBatchRequestData.RequestContextMapEntry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='tecton_proto.api.feature_service.GetFeaturesBatchRequestData.RequestContextMapEntry.key', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='key', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='value', full_name='tecton_proto.api.feature_service.GetFeaturesBatchRequestData.RequestContextMapEntry.value', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='value', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'8\001',
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1466,
  serialized_end=1558,
)

_GETFEATURESBATCHREQUESTDATA = _descriptor.Descriptor(
  name='GetFeaturesBatchRequestData',
  full_name='tecton_proto.api.feature_service.GetFeaturesBatchRequestData',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='join_key_map', full_name='tecton_proto.api.feature_service.GetFeaturesBatchRequestData.join_key_map', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='joinKeyMap', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='request_context_map', full_name='tecton_proto.api.feature_service.GetFeaturesBatchRequestData.request_context_map', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='requestContextMap', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_GETFEATURESBATCHREQUESTDATA_JOINKEYMAPENTRY, _GETFEATURESBATCHREQUESTDATA_REQUESTCONTEXTMAPENTRY, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2566,
  serialized_end=3024,
)

_GETFEATURESREQUEST.fields_by_name['params'].message_type = _GETFEATURESPARAMETERS
_GETFEATURESBATCHREQUEST.fields_by_name['params'].message_type = _GETFEATURESBATCHPARAMETERS
_GETFEATURESPARAMETERS_JOINKEYMAPENTRY.fields_by_name['value'].message_type = google_dot_protobuf_dot_struct__pb2._VALUE
_GETFEATURESPARAMETERS_JOINKEYMAPENTRY.containing_type = _GETFEATURESPARAMETERS
_GETFEATURESPARAMETERS_REQUESTCONTEXTMAPENTRY.fields_by_name['value'].message_type = google_dot_protobuf_dot_struct__pb2._VALUE
_GETFEATURESPARAMETERS_REQUESTCONTEXTMAPENTRY.containing_type = _GETFEATURESPARAMETERS
_GETFEATURESPARAMETERS.fields_by_name['join_key_map'].message_type = _GETFEATURESPARAMETERS_JOINKEYMAPENTRY
_GETFEATURESPARAMETERS.fields_by_name['request_context_map'].message_type = _GETFEATURESPARAMETERS_REQUESTCONTEXTMAPENTRY
_GETFEATURESPARAMETERS.fields_by_name['metadata_options'].message_type = _METADATAOPTIONS
_GETFEATURESPARAMETERS.oneofs_by_name['locator'].fields.append(
  _GETFEATURESPARAMETERS.fields_by_name['feature_service_id'])
_GETFEATURESPARAMETERS.fields_by_name['feature_service_id'].containing_oneof = _GETFEATURESPARAMETERS.oneofs_by_name['locator']
_GETFEATURESPARAMETERS.oneofs_by_name['locator'].fields.append(
  _GETFEATURESPARAMETERS.fields_by_name['feature_service_name'])
_GETFEATURESPARAMETERS.fields_by_name['feature_service_name'].containing_oneof = _GETFEATURESPARAMETERS.oneofs_by_name['locator']
_GETFEATURESPARAMETERS.oneofs_by_name['locator'].fields.append(
  _GETFEATURESPARAMETERS.fields_by_name['feature_package_id'])
_GETFEATURESPARAMETERS.fields_by_name['feature_package_id'].containing_oneof = _GETFEATURESPARAMETERS.oneofs_by_name['locator']
_GETFEATURESPARAMETERS.oneofs_by_name['locator'].fields.append(
  _GETFEATURESPARAMETERS.fields_by_name['feature_package_name'])
_GETFEATURESPARAMETERS.fields_by_name['feature_package_name'].containing_oneof = _GETFEATURESPARAMETERS.oneofs_by_name['locator']
_GETFEATURESPARAMETERS.oneofs_by_name['locator'].fields.append(
  _GETFEATURESPARAMETERS.fields_by_name['feature_view_id'])
_GETFEATURESPARAMETERS.fields_by_name['feature_view_id'].containing_oneof = _GETFEATURESPARAMETERS.oneofs_by_name['locator']
_GETFEATURESPARAMETERS.oneofs_by_name['locator'].fields.append(
  _GETFEATURESPARAMETERS.fields_by_name['feature_view_name'])
_GETFEATURESPARAMETERS.fields_by_name['feature_view_name'].containing_oneof = _GETFEATURESPARAMETERS.oneofs_by_name['locator']
_GETFEATURESBATCHPARAMETERS.fields_by_name['request_data'].message_type = _GETFEATURESBATCHREQUESTDATA
_GETFEATURESBATCHPARAMETERS.fields_by_name['metadata_options'].message_type = _METADATAOPTIONS
_GETFEATURESBATCHPARAMETERS.oneofs_by_name['locator'].fields.append(
  _GETFEATURESBATCHPARAMETERS.fields_by_name['feature_service_id'])
_GETFEATURESBATCHPARAMETERS.fields_by_name['feature_service_id'].containing_oneof = _GETFEATURESBATCHPARAMETERS.oneofs_by_name['locator']
_GETFEATURESBATCHPARAMETERS.oneofs_by_name['locator'].fields.append(
  _GETFEATURESBATCHPARAMETERS.fields_by_name['feature_service_name'])
_GETFEATURESBATCHPARAMETERS.fields_by_name['feature_service_name'].containing_oneof = _GETFEATURESBATCHPARAMETERS.oneofs_by_name['locator']
_GETFEATURESBATCHREQUESTDATA_JOINKEYMAPENTRY.fields_by_name['value'].message_type = google_dot_protobuf_dot_struct__pb2._VALUE
_GETFEATURESBATCHREQUESTDATA_JOINKEYMAPENTRY.containing_type = _GETFEATURESBATCHREQUESTDATA
_GETFEATURESBATCHREQUESTDATA_REQUESTCONTEXTMAPENTRY.fields_by_name['value'].message_type = google_dot_protobuf_dot_struct__pb2._VALUE
_GETFEATURESBATCHREQUESTDATA_REQUESTCONTEXTMAPENTRY.containing_type = _GETFEATURESBATCHREQUESTDATA
_GETFEATURESBATCHREQUESTDATA.fields_by_name['join_key_map'].message_type = _GETFEATURESBATCHREQUESTDATA_JOINKEYMAPENTRY
_GETFEATURESBATCHREQUESTDATA.fields_by_name['request_context_map'].message_type = _GETFEATURESBATCHREQUESTDATA_REQUESTCONTEXTMAPENTRY
DESCRIPTOR.message_types_by_name['MetadataOptions'] = _METADATAOPTIONS
DESCRIPTOR.message_types_by_name['GetFeaturesRequest'] = _GETFEATURESREQUEST
DESCRIPTOR.message_types_by_name['GetFeaturesBatchRequest'] = _GETFEATURESBATCHREQUEST
DESCRIPTOR.message_types_by_name['GetFeaturesParameters'] = _GETFEATURESPARAMETERS
DESCRIPTOR.message_types_by_name['GetFeaturesBatchParameters'] = _GETFEATURESBATCHPARAMETERS
DESCRIPTOR.message_types_by_name['GetFeaturesBatchRequestData'] = _GETFEATURESBATCHREQUESTDATA
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

MetadataOptions = _reflection.GeneratedProtocolMessageType('MetadataOptions', (_message.Message,), {
  'DESCRIPTOR' : _METADATAOPTIONS,
  '__module__' : 'tecton_proto.api.featureservice.feature_service_request_pb2'
  # @@protoc_insertion_point(class_scope:tecton_proto.api.feature_service.MetadataOptions)
  })
_sym_db.RegisterMessage(MetadataOptions)

GetFeaturesRequest = _reflection.GeneratedProtocolMessageType('GetFeaturesRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETFEATURESREQUEST,
  '__module__' : 'tecton_proto.api.featureservice.feature_service_request_pb2'
  # @@protoc_insertion_point(class_scope:tecton_proto.api.feature_service.GetFeaturesRequest)
  })
_sym_db.RegisterMessage(GetFeaturesRequest)

GetFeaturesBatchRequest = _reflection.GeneratedProtocolMessageType('GetFeaturesBatchRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETFEATURESBATCHREQUEST,
  '__module__' : 'tecton_proto.api.featureservice.feature_service_request_pb2'
  # @@protoc_insertion_point(class_scope:tecton_proto.api.feature_service.GetFeaturesBatchRequest)
  })
_sym_db.RegisterMessage(GetFeaturesBatchRequest)

GetFeaturesParameters = _reflection.GeneratedProtocolMessageType('GetFeaturesParameters', (_message.Message,), {

  'JoinKeyMapEntry' : _reflection.GeneratedProtocolMessageType('JoinKeyMapEntry', (_message.Message,), {
    'DESCRIPTOR' : _GETFEATURESPARAMETERS_JOINKEYMAPENTRY,
    '__module__' : 'tecton_proto.api.featureservice.feature_service_request_pb2'
    # @@protoc_insertion_point(class_scope:tecton_proto.api.feature_service.GetFeaturesParameters.JoinKeyMapEntry)
    })
  ,

  'RequestContextMapEntry' : _reflection.GeneratedProtocolMessageType('RequestContextMapEntry', (_message.Message,), {
    'DESCRIPTOR' : _GETFEATURESPARAMETERS_REQUESTCONTEXTMAPENTRY,
    '__module__' : 'tecton_proto.api.featureservice.feature_service_request_pb2'
    # @@protoc_insertion_point(class_scope:tecton_proto.api.feature_service.GetFeaturesParameters.RequestContextMapEntry)
    })
  ,
  'DESCRIPTOR' : _GETFEATURESPARAMETERS,
  '__module__' : 'tecton_proto.api.featureservice.feature_service_request_pb2'
  # @@protoc_insertion_point(class_scope:tecton_proto.api.feature_service.GetFeaturesParameters)
  })
_sym_db.RegisterMessage(GetFeaturesParameters)
_sym_db.RegisterMessage(GetFeaturesParameters.JoinKeyMapEntry)
_sym_db.RegisterMessage(GetFeaturesParameters.RequestContextMapEntry)

GetFeaturesBatchParameters = _reflection.GeneratedProtocolMessageType('GetFeaturesBatchParameters', (_message.Message,), {
  'DESCRIPTOR' : _GETFEATURESBATCHPARAMETERS,
  '__module__' : 'tecton_proto.api.featureservice.feature_service_request_pb2'
  # @@protoc_insertion_point(class_scope:tecton_proto.api.feature_service.GetFeaturesBatchParameters)
  })
_sym_db.RegisterMessage(GetFeaturesBatchParameters)

GetFeaturesBatchRequestData = _reflection.GeneratedProtocolMessageType('GetFeaturesBatchRequestData', (_message.Message,), {

  'JoinKeyMapEntry' : _reflection.GeneratedProtocolMessageType('JoinKeyMapEntry', (_message.Message,), {
    'DESCRIPTOR' : _GETFEATURESBATCHREQUESTDATA_JOINKEYMAPENTRY,
    '__module__' : 'tecton_proto.api.featureservice.feature_service_request_pb2'
    # @@protoc_insertion_point(class_scope:tecton_proto.api.feature_service.GetFeaturesBatchRequestData.JoinKeyMapEntry)
    })
  ,

  'RequestContextMapEntry' : _reflection.GeneratedProtocolMessageType('RequestContextMapEntry', (_message.Message,), {
    'DESCRIPTOR' : _GETFEATURESBATCHREQUESTDATA_REQUESTCONTEXTMAPENTRY,
    '__module__' : 'tecton_proto.api.featureservice.feature_service_request_pb2'
    # @@protoc_insertion_point(class_scope:tecton_proto.api.feature_service.GetFeaturesBatchRequestData.RequestContextMapEntry)
    })
  ,
  'DESCRIPTOR' : _GETFEATURESBATCHREQUESTDATA,
  '__module__' : 'tecton_proto.api.featureservice.feature_service_request_pb2'
  # @@protoc_insertion_point(class_scope:tecton_proto.api.feature_service.GetFeaturesBatchRequestData)
  })
_sym_db.RegisterMessage(GetFeaturesBatchRequestData)
_sym_db.RegisterMessage(GetFeaturesBatchRequestData.JoinKeyMapEntry)
_sym_db.RegisterMessage(GetFeaturesBatchRequestData.RequestContextMapEntry)


DESCRIPTOR._options = None
_METADATAOPTIONS.fields_by_name['include_types']._options = None
_GETFEATURESPARAMETERS_JOINKEYMAPENTRY._options = None
_GETFEATURESPARAMETERS_REQUESTCONTEXTMAPENTRY._options = None
_GETFEATURESPARAMETERS.fields_by_name['allow_partial_results']._options = None
_GETFEATURESPARAMETERS._options = None
_GETFEATURESBATCHPARAMETERS._options = None
_GETFEATURESBATCHREQUESTDATA_JOINKEYMAPENTRY._options = None
_GETFEATURESBATCHREQUESTDATA_REQUESTCONTEXTMAPENTRY._options = None
# @@protoc_insertion_point(module_scope)
