# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: tecton_proto/common/column_type.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor.FileDescriptor(
  name='tecton_proto/common/column_type.proto',
  package='tecton_proto.common',
  syntax='proto2',
  serialized_options=b'\n\021com.tecton.commonP\001Z(github.com/tecton-ai/tecton_proto/common',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n%tecton_proto/common/column_type.proto\x12\x13tecton_proto.common*\x84\x02\n\nColumnType\x12\x17\n\x13\x43OLUMN_TYPE_UNKNOWN\x10\x00\x12\x15\n\x11\x43OLUMN_TYPE_INT64\x10\x01\x12\x16\n\x12\x43OLUMN_TYPE_DOUBLE\x10\x02\x12\x16\n\x12\x43OLUMN_TYPE_STRING\x10\x03\x12\x14\n\x10\x43OLUMN_TYPE_BOOL\x10\x06\x12\x1c\n\x18\x43OLUMN_TYPE_STRING_ARRAY\x10\x07\x12\x1b\n\x17\x43OLUMN_TYPE_INT64_ARRAY\x10\x08\x12\x1c\n\x18\x43OLUMN_TYPE_DOUBLE_ARRAY\x10\t\x12\x1b\n\x17\x43OLUMN_TYPE_FLOAT_ARRAY\x10\n\"\x04\x08\x04\x10\x04\"\x04\x08\x05\x10\x05\x42?\n\x11\x63om.tecton.commonP\x01Z(github.com/tecton-ai/tecton_proto/common'
)

_COLUMNTYPE = _descriptor.EnumDescriptor(
  name='ColumnType',
  full_name='tecton_proto.common.ColumnType',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='COLUMN_TYPE_UNKNOWN', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='COLUMN_TYPE_INT64', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='COLUMN_TYPE_DOUBLE', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='COLUMN_TYPE_STRING', index=3, number=3,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='COLUMN_TYPE_BOOL', index=4, number=6,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='COLUMN_TYPE_STRING_ARRAY', index=5, number=7,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='COLUMN_TYPE_INT64_ARRAY', index=6, number=8,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='COLUMN_TYPE_DOUBLE_ARRAY', index=7, number=9,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='COLUMN_TYPE_FLOAT_ARRAY', index=8, number=10,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=63,
  serialized_end=323,
)
_sym_db.RegisterEnumDescriptor(_COLUMNTYPE)

ColumnType = enum_type_wrapper.EnumTypeWrapper(_COLUMNTYPE)
COLUMN_TYPE_UNKNOWN = 0
COLUMN_TYPE_INT64 = 1
COLUMN_TYPE_DOUBLE = 2
COLUMN_TYPE_STRING = 3
COLUMN_TYPE_BOOL = 6
COLUMN_TYPE_STRING_ARRAY = 7
COLUMN_TYPE_INT64_ARRAY = 8
COLUMN_TYPE_DOUBLE_ARRAY = 9
COLUMN_TYPE_FLOAT_ARRAY = 10


DESCRIPTOR.enum_types_by_name['ColumnType'] = _COLUMNTYPE
_sym_db.RegisterFileDescriptor(DESCRIPTOR)


DESCRIPTOR._options = None
# @@protoc_insertion_point(module_scope)
