# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: tecton_proto/args/entity.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from tecton_proto.args import basic_info_pb2 as tecton__proto_dot_args_dot_basic__info__pb2
from tecton_proto.common import id_pb2 as tecton__proto_dot_common_dot_id__pb2
from tecton_proto.args import diff_options_pb2 as tecton__proto_dot_args_dot_diff__options__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='tecton_proto/args/entity.proto',
  package='tecton_proto.args',
  syntax='proto2',
  serialized_options=b'\n\017com.tecton.argsP\001',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n\x1etecton_proto/args/entity.proto\x12\x11tecton_proto.args\x1a\"tecton_proto/args/basic_info.proto\x1a\x1ctecton_proto/common/id.proto\x1a$tecton_proto/args/diff_options.proto\"\x98\x01\n\nEntityArgs\x12\x34\n\tentity_id\x18\x01 \x01(\x0b\x32\x17.tecton_proto.common.IdR\x08\x65ntityId\x12\x37\n\x04info\x18\x02 \x01(\x0b\x32\x1c.tecton_proto.args.BasicInfoB\x05\x92M\x02\x10\x01R\x04info\x12\x1b\n\tjoin_keys\x18\x03 \x03(\tR\x08joinKeysB\x13\n\x0f\x63om.tecton.argsP\x01'
  ,
  dependencies=[tecton__proto_dot_args_dot_basic__info__pb2.DESCRIPTOR,tecton__proto_dot_common_dot_id__pb2.DESCRIPTOR,tecton__proto_dot_args_dot_diff__options__pb2.DESCRIPTOR,])




_ENTITYARGS = _descriptor.Descriptor(
  name='EntityArgs',
  full_name='tecton_proto.args.EntityArgs',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='entity_id', full_name='tecton_proto.args.EntityArgs.entity_id', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='entityId', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='info', full_name='tecton_proto.args.EntityArgs.info', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\222M\002\020\001', json_name='info', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='join_keys', full_name='tecton_proto.args.EntityArgs.join_keys', index=2,
      number=3, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='joinKeys', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=158,
  serialized_end=310,
)

_ENTITYARGS.fields_by_name['entity_id'].message_type = tecton__proto_dot_common_dot_id__pb2._ID
_ENTITYARGS.fields_by_name['info'].message_type = tecton__proto_dot_args_dot_basic__info__pb2._BASICINFO
DESCRIPTOR.message_types_by_name['EntityArgs'] = _ENTITYARGS
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

EntityArgs = _reflection.GeneratedProtocolMessageType('EntityArgs', (_message.Message,), {
  'DESCRIPTOR' : _ENTITYARGS,
  '__module__' : 'tecton_proto.args.entity_pb2'
  # @@protoc_insertion_point(class_scope:tecton_proto.args.EntityArgs)
  })
_sym_db.RegisterMessage(EntityArgs)


DESCRIPTOR._options = None
_ENTITYARGS.fields_by_name['info']._options = None
# @@protoc_insertion_point(module_scope)
