# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: tecton_proto/args/diff_options.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import descriptor_pb2 as google_dot_protobuf_dot_descriptor__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='tecton_proto/args/diff_options.proto',
  package='tecton_proto.args',
  syntax='proto2',
  serialized_options=b'\n\017com.tecton.argsP\001',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n$tecton_proto/args/diff_options.proto\x12\x11tecton_proto.args\x1a google/protobuf/descriptor.proto\"e\n\x0b\x44iffOptions\x12\x39\n\x06update\x18\x01 \x01(\x0e\x32!.tecton_proto.args.UpdateStrategyR\x06update\x12\x1b\n\thide_path\x18\x02 \x01(\x08R\x08hidePath*{\n\x0eUpdateStrategy\x12\x0c\n\x08RECREATE\x10\x00\x12\x0b\n\x07INPLACE\x10\x01\x12\x12\n\x0eINPLACE_ON_ADD\x10\x03\x12\x15\n\x11INPLACE_ON_REMOVE\x10\x04\x12\x0b\n\x07PASSIVE\x10\x05\x12\x16\n\x12INPLACE_BREAKGLASS\x10\x06:a\n\x0c\x64iff_options\x12\x1d.google.protobuf.FieldOptions\x18\xd2\t \x01(\x0b\x32\x1e.tecton_proto.args.DiffOptionsR\x0b\x64iffOptionsB\x13\n\x0f\x63om.tecton.argsP\x01'
  ,
  dependencies=[google_dot_protobuf_dot_descriptor__pb2.DESCRIPTOR,])

_UPDATESTRATEGY = _descriptor.EnumDescriptor(
  name='UpdateStrategy',
  full_name='tecton_proto.args.UpdateStrategy',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='RECREATE', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='INPLACE', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='INPLACE_ON_ADD', index=2, number=3,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='INPLACE_ON_REMOVE', index=3, number=4,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='PASSIVE', index=4, number=5,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='INPLACE_BREAKGLASS', index=5, number=6,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=196,
  serialized_end=319,
)
_sym_db.RegisterEnumDescriptor(_UPDATESTRATEGY)

UpdateStrategy = enum_type_wrapper.EnumTypeWrapper(_UPDATESTRATEGY)
RECREATE = 0
INPLACE = 1
INPLACE_ON_ADD = 3
INPLACE_ON_REMOVE = 4
PASSIVE = 5
INPLACE_BREAKGLASS = 6

DIFF_OPTIONS_FIELD_NUMBER = 1234
diff_options = _descriptor.FieldDescriptor(
  name='diff_options', full_name='tecton_proto.args.diff_options', index=0,
  number=1234, type=11, cpp_type=10, label=1,
  has_default_value=False, default_value=None,
  message_type=None, enum_type=None, containing_type=None,
  is_extension=True, extension_scope=None,
  serialized_options=None, json_name='diffOptions', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key)


_DIFFOPTIONS = _descriptor.Descriptor(
  name='DiffOptions',
  full_name='tecton_proto.args.DiffOptions',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='update', full_name='tecton_proto.args.DiffOptions.update', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='update', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='hide_path', full_name='tecton_proto.args.DiffOptions.hide_path', index=1,
      number=2, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='hidePath', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=93,
  serialized_end=194,
)

_DIFFOPTIONS.fields_by_name['update'].enum_type = _UPDATESTRATEGY
DESCRIPTOR.message_types_by_name['DiffOptions'] = _DIFFOPTIONS
DESCRIPTOR.enum_types_by_name['UpdateStrategy'] = _UPDATESTRATEGY
DESCRIPTOR.extensions_by_name['diff_options'] = diff_options
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

DiffOptions = _reflection.GeneratedProtocolMessageType('DiffOptions', (_message.Message,), {
  'DESCRIPTOR' : _DIFFOPTIONS,
  '__module__' : 'tecton_proto.args.diff_options_pb2'
  # @@protoc_insertion_point(class_scope:tecton_proto.args.DiffOptions)
  })
_sym_db.RegisterMessage(DiffOptions)

diff_options.message_type = _DIFFOPTIONS
google_dot_protobuf_dot_descriptor__pb2.FieldOptions.RegisterExtension(diff_options)

DESCRIPTOR._options = None
# @@protoc_insertion_point(module_scope)
