# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: tecton_proto/common/id.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor.FileDescriptor(
  name='tecton_proto/common/id.proto',
  package='tecton_proto.common',
  syntax='proto2',
  serialized_options=b'\n\021com.tecton.commonP\001',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n\x1ctecton_proto/common/id.proto\x12\x13tecton_proto.common\"n\n\x02Id\x12\x32\n\x15most_significant_bits\x18\x01 \x01(\x06R\x13mostSignificantBits\x12\x34\n\x16least_significant_bits\x18\x02 \x01(\x06R\x14leastSignificantBitsB\x15\n\x11\x63om.tecton.commonP\x01'
)




_ID = _descriptor.Descriptor(
  name='Id',
  full_name='tecton_proto.common.Id',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='most_significant_bits', full_name='tecton_proto.common.Id.most_significant_bits', index=0,
      number=1, type=6, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='mostSignificantBits', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='least_significant_bits', full_name='tecton_proto.common.Id.least_significant_bits', index=1,
      number=2, type=6, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='leastSignificantBits', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=53,
  serialized_end=163,
)

DESCRIPTOR.message_types_by_name['Id'] = _ID
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

Id = _reflection.GeneratedProtocolMessageType('Id', (_message.Message,), {
  'DESCRIPTOR' : _ID,
  '__module__' : 'tecton_proto.common.id_pb2'
  # @@protoc_insertion_point(class_scope:tecton_proto.common.Id)
  })
_sym_db.RegisterMessage(Id)


DESCRIPTOR._options = None
# @@protoc_insertion_point(module_scope)
