# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: tecton_proto/args/user_defined_function.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor.FileDescriptor(
  name='tecton_proto/args/user_defined_function.proto',
  package='tecton_proto.args',
  syntax='proto2',
  serialized_options=b'\n\017com.tecton.argsP\001Z&github.com/tecton-ai/tecton_proto/args',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n-tecton_proto/args/user_defined_function.proto\x12\x11tecton_proto.args\"C\n\x13UserDefinedFunction\x12\x12\n\x04name\x18\x01 \x01(\tR\x04name\x12\x12\n\x04\x62ody\x18\x03 \x01(\tR\x04\x62odyJ\x04\x08\x02\x10\x03\x42;\n\x0f\x63om.tecton.argsP\x01Z&github.com/tecton-ai/tecton_proto/args'
)




_USERDEFINEDFUNCTION = _descriptor.Descriptor(
  name='UserDefinedFunction',
  full_name='tecton_proto.args.UserDefinedFunction',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='name', full_name='tecton_proto.args.UserDefinedFunction.name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='name', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='body', full_name='tecton_proto.args.UserDefinedFunction.body', index=1,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='body', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=68,
  serialized_end=135,
)

DESCRIPTOR.message_types_by_name['UserDefinedFunction'] = _USERDEFINEDFUNCTION
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

UserDefinedFunction = _reflection.GeneratedProtocolMessageType('UserDefinedFunction', (_message.Message,), {
  'DESCRIPTOR' : _USERDEFINEDFUNCTION,
  '__module__' : 'tecton_proto.args.user_defined_function_pb2'
  # @@protoc_insertion_point(class_scope:tecton_proto.args.UserDefinedFunction)
  })
_sym_db.RegisterMessage(UserDefinedFunction)


DESCRIPTOR._options = None
# @@protoc_insertion_point(module_scope)
