# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: tecton_proto/common/secret.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor.FileDescriptor(
  name='tecton_proto/common/secret.proto',
  package='tecton_proto.common',
  syntax='proto2',
  serialized_options=b'\n\021com.tecton.commonP\001',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n tecton_proto/common/secret.proto\x12\x13tecton_proto.common\"\x84\x01\n\x06Secret\x12\x16\n\x05value\x18\x01 \x01(\tH\x00R\x05value\x12\'\n\x0eredacted_value\x18\x02 \x01(\tH\x00R\rredactedValue\x12)\n\x0f\x65ncrypted_value\x18\x03 \x01(\tH\x00R\x0e\x65ncryptedValueB\x0e\n\x0csecret_valueB\x15\n\x11\x63om.tecton.commonP\x01'
)




_SECRET = _descriptor.Descriptor(
  name='Secret',
  full_name='tecton_proto.common.Secret',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='value', full_name='tecton_proto.common.Secret.value', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='value', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='redacted_value', full_name='tecton_proto.common.Secret.redacted_value', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='redactedValue', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='encrypted_value', full_name='tecton_proto.common.Secret.encrypted_value', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='encryptedValue', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='secret_value', full_name='tecton_proto.common.Secret.secret_value',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=58,
  serialized_end=190,
)

_SECRET.oneofs_by_name['secret_value'].fields.append(
  _SECRET.fields_by_name['value'])
_SECRET.fields_by_name['value'].containing_oneof = _SECRET.oneofs_by_name['secret_value']
_SECRET.oneofs_by_name['secret_value'].fields.append(
  _SECRET.fields_by_name['redacted_value'])
_SECRET.fields_by_name['redacted_value'].containing_oneof = _SECRET.oneofs_by_name['secret_value']
_SECRET.oneofs_by_name['secret_value'].fields.append(
  _SECRET.fields_by_name['encrypted_value'])
_SECRET.fields_by_name['encrypted_value'].containing_oneof = _SECRET.oneofs_by_name['secret_value']
DESCRIPTOR.message_types_by_name['Secret'] = _SECRET
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

Secret = _reflection.GeneratedProtocolMessageType('Secret', (_message.Message,), {
  'DESCRIPTOR' : _SECRET,
  '__module__' : 'tecton_proto.common.secret_pb2'
  # @@protoc_insertion_point(class_scope:tecton_proto.common.Secret)
  })
_sym_db.RegisterMessage(Secret)


DESCRIPTOR._options = None
# @@protoc_insertion_point(module_scope)
