# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: tecton_proto/amplitude/client_logging.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import duration_pb2 as google_dot_protobuf_dot_duration__pb2
from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='tecton_proto/amplitude/client_logging.proto',
  package='tecton_proto.amplitude',
  syntax='proto2',
  serialized_options=b'\n\024com.tecton.amplitudeB\022ClientLoggingProtoP\001',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n+tecton_proto/amplitude/client_logging.proto\x12\x16tecton_proto.amplitude\x1a\x1egoogle/protobuf/duration.proto\x1a\x1fgoogle/protobuf/timestamp.proto\"7\n\x0bLoggedValue\x12\x12\n\x04name\x18\x01 \x01(\tR\x04name\x12\x14\n\x05value\x18\x02 \x01(\tR\x05value\"|\n\x08\x45rrorLog\x12\x18\n\x07message\x18\x01 \x01(\tR\x07message\x12\x1e\n\nstacktrace\x18\x02 \x01(\tR\nstacktrace\x12\x36\n\x05\x63\x61use\x18\x03 \x01(\x0b\x32 .tecton_proto.amplitude.ErrorLogR\x05\x63\x61use\"\xa7\x04\n\x13SDKMethodInvocation\x12.\n\x04time\x18\x01 \x01(\x0b\x32\x1a.google.protobuf.TimestampR\x04time\x12\x17\n\x07user_id\x18\x02 \x01(\tR\x06userId\x12\x19\n\x08trace_id\x18\x03 \x01(\tR\x07traceId\x12\x1b\n\tlog_level\x18\x04 \x01(\tR\x08logLevel\x12:\n\x04type\x18\x05 \x01(\x0e\x32&.tecton_proto.amplitude.LogMessageTypeR\x04type\x12\x1d\n\nclass_name\x18\x06 \x01(\tR\tclassName\x12\x1f\n\x0bmethod_name\x18\x07 \x01(\tR\nmethodName\x12@\n\x0e\x65xecution_time\x18\x08 \x01(\x0b\x32\x19.google.protobuf.DurationR\rexecutionTime\x12Z\n\x17params_or_return_values\x18\t \x03(\x0b\x32#.tecton_proto.amplitude.LoggedValueR\x14paramsOrReturnValues\x12\x36\n\x05\x65rror\x18\n \x01(\x0b\x32 .tecton_proto.amplitude.ErrorLogR\x05\x65rror\x12\x1c\n\tworkspace\x18\x0b \x01(\tR\tworkspace\x12\x1f\n\x0bsdk_version\x18\x0c \x01(\tR\nsdkVersion*\x8a\x01\n\x0eLogMessageType\x12#\n\x1f\x43LIENT_LOG_MESSAGE_TYPE_UNKNOWN\x10\x00\x12(\n$CLIENT_LOG_MESSAGE_TYPE_METHOD_ENTRY\x10\x01\x12)\n%CLIENT_LOG_MESSAGE_TYPE_METHOD_RETURN\x10\x02\x42,\n\x14\x63om.tecton.amplitudeB\x12\x43lientLoggingProtoP\x01'
  ,
  dependencies=[google_dot_protobuf_dot_duration__pb2.DESCRIPTOR,google_dot_protobuf_dot_timestamp__pb2.DESCRIPTOR,])

_LOGMESSAGETYPE = _descriptor.EnumDescriptor(
  name='LogMessageType',
  full_name='tecton_proto.amplitude.LogMessageType',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='CLIENT_LOG_MESSAGE_TYPE_UNKNOWN', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='CLIENT_LOG_MESSAGE_TYPE_METHOD_ENTRY', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='CLIENT_LOG_MESSAGE_TYPE_METHOD_RETURN', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=874,
  serialized_end=1012,
)
_sym_db.RegisterEnumDescriptor(_LOGMESSAGETYPE)

LogMessageType = enum_type_wrapper.EnumTypeWrapper(_LOGMESSAGETYPE)
CLIENT_LOG_MESSAGE_TYPE_UNKNOWN = 0
CLIENT_LOG_MESSAGE_TYPE_METHOD_ENTRY = 1
CLIENT_LOG_MESSAGE_TYPE_METHOD_RETURN = 2



_LOGGEDVALUE = _descriptor.Descriptor(
  name='LoggedValue',
  full_name='tecton_proto.amplitude.LoggedValue',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='name', full_name='tecton_proto.amplitude.LoggedValue.name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='name', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='value', full_name='tecton_proto.amplitude.LoggedValue.value', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='value', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=136,
  serialized_end=191,
)


_ERRORLOG = _descriptor.Descriptor(
  name='ErrorLog',
  full_name='tecton_proto.amplitude.ErrorLog',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='message', full_name='tecton_proto.amplitude.ErrorLog.message', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='message', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='stacktrace', full_name='tecton_proto.amplitude.ErrorLog.stacktrace', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='stacktrace', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='cause', full_name='tecton_proto.amplitude.ErrorLog.cause', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='cause', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=193,
  serialized_end=317,
)


_SDKMETHODINVOCATION = _descriptor.Descriptor(
  name='SDKMethodInvocation',
  full_name='tecton_proto.amplitude.SDKMethodInvocation',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='time', full_name='tecton_proto.amplitude.SDKMethodInvocation.time', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='time', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='user_id', full_name='tecton_proto.amplitude.SDKMethodInvocation.user_id', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='userId', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='trace_id', full_name='tecton_proto.amplitude.SDKMethodInvocation.trace_id', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='traceId', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='log_level', full_name='tecton_proto.amplitude.SDKMethodInvocation.log_level', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='logLevel', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='type', full_name='tecton_proto.amplitude.SDKMethodInvocation.type', index=4,
      number=5, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='type', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='class_name', full_name='tecton_proto.amplitude.SDKMethodInvocation.class_name', index=5,
      number=6, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='className', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='method_name', full_name='tecton_proto.amplitude.SDKMethodInvocation.method_name', index=6,
      number=7, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='methodName', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='execution_time', full_name='tecton_proto.amplitude.SDKMethodInvocation.execution_time', index=7,
      number=8, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='executionTime', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='params_or_return_values', full_name='tecton_proto.amplitude.SDKMethodInvocation.params_or_return_values', index=8,
      number=9, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='paramsOrReturnValues', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='error', full_name='tecton_proto.amplitude.SDKMethodInvocation.error', index=9,
      number=10, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='error', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='workspace', full_name='tecton_proto.amplitude.SDKMethodInvocation.workspace', index=10,
      number=11, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='workspace', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='sdk_version', full_name='tecton_proto.amplitude.SDKMethodInvocation.sdk_version', index=11,
      number=12, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='sdkVersion', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=320,
  serialized_end=871,
)

_ERRORLOG.fields_by_name['cause'].message_type = _ERRORLOG
_SDKMETHODINVOCATION.fields_by_name['time'].message_type = google_dot_protobuf_dot_timestamp__pb2._TIMESTAMP
_SDKMETHODINVOCATION.fields_by_name['type'].enum_type = _LOGMESSAGETYPE
_SDKMETHODINVOCATION.fields_by_name['execution_time'].message_type = google_dot_protobuf_dot_duration__pb2._DURATION
_SDKMETHODINVOCATION.fields_by_name['params_or_return_values'].message_type = _LOGGEDVALUE
_SDKMETHODINVOCATION.fields_by_name['error'].message_type = _ERRORLOG
DESCRIPTOR.message_types_by_name['LoggedValue'] = _LOGGEDVALUE
DESCRIPTOR.message_types_by_name['ErrorLog'] = _ERRORLOG
DESCRIPTOR.message_types_by_name['SDKMethodInvocation'] = _SDKMETHODINVOCATION
DESCRIPTOR.enum_types_by_name['LogMessageType'] = _LOGMESSAGETYPE
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

LoggedValue = _reflection.GeneratedProtocolMessageType('LoggedValue', (_message.Message,), {
  'DESCRIPTOR' : _LOGGEDVALUE,
  '__module__' : 'tecton_proto.amplitude.client_logging_pb2'
  # @@protoc_insertion_point(class_scope:tecton_proto.amplitude.LoggedValue)
  })
_sym_db.RegisterMessage(LoggedValue)

ErrorLog = _reflection.GeneratedProtocolMessageType('ErrorLog', (_message.Message,), {
  'DESCRIPTOR' : _ERRORLOG,
  '__module__' : 'tecton_proto.amplitude.client_logging_pb2'
  # @@protoc_insertion_point(class_scope:tecton_proto.amplitude.ErrorLog)
  })
_sym_db.RegisterMessage(ErrorLog)

SDKMethodInvocation = _reflection.GeneratedProtocolMessageType('SDKMethodInvocation', (_message.Message,), {
  'DESCRIPTOR' : _SDKMETHODINVOCATION,
  '__module__' : 'tecton_proto.amplitude.client_logging_pb2'
  # @@protoc_insertion_point(class_scope:tecton_proto.amplitude.SDKMethodInvocation)
  })
_sym_db.RegisterMessage(SDKMethodInvocation)


DESCRIPTOR._options = None
# @@protoc_insertion_point(module_scope)
