# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: tecton_proto/amplitude/amplitude.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import duration_pb2 as google_dot_protobuf_dot_duration__pb2
from tecton_proto.amplitude import client_logging_pb2 as tecton__proto_dot_amplitude_dot_client__logging__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='tecton_proto/amplitude/amplitude.proto',
  package='tecton_proto.amplitude',
  syntax='proto2',
  serialized_options=b'\n\024com.tecton.amplitudeP\001',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n&tecton_proto/amplitude/amplitude.proto\x12\x16tecton_proto.amplitude\x1a\x1egoogle/protobuf/duration.proto\x1a+tecton_proto/amplitude/client_logging.proto\"\x9b\x02\n\x0e\x41mplitudeEvent\x12\x17\n\x07user_id\x18\x01 \x01(\tR\x06userId\x12\x1b\n\tdevice_id\x18\x08 \x01(\tR\x08\x64\x65viceId\x12\x1d\n\nevent_type\x18\x02 \x01(\tR\teventType\x12\x1a\n\x08platform\x18\x03 \x01(\tR\x08platform\x12\x1d\n\nsession_id\x18\x05 \x01(\x03R\tsessionId\x12\x1c\n\ttimestamp\x18\x06 \x01(\x03R\ttimestamp\x12[\n\x10\x65vent_properties\x18\x07 \x01(\x0b\x32\x30.tecton_proto.amplitude.AmplitudeEventPropertiesR\x0f\x65ventProperties\"\xae\x03\n\x18\x41mplitudeEventProperties\x12!\n\x0c\x63luster_name\x18\x01 \x01(\tR\x0b\x63lusterName\x12\x1c\n\tworkspace\x18\x02 \x01(\tR\tworkspace\x12\x1f\n\x0bsdk_version\x18\x04 \x01(\tR\nsdkVersion\x12@\n\x0e\x65xecution_time\x18\x05 \x01(\x0b\x32\x19.google.protobuf.DurationR\rexecutionTime\x12$\n\x0enum_total_fcos\x18\x06 \x01(\x03R\x0cnumTotalFcos\x12(\n\x10num_fcos_changed\x18\x07 \x01(\x03R\x0enumFcosChanged\x12\x18\n\x07success\x18\x08 \x01(\x08R\x07success\x12#\n\rerror_message\x18\t \x01(\tR\x0c\x65rrorMessage\x12_\n\x15sdk_method_invocation\x18\x03 \x01(\x0b\x32+.tecton_proto.amplitude.SDKMethodInvocationR\x13sdkMethodInvocation\"h\n\rUploadRequest\x12\x17\n\x07\x61pi_key\x18\x01 \x01(\tR\x06\x61piKey\x12>\n\x06\x65vents\x18\x02 \x03(\x0b\x32&.tecton_proto.amplitude.AmplitudeEventR\x06\x65vents\"\xe4\x01\n\x0eUploadResponse\x12\x12\n\x04\x63ode\x18\x01 \x01(\x05R\x04\x63ode\x12\'\n\x0f\x65vents_ingested\x18\x02 \x01(\x05R\x0e\x65ventsIngested\x12,\n\x12payload_size_bytes\x18\x03 \x01(\x05R\x10payloadSizeBytes\x12,\n\x12server_upload_time\x18\x04 \x01(\x03R\x10serverUploadTime\x12\x14\n\x05\x65rror\x18\x05 \x01(\tR\x05\x65rror\x12#\n\rmissing_field\x18\x06 \x01(\tR\x0cmissingFieldB\x18\n\x14\x63om.tecton.amplitudeP\x01'
  ,
  dependencies=[google_dot_protobuf_dot_duration__pb2.DESCRIPTOR,tecton__proto_dot_amplitude_dot_client__logging__pb2.DESCRIPTOR,])




_AMPLITUDEEVENT = _descriptor.Descriptor(
  name='AmplitudeEvent',
  full_name='tecton_proto.amplitude.AmplitudeEvent',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='user_id', full_name='tecton_proto.amplitude.AmplitudeEvent.user_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='userId', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='device_id', full_name='tecton_proto.amplitude.AmplitudeEvent.device_id', index=1,
      number=8, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='deviceId', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='event_type', full_name='tecton_proto.amplitude.AmplitudeEvent.event_type', index=2,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='eventType', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='platform', full_name='tecton_proto.amplitude.AmplitudeEvent.platform', index=3,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='platform', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='session_id', full_name='tecton_proto.amplitude.AmplitudeEvent.session_id', index=4,
      number=5, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='sessionId', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='timestamp', full_name='tecton_proto.amplitude.AmplitudeEvent.timestamp', index=5,
      number=6, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='timestamp', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='event_properties', full_name='tecton_proto.amplitude.AmplitudeEvent.event_properties', index=6,
      number=7, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='eventProperties', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=144,
  serialized_end=427,
)


_AMPLITUDEEVENTPROPERTIES = _descriptor.Descriptor(
  name='AmplitudeEventProperties',
  full_name='tecton_proto.amplitude.AmplitudeEventProperties',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='cluster_name', full_name='tecton_proto.amplitude.AmplitudeEventProperties.cluster_name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='clusterName', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='workspace', full_name='tecton_proto.amplitude.AmplitudeEventProperties.workspace', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='workspace', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='sdk_version', full_name='tecton_proto.amplitude.AmplitudeEventProperties.sdk_version', index=2,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='sdkVersion', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='execution_time', full_name='tecton_proto.amplitude.AmplitudeEventProperties.execution_time', index=3,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='executionTime', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='num_total_fcos', full_name='tecton_proto.amplitude.AmplitudeEventProperties.num_total_fcos', index=4,
      number=6, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='numTotalFcos', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='num_fcos_changed', full_name='tecton_proto.amplitude.AmplitudeEventProperties.num_fcos_changed', index=5,
      number=7, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='numFcosChanged', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='success', full_name='tecton_proto.amplitude.AmplitudeEventProperties.success', index=6,
      number=8, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='success', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='error_message', full_name='tecton_proto.amplitude.AmplitudeEventProperties.error_message', index=7,
      number=9, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='errorMessage', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='sdk_method_invocation', full_name='tecton_proto.amplitude.AmplitudeEventProperties.sdk_method_invocation', index=8,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='sdkMethodInvocation', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=430,
  serialized_end=860,
)


_UPLOADREQUEST = _descriptor.Descriptor(
  name='UploadRequest',
  full_name='tecton_proto.amplitude.UploadRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='api_key', full_name='tecton_proto.amplitude.UploadRequest.api_key', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='apiKey', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='events', full_name='tecton_proto.amplitude.UploadRequest.events', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='events', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=862,
  serialized_end=966,
)


_UPLOADRESPONSE = _descriptor.Descriptor(
  name='UploadResponse',
  full_name='tecton_proto.amplitude.UploadResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='code', full_name='tecton_proto.amplitude.UploadResponse.code', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='code', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='events_ingested', full_name='tecton_proto.amplitude.UploadResponse.events_ingested', index=1,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='eventsIngested', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='payload_size_bytes', full_name='tecton_proto.amplitude.UploadResponse.payload_size_bytes', index=2,
      number=3, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='payloadSizeBytes', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='server_upload_time', full_name='tecton_proto.amplitude.UploadResponse.server_upload_time', index=3,
      number=4, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='serverUploadTime', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='error', full_name='tecton_proto.amplitude.UploadResponse.error', index=4,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='error', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='missing_field', full_name='tecton_proto.amplitude.UploadResponse.missing_field', index=5,
      number=6, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='missingField', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=969,
  serialized_end=1197,
)

_AMPLITUDEEVENT.fields_by_name['event_properties'].message_type = _AMPLITUDEEVENTPROPERTIES
_AMPLITUDEEVENTPROPERTIES.fields_by_name['execution_time'].message_type = google_dot_protobuf_dot_duration__pb2._DURATION
_AMPLITUDEEVENTPROPERTIES.fields_by_name['sdk_method_invocation'].message_type = tecton__proto_dot_amplitude_dot_client__logging__pb2._SDKMETHODINVOCATION
_UPLOADREQUEST.fields_by_name['events'].message_type = _AMPLITUDEEVENT
DESCRIPTOR.message_types_by_name['AmplitudeEvent'] = _AMPLITUDEEVENT
DESCRIPTOR.message_types_by_name['AmplitudeEventProperties'] = _AMPLITUDEEVENTPROPERTIES
DESCRIPTOR.message_types_by_name['UploadRequest'] = _UPLOADREQUEST
DESCRIPTOR.message_types_by_name['UploadResponse'] = _UPLOADRESPONSE
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

AmplitudeEvent = _reflection.GeneratedProtocolMessageType('AmplitudeEvent', (_message.Message,), {
  'DESCRIPTOR' : _AMPLITUDEEVENT,
  '__module__' : 'tecton_proto.amplitude.amplitude_pb2'
  # @@protoc_insertion_point(class_scope:tecton_proto.amplitude.AmplitudeEvent)
  })
_sym_db.RegisterMessage(AmplitudeEvent)

AmplitudeEventProperties = _reflection.GeneratedProtocolMessageType('AmplitudeEventProperties', (_message.Message,), {
  'DESCRIPTOR' : _AMPLITUDEEVENTPROPERTIES,
  '__module__' : 'tecton_proto.amplitude.amplitude_pb2'
  # @@protoc_insertion_point(class_scope:tecton_proto.amplitude.AmplitudeEventProperties)
  })
_sym_db.RegisterMessage(AmplitudeEventProperties)

UploadRequest = _reflection.GeneratedProtocolMessageType('UploadRequest', (_message.Message,), {
  'DESCRIPTOR' : _UPLOADREQUEST,
  '__module__' : 'tecton_proto.amplitude.amplitude_pb2'
  # @@protoc_insertion_point(class_scope:tecton_proto.amplitude.UploadRequest)
  })
_sym_db.RegisterMessage(UploadRequest)

UploadResponse = _reflection.GeneratedProtocolMessageType('UploadResponse', (_message.Message,), {
  'DESCRIPTOR' : _UPLOADRESPONSE,
  '__module__' : 'tecton_proto.amplitude.amplitude_pb2'
  # @@protoc_insertion_point(class_scope:tecton_proto.amplitude.UploadResponse)
  })
_sym_db.RegisterMessage(UploadResponse)


DESCRIPTOR._options = None
# @@protoc_insertion_point(module_scope)
