# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: tecton_proto/data/virtual_data_source.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from tecton_proto.data import batch_data_source_pb2 as tecton__proto_dot_data_dot_batch__data__source__pb2
from tecton_proto.data import fco_metadata_pb2 as tecton__proto_dot_data_dot_fco__metadata__pb2
from tecton_proto.common import id_pb2 as tecton__proto_dot_common_dot_id__pb2
from tecton_proto.data import stream_data_source_pb2 as tecton__proto_dot_data_dot_stream__data__source__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='tecton_proto/data/virtual_data_source.proto',
  package='tecton_proto.data',
  syntax='proto2',
  serialized_options=b'\n\017com.tecton.dataP\001',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n+tecton_proto/data/virtual_data_source.proto\x12\x11tecton_proto.data\x1a)tecton_proto/data/batch_data_source.proto\x1a$tecton_proto/data/fco_metadata.proto\x1a\x1ctecton_proto/common/id.proto\x1a*tecton_proto/data/stream_data_source.proto\"\xd9\x02\n\x11VirtualDataSource\x12L\n\x16virtual_data_source_id\x18\x01 \x01(\x0b\x32\x17.tecton_proto.common.IdR\x13virtualDataSourceId\x12N\n\x11\x62\x61tch_data_source\x18\x04 \x01(\x0b\x32\".tecton_proto.data.BatchDataSourceR\x0f\x62\x61tchDataSource\x12Q\n\x12stream_data_source\x18\x05 \x01(\x0b\x32#.tecton_proto.data.StreamDataSourceR\x10streamDataSource\x12\x41\n\x0c\x66\x63o_metadata\x18\x07 \x01(\x0b\x32\x1e.tecton_proto.data.FcoMetadataR\x0b\x66\x63oMetadataJ\x04\x08\x02\x10\x03J\x04\x08\x03\x10\x04J\x04\x08\x08\x10\tB\x13\n\x0f\x63om.tecton.dataP\x01'
  ,
  dependencies=[tecton__proto_dot_data_dot_batch__data__source__pb2.DESCRIPTOR,tecton__proto_dot_data_dot_fco__metadata__pb2.DESCRIPTOR,tecton__proto_dot_common_dot_id__pb2.DESCRIPTOR,tecton__proto_dot_data_dot_stream__data__source__pb2.DESCRIPTOR,])




_VIRTUALDATASOURCE = _descriptor.Descriptor(
  name='VirtualDataSource',
  full_name='tecton_proto.data.VirtualDataSource',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='virtual_data_source_id', full_name='tecton_proto.data.VirtualDataSource.virtual_data_source_id', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='virtualDataSourceId', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='batch_data_source', full_name='tecton_proto.data.VirtualDataSource.batch_data_source', index=1,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='batchDataSource', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='stream_data_source', full_name='tecton_proto.data.VirtualDataSource.stream_data_source', index=2,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='streamDataSource', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='fco_metadata', full_name='tecton_proto.data.VirtualDataSource.fco_metadata', index=3,
      number=7, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='fcoMetadata', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=222,
  serialized_end=567,
)

_VIRTUALDATASOURCE.fields_by_name['virtual_data_source_id'].message_type = tecton__proto_dot_common_dot_id__pb2._ID
_VIRTUALDATASOURCE.fields_by_name['batch_data_source'].message_type = tecton__proto_dot_data_dot_batch__data__source__pb2._BATCHDATASOURCE
_VIRTUALDATASOURCE.fields_by_name['stream_data_source'].message_type = tecton__proto_dot_data_dot_stream__data__source__pb2._STREAMDATASOURCE
_VIRTUALDATASOURCE.fields_by_name['fco_metadata'].message_type = tecton__proto_dot_data_dot_fco__metadata__pb2._FCOMETADATA
DESCRIPTOR.message_types_by_name['VirtualDataSource'] = _VIRTUALDATASOURCE
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

VirtualDataSource = _reflection.GeneratedProtocolMessageType('VirtualDataSource', (_message.Message,), {
  'DESCRIPTOR' : _VIRTUALDATASOURCE,
  '__module__' : 'tecton_proto.data.virtual_data_source_pb2'
  # @@protoc_insertion_point(class_scope:tecton_proto.data.VirtualDataSource)
  })
_sym_db.RegisterMessage(VirtualDataSource)


DESCRIPTOR._options = None
# @@protoc_insertion_point(module_scope)
