# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: tecton_proto/data/batch_data_source.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from tecton_proto.args import data_source_pb2 as tecton__proto_dot_args_dot_data__source__pb2
from tecton_proto.args import data_source_config_pb2 as tecton__proto_dot_args_dot_data__source__config__pb2
from tecton_proto.args import user_defined_function_pb2 as tecton__proto_dot_args_dot_user__defined__function__pb2
from tecton_proto.common import spark_schema_pb2 as tecton__proto_dot_common_dot_spark__schema__pb2
from tecton_proto.data import hive_metastore_pb2 as tecton__proto_dot_data_dot_hive__metastore__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='tecton_proto/data/batch_data_source.proto',
  package='tecton_proto.data',
  syntax='proto2',
  serialized_options=b'\n\017com.tecton.dataP\001',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n)tecton_proto/data/batch_data_source.proto\x12\x11tecton_proto.data\x1a#tecton_proto/args/data_source.proto\x1a*tecton_proto/args/data_source_config.proto\x1a-tecton_proto/args/user_defined_function.proto\x1a&tecton_proto/common/spark_schema.proto\x1a&tecton_proto/data/hive_metastore.proto\"T\n\x19TimestampColumnProperties\x12\x1f\n\x0b\x63olumn_name\x18\x01 \x01(\tR\ncolumnName\x12\x16\n\x06\x66ormat\x18\x02 \x01(\tR\x06\x66ormat\"\xa9\x06\n\x0f\x42\x61tchDataSource\x12G\n\nhive_table\x18\x01 \x01(\x0b\x32&.tecton_proto.data.HiveTableDataSourceH\x00R\thiveTable\x12\x37\n\x04\x66ile\x18\x08 \x01(\x0b\x32!.tecton_proto.data.FileDataSourceH\x00R\x04\x66ile\x12H\n\x0bredshift_db\x18\x0b \x01(\x0b\x32%.tecton_proto.data.RedshiftDataSourceH\x00R\nredshiftDb\x12\x46\n\tsnowflake\x18\x0c \x01(\x0b\x32&.tecton_proto.data.SnowflakeDataSourceH\x00R\tsnowflake\x12\x43\n\x0cspark_schema\x18\t \x01(\x0b\x32 .tecton_proto.common.SparkSchemaR\x0bsparkSchema\x12l\n\x1btimestamp_column_properties\x18\x04 \x01(\x0b\x32,.tecton_proto.data.TimestampColumnPropertiesR\x19timestampColumnProperties\x12\x41\n\x0c\x62\x61tch_config\x18\x05 \x01(\x0b\x32\x1e.tecton_proto.args.BatchConfigR\x0b\x62\x61tchConfig\x12\x32\n\x15\x64\x61te_partition_column\x18\x06 \x01(\tR\x13\x64\x61tePartitionColumn\x12h\n\x1a\x64\x61tetime_partition_columns\x18\x07 \x03(\x0b\x32*.tecton_proto.data.DatetimePartitionColumnR\x18\x64\x61tetimePartitionColumns\x12X\n\x14raw_batch_translator\x18\n \x01(\x0b\x32&.tecton_proto.args.UserDefinedFunctionR\x12rawBatchTranslatorB\x0e\n\x0c\x62\x61tch_sourceJ\x04\x08\x02\x10\x03\"\x88\x02\n\x0e\x46ileDataSource\x12\x10\n\x03uri\x18\x01 \x02(\tR\x03uri\x12?\n\x06\x66ormat\x18\x02 \x02(\x0e\x32\'.tecton_proto.data.FileDataSourceFormatR\x06\x66ormat\x12\x33\n\x16\x63onvert_to_glue_format\x18\x04 \x01(\x08R\x13\x63onvertToGlueFormat\x12\x1d\n\nschema_uri\x18\x05 \x01(\tR\tschemaUri\x12I\n\x0fschema_override\x18\x06 \x01(\x0b\x32 .tecton_proto.common.SparkSchemaR\x0eschemaOverrideJ\x04\x08\x03\x10\x04\"\x88\x01\n\x17\x44\x61tetimePartitionColumn\x12\x1f\n\x0b\x63olumn_name\x18\x01 \x02(\tR\ncolumnName\x12#\n\rformat_string\x18\x02 \x02(\tR\x0c\x66ormatString\x12\'\n\x0fminimum_seconds\x18\x03 \x02(\x03R\x0eminimumSeconds\"\xbe\x01\n\x12RedshiftDataSource\x12\x1a\n\x08\x65ndpoint\x18\x01 \x01(\tR\x08\x65ndpoint\x12\x1d\n\ncluster_id\x18\x02 \x01(\tR\tclusterId\x12\x1a\n\x08\x64\x61tabase\x18\x03 \x01(\tR\x08\x64\x61tabase\x12\x16\n\x05table\x18\x04 \x01(\tH\x00R\x05table\x12\x16\n\x05query\x18\x06 \x01(\tH\x00R\x05query\x12\x17\n\x07temp_s3\x18\x05 \x01(\tR\x06tempS3B\x08\n\x06source\"g\n\x13SnowflakeDataSource\x12P\n\rsnowflakeArgs\x18\x01 \x01(\x0b\x32*.tecton_proto.args.SnowflakeDataSourceArgsR\rsnowflakeArgs*~\n\x14\x46ileDataSourceFormat\x12 \n\x1c\x46ILE_DATA_SOURCE_FORMAT_JSON\x10\x00\x12#\n\x1f\x46ILE_DATA_SOURCE_FORMAT_PARQUET\x10\x01\x12\x1f\n\x1b\x46ILE_DATA_SOURCE_FORMAT_CSV\x10\x02\x42\x13\n\x0f\x63om.tecton.dataP\x01'
  ,
  dependencies=[tecton__proto_dot_args_dot_data__source__pb2.DESCRIPTOR,tecton__proto_dot_args_dot_data__source__config__pb2.DESCRIPTOR,tecton__proto_dot_args_dot_user__defined__function__pb2.DESCRIPTOR,tecton__proto_dot_common_dot_spark__schema__pb2.DESCRIPTOR,tecton__proto_dot_data_dot_hive__metastore__pb2.DESCRIPTOR,])

_FILEDATASOURCEFORMAT = _descriptor.EnumDescriptor(
  name='FileDataSourceFormat',
  full_name='tecton_proto.data.FileDataSourceFormat',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='FILE_DATA_SOURCE_FORMAT_JSON', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='FILE_DATA_SOURCE_FORMAT_PARQUET', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='FILE_DATA_SOURCE_FORMAT_CSV', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=1874,
  serialized_end=2000,
)
_sym_db.RegisterEnumDescriptor(_FILEDATASOURCEFORMAT)

FileDataSourceFormat = enum_type_wrapper.EnumTypeWrapper(_FILEDATASOURCEFORMAT)
FILE_DATA_SOURCE_FORMAT_JSON = 0
FILE_DATA_SOURCE_FORMAT_PARQUET = 1
FILE_DATA_SOURCE_FORMAT_CSV = 2



_TIMESTAMPCOLUMNPROPERTIES = _descriptor.Descriptor(
  name='TimestampColumnProperties',
  full_name='tecton_proto.data.TimestampColumnProperties',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='column_name', full_name='tecton_proto.data.TimestampColumnProperties.column_name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='columnName', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='format', full_name='tecton_proto.data.TimestampColumnProperties.format', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='format', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=272,
  serialized_end=356,
)


_BATCHDATASOURCE = _descriptor.Descriptor(
  name='BatchDataSource',
  full_name='tecton_proto.data.BatchDataSource',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='hive_table', full_name='tecton_proto.data.BatchDataSource.hive_table', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='hiveTable', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='file', full_name='tecton_proto.data.BatchDataSource.file', index=1,
      number=8, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='file', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='redshift_db', full_name='tecton_proto.data.BatchDataSource.redshift_db', index=2,
      number=11, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='redshiftDb', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='snowflake', full_name='tecton_proto.data.BatchDataSource.snowflake', index=3,
      number=12, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='snowflake', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='spark_schema', full_name='tecton_proto.data.BatchDataSource.spark_schema', index=4,
      number=9, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='sparkSchema', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='timestamp_column_properties', full_name='tecton_proto.data.BatchDataSource.timestamp_column_properties', index=5,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='timestampColumnProperties', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='batch_config', full_name='tecton_proto.data.BatchDataSource.batch_config', index=6,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='batchConfig', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='date_partition_column', full_name='tecton_proto.data.BatchDataSource.date_partition_column', index=7,
      number=6, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='datePartitionColumn', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='datetime_partition_columns', full_name='tecton_proto.data.BatchDataSource.datetime_partition_columns', index=8,
      number=7, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='datetimePartitionColumns', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='raw_batch_translator', full_name='tecton_proto.data.BatchDataSource.raw_batch_translator', index=9,
      number=10, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='rawBatchTranslator', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='batch_source', full_name='tecton_proto.data.BatchDataSource.batch_source',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=359,
  serialized_end=1168,
)


_FILEDATASOURCE = _descriptor.Descriptor(
  name='FileDataSource',
  full_name='tecton_proto.data.FileDataSource',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='uri', full_name='tecton_proto.data.FileDataSource.uri', index=0,
      number=1, type=9, cpp_type=9, label=2,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='uri', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='format', full_name='tecton_proto.data.FileDataSource.format', index=1,
      number=2, type=14, cpp_type=8, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='format', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='convert_to_glue_format', full_name='tecton_proto.data.FileDataSource.convert_to_glue_format', index=2,
      number=4, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='convertToGlueFormat', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='schema_uri', full_name='tecton_proto.data.FileDataSource.schema_uri', index=3,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='schemaUri', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='schema_override', full_name='tecton_proto.data.FileDataSource.schema_override', index=4,
      number=6, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='schemaOverride', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1171,
  serialized_end=1435,
)


_DATETIMEPARTITIONCOLUMN = _descriptor.Descriptor(
  name='DatetimePartitionColumn',
  full_name='tecton_proto.data.DatetimePartitionColumn',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='column_name', full_name='tecton_proto.data.DatetimePartitionColumn.column_name', index=0,
      number=1, type=9, cpp_type=9, label=2,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='columnName', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='format_string', full_name='tecton_proto.data.DatetimePartitionColumn.format_string', index=1,
      number=2, type=9, cpp_type=9, label=2,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='formatString', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='minimum_seconds', full_name='tecton_proto.data.DatetimePartitionColumn.minimum_seconds', index=2,
      number=3, type=3, cpp_type=2, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='minimumSeconds', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1438,
  serialized_end=1574,
)


_REDSHIFTDATASOURCE = _descriptor.Descriptor(
  name='RedshiftDataSource',
  full_name='tecton_proto.data.RedshiftDataSource',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='endpoint', full_name='tecton_proto.data.RedshiftDataSource.endpoint', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='endpoint', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='cluster_id', full_name='tecton_proto.data.RedshiftDataSource.cluster_id', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='clusterId', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='database', full_name='tecton_proto.data.RedshiftDataSource.database', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='database', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='table', full_name='tecton_proto.data.RedshiftDataSource.table', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='table', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='query', full_name='tecton_proto.data.RedshiftDataSource.query', index=4,
      number=6, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='query', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='temp_s3', full_name='tecton_proto.data.RedshiftDataSource.temp_s3', index=5,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='tempS3', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='source', full_name='tecton_proto.data.RedshiftDataSource.source',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=1577,
  serialized_end=1767,
)


_SNOWFLAKEDATASOURCE = _descriptor.Descriptor(
  name='SnowflakeDataSource',
  full_name='tecton_proto.data.SnowflakeDataSource',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='snowflakeArgs', full_name='tecton_proto.data.SnowflakeDataSource.snowflakeArgs', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='snowflakeArgs', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1769,
  serialized_end=1872,
)

_BATCHDATASOURCE.fields_by_name['hive_table'].message_type = tecton__proto_dot_data_dot_hive__metastore__pb2._HIVETABLEDATASOURCE
_BATCHDATASOURCE.fields_by_name['file'].message_type = _FILEDATASOURCE
_BATCHDATASOURCE.fields_by_name['redshift_db'].message_type = _REDSHIFTDATASOURCE
_BATCHDATASOURCE.fields_by_name['snowflake'].message_type = _SNOWFLAKEDATASOURCE
_BATCHDATASOURCE.fields_by_name['spark_schema'].message_type = tecton__proto_dot_common_dot_spark__schema__pb2._SPARKSCHEMA
_BATCHDATASOURCE.fields_by_name['timestamp_column_properties'].message_type = _TIMESTAMPCOLUMNPROPERTIES
_BATCHDATASOURCE.fields_by_name['batch_config'].message_type = tecton__proto_dot_args_dot_data__source__config__pb2._BATCHCONFIG
_BATCHDATASOURCE.fields_by_name['datetime_partition_columns'].message_type = _DATETIMEPARTITIONCOLUMN
_BATCHDATASOURCE.fields_by_name['raw_batch_translator'].message_type = tecton__proto_dot_args_dot_user__defined__function__pb2._USERDEFINEDFUNCTION
_BATCHDATASOURCE.oneofs_by_name['batch_source'].fields.append(
  _BATCHDATASOURCE.fields_by_name['hive_table'])
_BATCHDATASOURCE.fields_by_name['hive_table'].containing_oneof = _BATCHDATASOURCE.oneofs_by_name['batch_source']
_BATCHDATASOURCE.oneofs_by_name['batch_source'].fields.append(
  _BATCHDATASOURCE.fields_by_name['file'])
_BATCHDATASOURCE.fields_by_name['file'].containing_oneof = _BATCHDATASOURCE.oneofs_by_name['batch_source']
_BATCHDATASOURCE.oneofs_by_name['batch_source'].fields.append(
  _BATCHDATASOURCE.fields_by_name['redshift_db'])
_BATCHDATASOURCE.fields_by_name['redshift_db'].containing_oneof = _BATCHDATASOURCE.oneofs_by_name['batch_source']
_BATCHDATASOURCE.oneofs_by_name['batch_source'].fields.append(
  _BATCHDATASOURCE.fields_by_name['snowflake'])
_BATCHDATASOURCE.fields_by_name['snowflake'].containing_oneof = _BATCHDATASOURCE.oneofs_by_name['batch_source']
_FILEDATASOURCE.fields_by_name['format'].enum_type = _FILEDATASOURCEFORMAT
_FILEDATASOURCE.fields_by_name['schema_override'].message_type = tecton__proto_dot_common_dot_spark__schema__pb2._SPARKSCHEMA
_REDSHIFTDATASOURCE.oneofs_by_name['source'].fields.append(
  _REDSHIFTDATASOURCE.fields_by_name['table'])
_REDSHIFTDATASOURCE.fields_by_name['table'].containing_oneof = _REDSHIFTDATASOURCE.oneofs_by_name['source']
_REDSHIFTDATASOURCE.oneofs_by_name['source'].fields.append(
  _REDSHIFTDATASOURCE.fields_by_name['query'])
_REDSHIFTDATASOURCE.fields_by_name['query'].containing_oneof = _REDSHIFTDATASOURCE.oneofs_by_name['source']
_SNOWFLAKEDATASOURCE.fields_by_name['snowflakeArgs'].message_type = tecton__proto_dot_args_dot_data__source__pb2._SNOWFLAKEDATASOURCEARGS
DESCRIPTOR.message_types_by_name['TimestampColumnProperties'] = _TIMESTAMPCOLUMNPROPERTIES
DESCRIPTOR.message_types_by_name['BatchDataSource'] = _BATCHDATASOURCE
DESCRIPTOR.message_types_by_name['FileDataSource'] = _FILEDATASOURCE
DESCRIPTOR.message_types_by_name['DatetimePartitionColumn'] = _DATETIMEPARTITIONCOLUMN
DESCRIPTOR.message_types_by_name['RedshiftDataSource'] = _REDSHIFTDATASOURCE
DESCRIPTOR.message_types_by_name['SnowflakeDataSource'] = _SNOWFLAKEDATASOURCE
DESCRIPTOR.enum_types_by_name['FileDataSourceFormat'] = _FILEDATASOURCEFORMAT
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

TimestampColumnProperties = _reflection.GeneratedProtocolMessageType('TimestampColumnProperties', (_message.Message,), {
  'DESCRIPTOR' : _TIMESTAMPCOLUMNPROPERTIES,
  '__module__' : 'tecton_proto.data.batch_data_source_pb2'
  # @@protoc_insertion_point(class_scope:tecton_proto.data.TimestampColumnProperties)
  })
_sym_db.RegisterMessage(TimestampColumnProperties)

BatchDataSource = _reflection.GeneratedProtocolMessageType('BatchDataSource', (_message.Message,), {
  'DESCRIPTOR' : _BATCHDATASOURCE,
  '__module__' : 'tecton_proto.data.batch_data_source_pb2'
  # @@protoc_insertion_point(class_scope:tecton_proto.data.BatchDataSource)
  })
_sym_db.RegisterMessage(BatchDataSource)

FileDataSource = _reflection.GeneratedProtocolMessageType('FileDataSource', (_message.Message,), {
  'DESCRIPTOR' : _FILEDATASOURCE,
  '__module__' : 'tecton_proto.data.batch_data_source_pb2'
  # @@protoc_insertion_point(class_scope:tecton_proto.data.FileDataSource)
  })
_sym_db.RegisterMessage(FileDataSource)

DatetimePartitionColumn = _reflection.GeneratedProtocolMessageType('DatetimePartitionColumn', (_message.Message,), {
  'DESCRIPTOR' : _DATETIMEPARTITIONCOLUMN,
  '__module__' : 'tecton_proto.data.batch_data_source_pb2'
  # @@protoc_insertion_point(class_scope:tecton_proto.data.DatetimePartitionColumn)
  })
_sym_db.RegisterMessage(DatetimePartitionColumn)

RedshiftDataSource = _reflection.GeneratedProtocolMessageType('RedshiftDataSource', (_message.Message,), {
  'DESCRIPTOR' : _REDSHIFTDATASOURCE,
  '__module__' : 'tecton_proto.data.batch_data_source_pb2'
  # @@protoc_insertion_point(class_scope:tecton_proto.data.RedshiftDataSource)
  })
_sym_db.RegisterMessage(RedshiftDataSource)

SnowflakeDataSource = _reflection.GeneratedProtocolMessageType('SnowflakeDataSource', (_message.Message,), {
  'DESCRIPTOR' : _SNOWFLAKEDATASOURCE,
  '__module__' : 'tecton_proto.data.batch_data_source_pb2'
  # @@protoc_insertion_point(class_scope:tecton_proto.data.SnowflakeDataSource)
  })
_sym_db.RegisterMessage(SnowflakeDataSource)


DESCRIPTOR._options = None
# @@protoc_insertion_point(module_scope)
