# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: tecton_proto/data/fco.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from tecton_proto.common import id_pb2 as tecton__proto_dot_common_dot_id__pb2
from tecton_proto.data import entity_pb2 as tecton__proto_dot_data_dot_entity__pb2
from tecton_proto.data import virtual_data_source_pb2 as tecton__proto_dot_data_dot_virtual__data__source__pb2
from tecton_proto.data import feature_view_pb2 as tecton__proto_dot_data_dot_feature__view__pb2
from tecton_proto.data import feature_service_pb2 as tecton__proto_dot_data_dot_feature__service__pb2
from tecton_proto.data import new_transformation_pb2 as tecton__proto_dot_data_dot_new__transformation__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='tecton_proto/data/fco.proto',
  package='tecton_proto.data',
  syntax='proto2',
  serialized_options=b'\n\017com.tecton.dataP\001',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n\x1btecton_proto/data/fco.proto\x12\x11tecton_proto.data\x1a\x1ctecton_proto/common/id.proto\x1a\x1etecton_proto/data/entity.proto\x1a+tecton_proto/data/virtual_data_source.proto\x1a$tecton_proto/data/feature_view.proto\x1a\'tecton_proto/data/feature_service.proto\x1a*tecton_proto/data/new_transformation.proto\"\x8f\x03\n\x03\x46\x63o\x12V\n\x13virtual_data_source\x18\x01 \x01(\x0b\x32$.tecton_proto.data.VirtualDataSourceH\x00R\x11virtualDataSource\x12\x33\n\x06\x65ntity\x18\x02 \x01(\x0b\x32\x19.tecton_proto.data.EntityH\x00R\x06\x65ntity\x12\x43\n\x0c\x66\x65\x61ture_view\x18\x06 \x01(\x0b\x32\x1e.tecton_proto.data.FeatureViewH\x00R\x0b\x66\x65\x61tureView\x12L\n\x0f\x66\x65\x61ture_service\x18\x04 \x01(\x0b\x32!.tecton_proto.data.FeatureServiceH\x00R\x0e\x66\x65\x61tureService\x12U\n\x12new_transformation\x18\x07 \x01(\x0b\x32$.tecton_proto.data.NewTransformationH\x00R\x11newTransformationB\x05\n\x03\x66\x63oJ\x04\x08\x03\x10\x04J\x04\x08\x05\x10\x06\"n\n\x0c\x46\x63oContainer\x12\x32\n\x08root_ids\x18\x01 \x03(\x0b\x32\x17.tecton_proto.common.IdR\x07rootIds\x12*\n\x04\x66\x63os\x18\x02 \x03(\x0b\x32\x16.tecton_proto.data.FcoR\x04\x66\x63osB\x13\n\x0f\x63om.tecton.dataP\x01'
  ,
  dependencies=[tecton__proto_dot_common_dot_id__pb2.DESCRIPTOR,tecton__proto_dot_data_dot_entity__pb2.DESCRIPTOR,tecton__proto_dot_data_dot_virtual__data__source__pb2.DESCRIPTOR,tecton__proto_dot_data_dot_feature__view__pb2.DESCRIPTOR,tecton__proto_dot_data_dot_feature__service__pb2.DESCRIPTOR,tecton__proto_dot_data_dot_new__transformation__pb2.DESCRIPTOR,])




_FCO = _descriptor.Descriptor(
  name='Fco',
  full_name='tecton_proto.data.Fco',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='virtual_data_source', full_name='tecton_proto.data.Fco.virtual_data_source', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='virtualDataSource', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='entity', full_name='tecton_proto.data.Fco.entity', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='entity', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='feature_view', full_name='tecton_proto.data.Fco.feature_view', index=2,
      number=6, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='featureView', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='feature_service', full_name='tecton_proto.data.Fco.feature_service', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='featureService', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='new_transformation', full_name='tecton_proto.data.Fco.new_transformation', index=4,
      number=7, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='newTransformation', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='fco', full_name='tecton_proto.data.Fco.fco',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=281,
  serialized_end=680,
)


_FCOCONTAINER = _descriptor.Descriptor(
  name='FcoContainer',
  full_name='tecton_proto.data.FcoContainer',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='root_ids', full_name='tecton_proto.data.FcoContainer.root_ids', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='rootIds', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='fcos', full_name='tecton_proto.data.FcoContainer.fcos', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='fcos', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=682,
  serialized_end=792,
)

_FCO.fields_by_name['virtual_data_source'].message_type = tecton__proto_dot_data_dot_virtual__data__source__pb2._VIRTUALDATASOURCE
_FCO.fields_by_name['entity'].message_type = tecton__proto_dot_data_dot_entity__pb2._ENTITY
_FCO.fields_by_name['feature_view'].message_type = tecton__proto_dot_data_dot_feature__view__pb2._FEATUREVIEW
_FCO.fields_by_name['feature_service'].message_type = tecton__proto_dot_data_dot_feature__service__pb2._FEATURESERVICE
_FCO.fields_by_name['new_transformation'].message_type = tecton__proto_dot_data_dot_new__transformation__pb2._NEWTRANSFORMATION
_FCO.oneofs_by_name['fco'].fields.append(
  _FCO.fields_by_name['virtual_data_source'])
_FCO.fields_by_name['virtual_data_source'].containing_oneof = _FCO.oneofs_by_name['fco']
_FCO.oneofs_by_name['fco'].fields.append(
  _FCO.fields_by_name['entity'])
_FCO.fields_by_name['entity'].containing_oneof = _FCO.oneofs_by_name['fco']
_FCO.oneofs_by_name['fco'].fields.append(
  _FCO.fields_by_name['feature_view'])
_FCO.fields_by_name['feature_view'].containing_oneof = _FCO.oneofs_by_name['fco']
_FCO.oneofs_by_name['fco'].fields.append(
  _FCO.fields_by_name['feature_service'])
_FCO.fields_by_name['feature_service'].containing_oneof = _FCO.oneofs_by_name['fco']
_FCO.oneofs_by_name['fco'].fields.append(
  _FCO.fields_by_name['new_transformation'])
_FCO.fields_by_name['new_transformation'].containing_oneof = _FCO.oneofs_by_name['fco']
_FCOCONTAINER.fields_by_name['root_ids'].message_type = tecton__proto_dot_common_dot_id__pb2._ID
_FCOCONTAINER.fields_by_name['fcos'].message_type = _FCO
DESCRIPTOR.message_types_by_name['Fco'] = _FCO
DESCRIPTOR.message_types_by_name['FcoContainer'] = _FCOCONTAINER
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

Fco = _reflection.GeneratedProtocolMessageType('Fco', (_message.Message,), {
  'DESCRIPTOR' : _FCO,
  '__module__' : 'tecton_proto.data.fco_pb2'
  # @@protoc_insertion_point(class_scope:tecton_proto.data.Fco)
  })
_sym_db.RegisterMessage(Fco)

FcoContainer = _reflection.GeneratedProtocolMessageType('FcoContainer', (_message.Message,), {
  'DESCRIPTOR' : _FCOCONTAINER,
  '__module__' : 'tecton_proto.data.fco_pb2'
  # @@protoc_insertion_point(class_scope:tecton_proto.data.FcoContainer)
  })
_sym_db.RegisterMessage(FcoContainer)


DESCRIPTOR._options = None
# @@protoc_insertion_point(module_scope)
