# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: tecton_proto/data/tecton_api_key.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from tecton_proto.common import id_pb2 as tecton__proto_dot_common_dot_id__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='tecton_proto/data/tecton_api_key.proto',
  package='tecton_proto.data',
  syntax='proto2',
  serialized_options=b'\n\017com.tecton.dataP\001',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n&tecton_proto/data/tecton_api_key.proto\x12\x11tecton_proto.data\x1a\x1ctecton_proto/common/id.proto\"\xf1\x01\n\x0cTectonApiKey\x12\'\n\x02id\x18\x01 \x01(\x0b\x32\x17.tecton_proto.common.IdR\x02id\x12\x1d\n\nhashed_key\x18\x02 \x01(\tR\thashedKey\x12 \n\x0b\x64\x65scription\x18\x03 \x01(\tR\x0b\x64\x65scription\x12\x1a\n\x08\x61rchived\x18\x04 \x01(\x08R\x08\x61rchived\x12\x1d\n\ncreated_by\x18\x05 \x01(\tR\tcreatedBy\x12!\n\x0cobscured_key\x18\x06 \x01(\tR\x0bobscuredKey\x12\x19\n\x08is_admin\x18\x07 \x01(\x08R\x07isAdminB\x13\n\x0f\x63om.tecton.dataP\x01'
  ,
  dependencies=[tecton__proto_dot_common_dot_id__pb2.DESCRIPTOR,])




_TECTONAPIKEY = _descriptor.Descriptor(
  name='TectonApiKey',
  full_name='tecton_proto.data.TectonApiKey',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='id', full_name='tecton_proto.data.TectonApiKey.id', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='id', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='hashed_key', full_name='tecton_proto.data.TectonApiKey.hashed_key', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='hashedKey', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='description', full_name='tecton_proto.data.TectonApiKey.description', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='description', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='archived', full_name='tecton_proto.data.TectonApiKey.archived', index=3,
      number=4, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='archived', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='created_by', full_name='tecton_proto.data.TectonApiKey.created_by', index=4,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='createdBy', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='obscured_key', full_name='tecton_proto.data.TectonApiKey.obscured_key', index=5,
      number=6, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='obscuredKey', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='is_admin', full_name='tecton_proto.data.TectonApiKey.is_admin', index=6,
      number=7, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='isAdmin', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=92,
  serialized_end=333,
)

_TECTONAPIKEY.fields_by_name['id'].message_type = tecton__proto_dot_common_dot_id__pb2._ID
DESCRIPTOR.message_types_by_name['TectonApiKey'] = _TECTONAPIKEY
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

TectonApiKey = _reflection.GeneratedProtocolMessageType('TectonApiKey', (_message.Message,), {
  'DESCRIPTOR' : _TECTONAPIKEY,
  '__module__' : 'tecton_proto.data.tecton_api_key_pb2'
  # @@protoc_insertion_point(class_scope:tecton_proto.data.TectonApiKey)
  })
_sym_db.RegisterMessage(TectonApiKey)


DESCRIPTOR._options = None
# @@protoc_insertion_point(module_scope)
