# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: tecton_proto/data/fv_materialization.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from tecton_proto.common import fco_locator_pb2 as tecton__proto_dot_common_dot_fco__locator__pb2
from tecton_proto.common import id_pb2 as tecton__proto_dot_common_dot_id__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='tecton_proto/data/fv_materialization.proto',
  package='tecton_proto.data',
  syntax='proto2',
  serialized_options=b'\n\017com.tecton.dataP\001',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n*tecton_proto/data/fv_materialization.proto\x12\x11tecton_proto.data\x1a%tecton_proto/common/fco_locator.proto\x1a\x1ctecton_proto/common/id.proto\" \n\nS3Location\x12\x12\n\x04path\x18\x01 \x01(\tR\x04path\"\xed\x03\n\x11\x46vMaterialization\x12Q\n\x14\x66\x65\x61ture_view_locator\x18\t \x01(\x0b\x32\x1f.tecton_proto.common.FcoLocatorR\x12\x66\x65\x61tureViewLocator\x12>\n\x1bmaterialization_workflow_id\x18\x03 \x01(\x05R\x19materializationWorkflowId\x12[\n\x1amaterialized_data_location\x18\x05 \x01(\x0b\x32\x1d.tecton_proto.data.S3LocationR\x18materializedDataLocation\x12\x61\n\x1dstreaming_checkpoint_location\x18\x06 \x01(\x0b\x32\x1d.tecton_proto.data.S3LocationR\x1bstreamingCheckpointLocation\x12\x32\n\x15has_materialized_data\x18\x07 \x01(\x08R\x13hasMaterializedData\x12?\n\x1c\x66\x65\x61ture_store_format_version\x18\x08 \x01(\x05R\x19\x66\x65\x61tureStoreFormatVersionJ\x04\x08\x01\x10\x02J\x04\x08\x02\x10\x03J\x04\x08\x04\x10\x05\x42\x13\n\x0f\x63om.tecton.dataP\x01'
  ,
  dependencies=[tecton__proto_dot_common_dot_fco__locator__pb2.DESCRIPTOR,tecton__proto_dot_common_dot_id__pb2.DESCRIPTOR,])




_S3LOCATION = _descriptor.Descriptor(
  name='S3Location',
  full_name='tecton_proto.data.S3Location',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='path', full_name='tecton_proto.data.S3Location.path', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='path', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=134,
  serialized_end=166,
)


_FVMATERIALIZATION = _descriptor.Descriptor(
  name='FvMaterialization',
  full_name='tecton_proto.data.FvMaterialization',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='feature_view_locator', full_name='tecton_proto.data.FvMaterialization.feature_view_locator', index=0,
      number=9, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='featureViewLocator', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='materialization_workflow_id', full_name='tecton_proto.data.FvMaterialization.materialization_workflow_id', index=1,
      number=3, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='materializationWorkflowId', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='materialized_data_location', full_name='tecton_proto.data.FvMaterialization.materialized_data_location', index=2,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='materializedDataLocation', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='streaming_checkpoint_location', full_name='tecton_proto.data.FvMaterialization.streaming_checkpoint_location', index=3,
      number=6, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='streamingCheckpointLocation', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='has_materialized_data', full_name='tecton_proto.data.FvMaterialization.has_materialized_data', index=4,
      number=7, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='hasMaterializedData', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='feature_store_format_version', full_name='tecton_proto.data.FvMaterialization.feature_store_format_version', index=5,
      number=8, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='featureStoreFormatVersion', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=169,
  serialized_end=662,
)

_FVMATERIALIZATION.fields_by_name['feature_view_locator'].message_type = tecton__proto_dot_common_dot_fco__locator__pb2._FCOLOCATOR
_FVMATERIALIZATION.fields_by_name['materialized_data_location'].message_type = _S3LOCATION
_FVMATERIALIZATION.fields_by_name['streaming_checkpoint_location'].message_type = _S3LOCATION
DESCRIPTOR.message_types_by_name['S3Location'] = _S3LOCATION
DESCRIPTOR.message_types_by_name['FvMaterialization'] = _FVMATERIALIZATION
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

S3Location = _reflection.GeneratedProtocolMessageType('S3Location', (_message.Message,), {
  'DESCRIPTOR' : _S3LOCATION,
  '__module__' : 'tecton_proto.data.fv_materialization_pb2'
  # @@protoc_insertion_point(class_scope:tecton_proto.data.S3Location)
  })
_sym_db.RegisterMessage(S3Location)

FvMaterialization = _reflection.GeneratedProtocolMessageType('FvMaterialization', (_message.Message,), {
  'DESCRIPTOR' : _FVMATERIALIZATION,
  '__module__' : 'tecton_proto.data.fv_materialization_pb2'
  # @@protoc_insertion_point(class_scope:tecton_proto.data.FvMaterialization)
  })
_sym_db.RegisterMessage(FvMaterialization)


DESCRIPTOR._options = None
# @@protoc_insertion_point(module_scope)
