# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: tecton_proto/data/workspace.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor.FileDescriptor(
  name='tecton_proto/data/workspace.proto',
  package='tecton_proto.data',
  syntax='proto2',
  serialized_options=b'\n\017com.tecton.dataP\001',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n!tecton_proto/data/workspace.proto\x12\x11tecton_proto.data\"?\n\x15WorkspaceCapabilities\x12&\n\x0ematerializable\x18\x01 \x01(\x08R\x0ematerializable\"m\n\tWorkspace\x12\x12\n\x04name\x18\x01 \x01(\tR\x04name\x12L\n\x0c\x63\x61pabilities\x18\x02 \x01(\x0b\x32(.tecton_proto.data.WorkspaceCapabilitiesR\x0c\x63\x61pabilitiesB\x13\n\x0f\x63om.tecton.dataP\x01'
)




_WORKSPACECAPABILITIES = _descriptor.Descriptor(
  name='WorkspaceCapabilities',
  full_name='tecton_proto.data.WorkspaceCapabilities',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='materializable', full_name='tecton_proto.data.WorkspaceCapabilities.materializable', index=0,
      number=1, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='materializable', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=56,
  serialized_end=119,
)


_WORKSPACE = _descriptor.Descriptor(
  name='Workspace',
  full_name='tecton_proto.data.Workspace',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='name', full_name='tecton_proto.data.Workspace.name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='name', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='capabilities', full_name='tecton_proto.data.Workspace.capabilities', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='capabilities', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=121,
  serialized_end=230,
)

_WORKSPACE.fields_by_name['capabilities'].message_type = _WORKSPACECAPABILITIES
DESCRIPTOR.message_types_by_name['WorkspaceCapabilities'] = _WORKSPACECAPABILITIES
DESCRIPTOR.message_types_by_name['Workspace'] = _WORKSPACE
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

WorkspaceCapabilities = _reflection.GeneratedProtocolMessageType('WorkspaceCapabilities', (_message.Message,), {
  'DESCRIPTOR' : _WORKSPACECAPABILITIES,
  '__module__' : 'tecton_proto.data.workspace_pb2'
  # @@protoc_insertion_point(class_scope:tecton_proto.data.WorkspaceCapabilities)
  })
_sym_db.RegisterMessage(WorkspaceCapabilities)

Workspace = _reflection.GeneratedProtocolMessageType('Workspace', (_message.Message,), {
  'DESCRIPTOR' : _WORKSPACE,
  '__module__' : 'tecton_proto.data.workspace_pb2'
  # @@protoc_insertion_point(class_scope:tecton_proto.data.Workspace)
  })
_sym_db.RegisterMessage(Workspace)


DESCRIPTOR._options = None
# @@protoc_insertion_point(module_scope)
