# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: tecton_proto/args/data_source_config.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from tecton_proto.common import id_pb2 as tecton__proto_dot_common_dot_id__pb2
from google.protobuf import duration_pb2 as google_dot_protobuf_dot_duration__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='tecton_proto/args/data_source_config.proto',
  package='tecton_proto.args',
  syntax='proto2',
  serialized_options=b'\n\017com.tecton.argsP\001',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n*tecton_proto/args/data_source_config.proto\x12\x11tecton_proto.args\x1a\x1ctecton_proto/common/id.proto\x1a\x1egoogle/protobuf/duration.proto\"\x13\n\x0b\x42\x61tchConfigJ\x04\x08\x01\x10\x02\"\xc7\x01\n\x0cStreamConfig\x12`\n\x17initial_stream_position\x18\x01 \x01(\x0e\x32(.tecton_proto.args.InitialStreamPositionR\x15initialStreamPosition\x12U\n\x19watermark_delay_threshold\x18\x02 \x01(\x0b\x32\x19.google.protobuf.DurationR\x17watermarkDelayThreshold*\x94\x01\n\x15InitialStreamPosition\x12\'\n#INITIAL_STREAM_POSITION_UNSPECIFIED\x10\x00\x12\"\n\x1eINITIAL_STREAM_POSITION_LATEST\x10\x01\x12(\n$INITIAL_STREAM_POSITION_TRIM_HORIZON\x10\x03\"\x04\x08\x02\x10\x02\x42\x13\n\x0f\x63om.tecton.argsP\x01'
  ,
  dependencies=[tecton__proto_dot_common_dot_id__pb2.DESCRIPTOR,google_dot_protobuf_dot_duration__pb2.DESCRIPTOR,])

_INITIALSTREAMPOSITION = _descriptor.EnumDescriptor(
  name='InitialStreamPosition',
  full_name='tecton_proto.args.InitialStreamPosition',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='INITIAL_STREAM_POSITION_UNSPECIFIED', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='INITIAL_STREAM_POSITION_LATEST', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='INITIAL_STREAM_POSITION_TRIM_HORIZON', index=2, number=3,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=351,
  serialized_end=499,
)
_sym_db.RegisterEnumDescriptor(_INITIALSTREAMPOSITION)

InitialStreamPosition = enum_type_wrapper.EnumTypeWrapper(_INITIALSTREAMPOSITION)
INITIAL_STREAM_POSITION_UNSPECIFIED = 0
INITIAL_STREAM_POSITION_LATEST = 1
INITIAL_STREAM_POSITION_TRIM_HORIZON = 3



_BATCHCONFIG = _descriptor.Descriptor(
  name='BatchConfig',
  full_name='tecton_proto.args.BatchConfig',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=127,
  serialized_end=146,
)


_STREAMCONFIG = _descriptor.Descriptor(
  name='StreamConfig',
  full_name='tecton_proto.args.StreamConfig',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='initial_stream_position', full_name='tecton_proto.args.StreamConfig.initial_stream_position', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='initialStreamPosition', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='watermark_delay_threshold', full_name='tecton_proto.args.StreamConfig.watermark_delay_threshold', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='watermarkDelayThreshold', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=149,
  serialized_end=348,
)

_STREAMCONFIG.fields_by_name['initial_stream_position'].enum_type = _INITIALSTREAMPOSITION
_STREAMCONFIG.fields_by_name['watermark_delay_threshold'].message_type = google_dot_protobuf_dot_duration__pb2._DURATION
DESCRIPTOR.message_types_by_name['BatchConfig'] = _BATCHCONFIG
DESCRIPTOR.message_types_by_name['StreamConfig'] = _STREAMCONFIG
DESCRIPTOR.enum_types_by_name['InitialStreamPosition'] = _INITIALSTREAMPOSITION
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

BatchConfig = _reflection.GeneratedProtocolMessageType('BatchConfig', (_message.Message,), {
  'DESCRIPTOR' : _BATCHCONFIG,
  '__module__' : 'tecton_proto.args.data_source_config_pb2'
  # @@protoc_insertion_point(class_scope:tecton_proto.args.BatchConfig)
  })
_sym_db.RegisterMessage(BatchConfig)

StreamConfig = _reflection.GeneratedProtocolMessageType('StreamConfig', (_message.Message,), {
  'DESCRIPTOR' : _STREAMCONFIG,
  '__module__' : 'tecton_proto.args.data_source_config_pb2'
  # @@protoc_insertion_point(class_scope:tecton_proto.args.StreamConfig)
  })
_sym_db.RegisterMessage(StreamConfig)


DESCRIPTOR._options = None
# @@protoc_insertion_point(module_scope)
