# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: tecton_proto/args/pipeline.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import duration_pb2 as google_dot_protobuf_dot_duration__pb2
from google.protobuf import empty_pb2 as google_dot_protobuf_dot_empty__pb2
from tecton_proto.common import id_pb2 as tecton__proto_dot_common_dot_id__pb2
from tecton_proto.common import spark_schema_pb2 as tecton__proto_dot_common_dot_spark__schema__pb2
from tecton_proto.args import feature_service_pb2 as tecton__proto_dot_args_dot_feature__service__pb2
from tecton_proto.args import diff_options_pb2 as tecton__proto_dot_args_dot_diff__options__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='tecton_proto/args/pipeline.proto',
  package='tecton_proto.args',
  syntax='proto2',
  serialized_options=b'\n\017com.tecton.argsP\001',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n tecton_proto/args/pipeline.proto\x12\x11tecton_proto.args\x1a\x1egoogle/protobuf/duration.proto\x1a\x1bgoogle/protobuf/empty.proto\x1a\x1ctecton_proto/common/id.proto\x1a&tecton_proto/common/spark_schema.proto\x1a\'tecton_proto/args/feature_service.proto\x1a$tecton_proto/args/diff_options.proto\"\xc6\x01\n\x08Pipeline\x12\x33\n\x04root\x18\x01 \x01(\x0b\x32\x1f.tecton_proto.args.PipelineNodeR\x04root\x12\x33\n\x04mode\x18\x02 \x01(\x0e\x32\x1f.tecton_proto.args.PipelineModeR\x04mode\x12P\n\x11resolved_pipeline\x18\x03 \x01(\x0b\x32#.tecton_proto.args.ResolvedPipelineR\x10resolvedPipeline\"H\n\x1cSnowflakeSQLResolvedPipeline\x12(\n\x10root_inlined_sql\x18\x01 \x01(\tR\x0erootInlinedSql\"r\n\x10ResolvedPipeline\x12V\n\rsnowflake_sql\x18\x01 \x01(\x0b\x32/.tecton_proto.args.SnowflakeSQLResolvedPipelineH\x00R\x0csnowflakeSqlB\x06\n\x04type\"\xbc\x04\n\x0cPipelineNode\x12X\n\x13transformation_node\x18\x01 \x01(\x0b\x32%.tecton_proto.args.TransformationNodeH\x00R\x12transformationNode\x12M\n\x10\x64\x61ta_source_node\x18\x02 \x01(\x0b\x32!.tecton_proto.args.DataSourceNodeH\x00R\x0e\x64\x61taSourceNode\x12\x46\n\rconstant_node\x18\x03 \x01(\x0b\x32\x1f.tecton_proto.args.ConstantNodeH\x00R\x0c\x63onstantNode\x12\x63\n\x18request_data_source_node\x18\x04 \x01(\x0b\x32(.tecton_proto.args.RequestDataSourceNodeH\x00R\x15requestDataSourceNode\x12P\n\x11\x66\x65\x61ture_view_node\x18\x05 \x01(\x0b\x32\".tecton_proto.args.FeatureViewNodeH\x00R\x0f\x66\x65\x61tureViewNode\x12q\n\x1cmaterialization_context_node\x18\x07 \x01(\x0b\x32-.tecton_proto.args.MaterializationContextNodeH\x00R\x1amaterializationContextNodeB\x0b\n\tnode_typeJ\x04\x08\x06\x10\x07\"\x89\x01\n\x15RequestDataSourceNode\x12J\n\x0frequest_context\x18\x01 \x01(\x0b\x32!.tecton_proto.args.RequestContextR\x0erequestContext\x12$\n\ninput_name\x18\x02 \x01(\tB\x05\x92M\x02\x08\x03R\tinputName\"J\n\x0eRequestContext\x12\x38\n\x06schema\x18\x01 \x01(\x0b\x32 .tecton_proto.common.SparkSchemaR\x06schema\"\xcc\x01\n\x0f\x46\x65\x61tureViewNode\x12?\n\x0f\x66\x65\x61ture_view_id\x18\x01 \x01(\x0b\x32\x17.tecton_proto.common.IdR\rfeatureViewId\x12R\n\x0c\x66\x65\x61ture_view\x18\x02 \x01(\x0b\x32/.tecton_proto.args.FeatureServiceFeaturePackageR\x0b\x66\x65\x61tureView\x12$\n\ninput_name\x18\x03 \x01(\tB\x05\x92M\x02\x08\x03R\tinputName\"\x8c\x01\n\x12TransformationNode\x12\x44\n\x11transformation_id\x18\x01 \x01(\x0b\x32\x17.tecton_proto.common.IdR\x10transformationId\x12\x30\n\x06inputs\x18\x02 \x03(\x0b\x32\x18.tecton_proto.args.InputR\x06inputs\"\x84\x01\n\x05Input\x12\x1d\n\targ_index\x18\x01 \x01(\x05H\x00R\x08\x61rgIndex\x12\x1b\n\x08\x61rg_name\x18\x02 \x01(\tH\x00R\x07\x61rgName\x12\x33\n\x04node\x18\x03 \x01(\x0b\x32\x1f.tecton_proto.args.PipelineNodeR\x04nodeB\n\n\x08\x61rg_type\"\x82\x03\n\x0e\x44\x61taSourceNode\x12L\n\x16virtual_data_source_id\x18\x01 \x01(\x0b\x32\x17.tecton_proto.common.IdR\x13virtualDataSourceId\x12\x33\n\x06window\x18\x02 \x01(\x0b\x32\x19.google.protobuf.DurationH\x00R\x06window\x12>\n\x1awindow_unbounded_preceding\x18\x04 \x01(\x08H\x00R\x18windowUnboundedPreceding\x12+\n\x10window_unbounded\x18\x06 \x01(\x08H\x00R\x0fwindowUnbounded\x12\x42\n\x0fschedule_offset\x18\x03 \x01(\x0b\x32\x19.google.protobuf.DurationR\x0escheduleOffset\x12$\n\ninput_name\x18\x05 \x01(\tB\x05\x92M\x02\x08\x03R\tinputNameB\x16\n\x14\x64\x61ta_window_override\"\xe0\x01\n\x0c\x43onstantNode\x12#\n\x0cstring_const\x18\x01 \x01(\tH\x00R\x0bstringConst\x12\x1d\n\tint_const\x18\x02 \x01(\tH\x00R\x08intConst\x12!\n\x0b\x66loat_const\x18\x03 \x01(\tH\x00R\nfloatConst\x12\x1f\n\nbool_const\x18\x04 \x01(\x08H\x00R\tboolConst\x12\x37\n\nnull_const\x18\x05 \x01(\x0b\x32\x16.google.protobuf.EmptyH\x00R\tnullConstB\x0f\n\rconstant_type\"\x1c\n\x1aMaterializationContextNode*\x80\x01\n\x0cPipelineMode\x12\x19\n\x15PIPELINE_MODE_UNKNOWN\x10\x00\x12\x17\n\x13PIPELINE_MODE_SPARK\x10\x01\x12\x1b\n\x17PIPELINE_MODE_ON_DEMAND\x10\x02\x12\x1f\n\x1bPIPELINE_MODE_SNOWFLAKE_SQL\x10\x03\x42\x13\n\x0f\x63om.tecton.argsP\x01'
  ,
  dependencies=[google_dot_protobuf_dot_duration__pb2.DESCRIPTOR,google_dot_protobuf_dot_empty__pb2.DESCRIPTOR,tecton__proto_dot_common_dot_id__pb2.DESCRIPTOR,tecton__proto_dot_common_dot_spark__schema__pb2.DESCRIPTOR,tecton__proto_dot_args_dot_feature__service__pb2.DESCRIPTOR,tecton__proto_dot_args_dot_diff__options__pb2.DESCRIPTOR,])

_PIPELINEMODE = _descriptor.EnumDescriptor(
  name='PipelineMode',
  full_name='tecton_proto.args.PipelineMode',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='PIPELINE_MODE_UNKNOWN', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='PIPELINE_MODE_SPARK', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='PIPELINE_MODE_ON_DEMAND', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='PIPELINE_MODE_SNOWFLAKE_SQL', index=3, number=3,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=2579,
  serialized_end=2707,
)
_sym_db.RegisterEnumDescriptor(_PIPELINEMODE)

PipelineMode = enum_type_wrapper.EnumTypeWrapper(_PIPELINEMODE)
PIPELINE_MODE_UNKNOWN = 0
PIPELINE_MODE_SPARK = 1
PIPELINE_MODE_ON_DEMAND = 2
PIPELINE_MODE_SNOWFLAKE_SQL = 3



_PIPELINE = _descriptor.Descriptor(
  name='Pipeline',
  full_name='tecton_proto.args.Pipeline',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='root', full_name='tecton_proto.args.Pipeline.root', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='root', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='mode', full_name='tecton_proto.args.Pipeline.mode', index=1,
      number=2, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='mode', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='resolved_pipeline', full_name='tecton_proto.args.Pipeline.resolved_pipeline', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='resolvedPipeline', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=266,
  serialized_end=464,
)


_SNOWFLAKESQLRESOLVEDPIPELINE = _descriptor.Descriptor(
  name='SnowflakeSQLResolvedPipeline',
  full_name='tecton_proto.args.SnowflakeSQLResolvedPipeline',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='root_inlined_sql', full_name='tecton_proto.args.SnowflakeSQLResolvedPipeline.root_inlined_sql', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='rootInlinedSql', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=466,
  serialized_end=538,
)


_RESOLVEDPIPELINE = _descriptor.Descriptor(
  name='ResolvedPipeline',
  full_name='tecton_proto.args.ResolvedPipeline',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='snowflake_sql', full_name='tecton_proto.args.ResolvedPipeline.snowflake_sql', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='snowflakeSql', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='type', full_name='tecton_proto.args.ResolvedPipeline.type',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=540,
  serialized_end=654,
)


_PIPELINENODE = _descriptor.Descriptor(
  name='PipelineNode',
  full_name='tecton_proto.args.PipelineNode',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='transformation_node', full_name='tecton_proto.args.PipelineNode.transformation_node', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='transformationNode', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='data_source_node', full_name='tecton_proto.args.PipelineNode.data_source_node', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='dataSourceNode', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='constant_node', full_name='tecton_proto.args.PipelineNode.constant_node', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='constantNode', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='request_data_source_node', full_name='tecton_proto.args.PipelineNode.request_data_source_node', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='requestDataSourceNode', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='feature_view_node', full_name='tecton_proto.args.PipelineNode.feature_view_node', index=4,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='featureViewNode', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='materialization_context_node', full_name='tecton_proto.args.PipelineNode.materialization_context_node', index=5,
      number=7, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='materializationContextNode', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='node_type', full_name='tecton_proto.args.PipelineNode.node_type',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=657,
  serialized_end=1229,
)


_REQUESTDATASOURCENODE = _descriptor.Descriptor(
  name='RequestDataSourceNode',
  full_name='tecton_proto.args.RequestDataSourceNode',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='request_context', full_name='tecton_proto.args.RequestDataSourceNode.request_context', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='requestContext', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='input_name', full_name='tecton_proto.args.RequestDataSourceNode.input_name', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\222M\002\010\003', json_name='inputName', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1232,
  serialized_end=1369,
)


_REQUESTCONTEXT = _descriptor.Descriptor(
  name='RequestContext',
  full_name='tecton_proto.args.RequestContext',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='schema', full_name='tecton_proto.args.RequestContext.schema', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='schema', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1371,
  serialized_end=1445,
)


_FEATUREVIEWNODE = _descriptor.Descriptor(
  name='FeatureViewNode',
  full_name='tecton_proto.args.FeatureViewNode',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='feature_view_id', full_name='tecton_proto.args.FeatureViewNode.feature_view_id', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='featureViewId', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='feature_view', full_name='tecton_proto.args.FeatureViewNode.feature_view', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='featureView', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='input_name', full_name='tecton_proto.args.FeatureViewNode.input_name', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\222M\002\010\003', json_name='inputName', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1448,
  serialized_end=1652,
)


_TRANSFORMATIONNODE = _descriptor.Descriptor(
  name='TransformationNode',
  full_name='tecton_proto.args.TransformationNode',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='transformation_id', full_name='tecton_proto.args.TransformationNode.transformation_id', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='transformationId', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='inputs', full_name='tecton_proto.args.TransformationNode.inputs', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='inputs', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1655,
  serialized_end=1795,
)


_INPUT = _descriptor.Descriptor(
  name='Input',
  full_name='tecton_proto.args.Input',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='arg_index', full_name='tecton_proto.args.Input.arg_index', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='argIndex', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='arg_name', full_name='tecton_proto.args.Input.arg_name', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='argName', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='node', full_name='tecton_proto.args.Input.node', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='node', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='arg_type', full_name='tecton_proto.args.Input.arg_type',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=1798,
  serialized_end=1930,
)


_DATASOURCENODE = _descriptor.Descriptor(
  name='DataSourceNode',
  full_name='tecton_proto.args.DataSourceNode',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='virtual_data_source_id', full_name='tecton_proto.args.DataSourceNode.virtual_data_source_id', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='virtualDataSourceId', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='window', full_name='tecton_proto.args.DataSourceNode.window', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='window', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='window_unbounded_preceding', full_name='tecton_proto.args.DataSourceNode.window_unbounded_preceding', index=2,
      number=4, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='windowUnboundedPreceding', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='window_unbounded', full_name='tecton_proto.args.DataSourceNode.window_unbounded', index=3,
      number=6, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='windowUnbounded', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='schedule_offset', full_name='tecton_proto.args.DataSourceNode.schedule_offset', index=4,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='scheduleOffset', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='input_name', full_name='tecton_proto.args.DataSourceNode.input_name', index=5,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\222M\002\010\003', json_name='inputName', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='data_window_override', full_name='tecton_proto.args.DataSourceNode.data_window_override',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=1933,
  serialized_end=2319,
)


_CONSTANTNODE = _descriptor.Descriptor(
  name='ConstantNode',
  full_name='tecton_proto.args.ConstantNode',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='string_const', full_name='tecton_proto.args.ConstantNode.string_const', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='stringConst', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='int_const', full_name='tecton_proto.args.ConstantNode.int_const', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='intConst', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='float_const', full_name='tecton_proto.args.ConstantNode.float_const', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='floatConst', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='bool_const', full_name='tecton_proto.args.ConstantNode.bool_const', index=3,
      number=4, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='boolConst', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='null_const', full_name='tecton_proto.args.ConstantNode.null_const', index=4,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='nullConst', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='constant_type', full_name='tecton_proto.args.ConstantNode.constant_type',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=2322,
  serialized_end=2546,
)


_MATERIALIZATIONCONTEXTNODE = _descriptor.Descriptor(
  name='MaterializationContextNode',
  full_name='tecton_proto.args.MaterializationContextNode',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2548,
  serialized_end=2576,
)

_PIPELINE.fields_by_name['root'].message_type = _PIPELINENODE
_PIPELINE.fields_by_name['mode'].enum_type = _PIPELINEMODE
_PIPELINE.fields_by_name['resolved_pipeline'].message_type = _RESOLVEDPIPELINE
_RESOLVEDPIPELINE.fields_by_name['snowflake_sql'].message_type = _SNOWFLAKESQLRESOLVEDPIPELINE
_RESOLVEDPIPELINE.oneofs_by_name['type'].fields.append(
  _RESOLVEDPIPELINE.fields_by_name['snowflake_sql'])
_RESOLVEDPIPELINE.fields_by_name['snowflake_sql'].containing_oneof = _RESOLVEDPIPELINE.oneofs_by_name['type']
_PIPELINENODE.fields_by_name['transformation_node'].message_type = _TRANSFORMATIONNODE
_PIPELINENODE.fields_by_name['data_source_node'].message_type = _DATASOURCENODE
_PIPELINENODE.fields_by_name['constant_node'].message_type = _CONSTANTNODE
_PIPELINENODE.fields_by_name['request_data_source_node'].message_type = _REQUESTDATASOURCENODE
_PIPELINENODE.fields_by_name['feature_view_node'].message_type = _FEATUREVIEWNODE
_PIPELINENODE.fields_by_name['materialization_context_node'].message_type = _MATERIALIZATIONCONTEXTNODE
_PIPELINENODE.oneofs_by_name['node_type'].fields.append(
  _PIPELINENODE.fields_by_name['transformation_node'])
_PIPELINENODE.fields_by_name['transformation_node'].containing_oneof = _PIPELINENODE.oneofs_by_name['node_type']
_PIPELINENODE.oneofs_by_name['node_type'].fields.append(
  _PIPELINENODE.fields_by_name['data_source_node'])
_PIPELINENODE.fields_by_name['data_source_node'].containing_oneof = _PIPELINENODE.oneofs_by_name['node_type']
_PIPELINENODE.oneofs_by_name['node_type'].fields.append(
  _PIPELINENODE.fields_by_name['constant_node'])
_PIPELINENODE.fields_by_name['constant_node'].containing_oneof = _PIPELINENODE.oneofs_by_name['node_type']
_PIPELINENODE.oneofs_by_name['node_type'].fields.append(
  _PIPELINENODE.fields_by_name['request_data_source_node'])
_PIPELINENODE.fields_by_name['request_data_source_node'].containing_oneof = _PIPELINENODE.oneofs_by_name['node_type']
_PIPELINENODE.oneofs_by_name['node_type'].fields.append(
  _PIPELINENODE.fields_by_name['feature_view_node'])
_PIPELINENODE.fields_by_name['feature_view_node'].containing_oneof = _PIPELINENODE.oneofs_by_name['node_type']
_PIPELINENODE.oneofs_by_name['node_type'].fields.append(
  _PIPELINENODE.fields_by_name['materialization_context_node'])
_PIPELINENODE.fields_by_name['materialization_context_node'].containing_oneof = _PIPELINENODE.oneofs_by_name['node_type']
_REQUESTDATASOURCENODE.fields_by_name['request_context'].message_type = _REQUESTCONTEXT
_REQUESTCONTEXT.fields_by_name['schema'].message_type = tecton__proto_dot_common_dot_spark__schema__pb2._SPARKSCHEMA
_FEATUREVIEWNODE.fields_by_name['feature_view_id'].message_type = tecton__proto_dot_common_dot_id__pb2._ID
_FEATUREVIEWNODE.fields_by_name['feature_view'].message_type = tecton__proto_dot_args_dot_feature__service__pb2._FEATURESERVICEFEATUREPACKAGE
_TRANSFORMATIONNODE.fields_by_name['transformation_id'].message_type = tecton__proto_dot_common_dot_id__pb2._ID
_TRANSFORMATIONNODE.fields_by_name['inputs'].message_type = _INPUT
_INPUT.fields_by_name['node'].message_type = _PIPELINENODE
_INPUT.oneofs_by_name['arg_type'].fields.append(
  _INPUT.fields_by_name['arg_index'])
_INPUT.fields_by_name['arg_index'].containing_oneof = _INPUT.oneofs_by_name['arg_type']
_INPUT.oneofs_by_name['arg_type'].fields.append(
  _INPUT.fields_by_name['arg_name'])
_INPUT.fields_by_name['arg_name'].containing_oneof = _INPUT.oneofs_by_name['arg_type']
_DATASOURCENODE.fields_by_name['virtual_data_source_id'].message_type = tecton__proto_dot_common_dot_id__pb2._ID
_DATASOURCENODE.fields_by_name['window'].message_type = google_dot_protobuf_dot_duration__pb2._DURATION
_DATASOURCENODE.fields_by_name['schedule_offset'].message_type = google_dot_protobuf_dot_duration__pb2._DURATION
_DATASOURCENODE.oneofs_by_name['data_window_override'].fields.append(
  _DATASOURCENODE.fields_by_name['window'])
_DATASOURCENODE.fields_by_name['window'].containing_oneof = _DATASOURCENODE.oneofs_by_name['data_window_override']
_DATASOURCENODE.oneofs_by_name['data_window_override'].fields.append(
  _DATASOURCENODE.fields_by_name['window_unbounded_preceding'])
_DATASOURCENODE.fields_by_name['window_unbounded_preceding'].containing_oneof = _DATASOURCENODE.oneofs_by_name['data_window_override']
_DATASOURCENODE.oneofs_by_name['data_window_override'].fields.append(
  _DATASOURCENODE.fields_by_name['window_unbounded'])
_DATASOURCENODE.fields_by_name['window_unbounded'].containing_oneof = _DATASOURCENODE.oneofs_by_name['data_window_override']
_CONSTANTNODE.fields_by_name['null_const'].message_type = google_dot_protobuf_dot_empty__pb2._EMPTY
_CONSTANTNODE.oneofs_by_name['constant_type'].fields.append(
  _CONSTANTNODE.fields_by_name['string_const'])
_CONSTANTNODE.fields_by_name['string_const'].containing_oneof = _CONSTANTNODE.oneofs_by_name['constant_type']
_CONSTANTNODE.oneofs_by_name['constant_type'].fields.append(
  _CONSTANTNODE.fields_by_name['int_const'])
_CONSTANTNODE.fields_by_name['int_const'].containing_oneof = _CONSTANTNODE.oneofs_by_name['constant_type']
_CONSTANTNODE.oneofs_by_name['constant_type'].fields.append(
  _CONSTANTNODE.fields_by_name['float_const'])
_CONSTANTNODE.fields_by_name['float_const'].containing_oneof = _CONSTANTNODE.oneofs_by_name['constant_type']
_CONSTANTNODE.oneofs_by_name['constant_type'].fields.append(
  _CONSTANTNODE.fields_by_name['bool_const'])
_CONSTANTNODE.fields_by_name['bool_const'].containing_oneof = _CONSTANTNODE.oneofs_by_name['constant_type']
_CONSTANTNODE.oneofs_by_name['constant_type'].fields.append(
  _CONSTANTNODE.fields_by_name['null_const'])
_CONSTANTNODE.fields_by_name['null_const'].containing_oneof = _CONSTANTNODE.oneofs_by_name['constant_type']
DESCRIPTOR.message_types_by_name['Pipeline'] = _PIPELINE
DESCRIPTOR.message_types_by_name['SnowflakeSQLResolvedPipeline'] = _SNOWFLAKESQLRESOLVEDPIPELINE
DESCRIPTOR.message_types_by_name['ResolvedPipeline'] = _RESOLVEDPIPELINE
DESCRIPTOR.message_types_by_name['PipelineNode'] = _PIPELINENODE
DESCRIPTOR.message_types_by_name['RequestDataSourceNode'] = _REQUESTDATASOURCENODE
DESCRIPTOR.message_types_by_name['RequestContext'] = _REQUESTCONTEXT
DESCRIPTOR.message_types_by_name['FeatureViewNode'] = _FEATUREVIEWNODE
DESCRIPTOR.message_types_by_name['TransformationNode'] = _TRANSFORMATIONNODE
DESCRIPTOR.message_types_by_name['Input'] = _INPUT
DESCRIPTOR.message_types_by_name['DataSourceNode'] = _DATASOURCENODE
DESCRIPTOR.message_types_by_name['ConstantNode'] = _CONSTANTNODE
DESCRIPTOR.message_types_by_name['MaterializationContextNode'] = _MATERIALIZATIONCONTEXTNODE
DESCRIPTOR.enum_types_by_name['PipelineMode'] = _PIPELINEMODE
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

Pipeline = _reflection.GeneratedProtocolMessageType('Pipeline', (_message.Message,), {
  'DESCRIPTOR' : _PIPELINE,
  '__module__' : 'tecton_proto.args.pipeline_pb2'
  # @@protoc_insertion_point(class_scope:tecton_proto.args.Pipeline)
  })
_sym_db.RegisterMessage(Pipeline)

SnowflakeSQLResolvedPipeline = _reflection.GeneratedProtocolMessageType('SnowflakeSQLResolvedPipeline', (_message.Message,), {
  'DESCRIPTOR' : _SNOWFLAKESQLRESOLVEDPIPELINE,
  '__module__' : 'tecton_proto.args.pipeline_pb2'
  # @@protoc_insertion_point(class_scope:tecton_proto.args.SnowflakeSQLResolvedPipeline)
  })
_sym_db.RegisterMessage(SnowflakeSQLResolvedPipeline)

ResolvedPipeline = _reflection.GeneratedProtocolMessageType('ResolvedPipeline', (_message.Message,), {
  'DESCRIPTOR' : _RESOLVEDPIPELINE,
  '__module__' : 'tecton_proto.args.pipeline_pb2'
  # @@protoc_insertion_point(class_scope:tecton_proto.args.ResolvedPipeline)
  })
_sym_db.RegisterMessage(ResolvedPipeline)

PipelineNode = _reflection.GeneratedProtocolMessageType('PipelineNode', (_message.Message,), {
  'DESCRIPTOR' : _PIPELINENODE,
  '__module__' : 'tecton_proto.args.pipeline_pb2'
  # @@protoc_insertion_point(class_scope:tecton_proto.args.PipelineNode)
  })
_sym_db.RegisterMessage(PipelineNode)

RequestDataSourceNode = _reflection.GeneratedProtocolMessageType('RequestDataSourceNode', (_message.Message,), {
  'DESCRIPTOR' : _REQUESTDATASOURCENODE,
  '__module__' : 'tecton_proto.args.pipeline_pb2'
  # @@protoc_insertion_point(class_scope:tecton_proto.args.RequestDataSourceNode)
  })
_sym_db.RegisterMessage(RequestDataSourceNode)

RequestContext = _reflection.GeneratedProtocolMessageType('RequestContext', (_message.Message,), {
  'DESCRIPTOR' : _REQUESTCONTEXT,
  '__module__' : 'tecton_proto.args.pipeline_pb2'
  # @@protoc_insertion_point(class_scope:tecton_proto.args.RequestContext)
  })
_sym_db.RegisterMessage(RequestContext)

FeatureViewNode = _reflection.GeneratedProtocolMessageType('FeatureViewNode', (_message.Message,), {
  'DESCRIPTOR' : _FEATUREVIEWNODE,
  '__module__' : 'tecton_proto.args.pipeline_pb2'
  # @@protoc_insertion_point(class_scope:tecton_proto.args.FeatureViewNode)
  })
_sym_db.RegisterMessage(FeatureViewNode)

TransformationNode = _reflection.GeneratedProtocolMessageType('TransformationNode', (_message.Message,), {
  'DESCRIPTOR' : _TRANSFORMATIONNODE,
  '__module__' : 'tecton_proto.args.pipeline_pb2'
  # @@protoc_insertion_point(class_scope:tecton_proto.args.TransformationNode)
  })
_sym_db.RegisterMessage(TransformationNode)

Input = _reflection.GeneratedProtocolMessageType('Input', (_message.Message,), {
  'DESCRIPTOR' : _INPUT,
  '__module__' : 'tecton_proto.args.pipeline_pb2'
  # @@protoc_insertion_point(class_scope:tecton_proto.args.Input)
  })
_sym_db.RegisterMessage(Input)

DataSourceNode = _reflection.GeneratedProtocolMessageType('DataSourceNode', (_message.Message,), {
  'DESCRIPTOR' : _DATASOURCENODE,
  '__module__' : 'tecton_proto.args.pipeline_pb2'
  # @@protoc_insertion_point(class_scope:tecton_proto.args.DataSourceNode)
  })
_sym_db.RegisterMessage(DataSourceNode)

ConstantNode = _reflection.GeneratedProtocolMessageType('ConstantNode', (_message.Message,), {
  'DESCRIPTOR' : _CONSTANTNODE,
  '__module__' : 'tecton_proto.args.pipeline_pb2'
  # @@protoc_insertion_point(class_scope:tecton_proto.args.ConstantNode)
  })
_sym_db.RegisterMessage(ConstantNode)

MaterializationContextNode = _reflection.GeneratedProtocolMessageType('MaterializationContextNode', (_message.Message,), {
  'DESCRIPTOR' : _MATERIALIZATIONCONTEXTNODE,
  '__module__' : 'tecton_proto.args.pipeline_pb2'
  # @@protoc_insertion_point(class_scope:tecton_proto.args.MaterializationContextNode)
  })
_sym_db.RegisterMessage(MaterializationContextNode)


DESCRIPTOR._options = None
_REQUESTDATASOURCENODE.fields_by_name['input_name']._options = None
_FEATUREVIEWNODE.fields_by_name['input_name']._options = None
_DATASOURCENODE.fields_by_name['input_name']._options = None
# @@protoc_insertion_point(module_scope)
