# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: tecton_proto/data/saved_feature_data_frame.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2
from tecton_proto.common import id_pb2 as tecton__proto_dot_common_dot_id__pb2
from tecton_proto.common import spark_schema_pb2 as tecton__proto_dot_common_dot_spark__schema__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='tecton_proto/data/saved_feature_data_frame.proto',
  package='tecton_proto.data',
  syntax='proto2',
  serialized_options=b'\n\017com.tecton.dataP\001',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n0tecton_proto/data/saved_feature_data_frame.proto\x12\x11tecton_proto.data\x1a\x1fgoogle/protobuf/timestamp.proto\x1a\x1ctecton_proto/common/id.proto\x1a&tecton_proto/common/spark_schema.proto\"\xd1\x01\n\x19SavedFeatureDataFrameInfo\x12\x12\n\x04name\x18\x01 \x01(\tR\x04name\x12\x39\n\ncreated_at\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.TimestampR\tcreatedAt\x12\x1f\n\x0bis_archived\x18\x03 \x01(\x08R\nisArchived\x12\x1c\n\tworkspace\x18\x04 \x01(\tR\tworkspace\x12&\n\x0fis_data_deleted\x18\x05 \x01(\x08R\risDataDeleted\"\x9f\x06\n\x15SavedFeatureDataFrame\x12T\n\x1asaved_feature_dataframe_id\x18\x01 \x01(\x0b\x32\x17.tecton_proto.common.IdR\x17savedFeatureDataframeId\x12@\n\x04info\x18\x02 \x01(\x0b\x32,.tecton_proto.data.SavedFeatureDataFrameInfoR\x04info\x12-\n\x12\x64\x61taframe_location\x18\x03 \x01(\tR\x11\x64\x61taframeLocation\x12G\n\x12\x66\x65\x61ture_package_id\x18\x04 \x01(\x0b\x32\x17.tecton_proto.common.IdH\x00R\x10\x66\x65\x61turePackageId\x12G\n\x12\x66\x65\x61ture_service_id\x18\x05 \x01(\x0b\x32\x17.tecton_proto.common.IdH\x00R\x10\x66\x65\x61tureServiceId\x12\x32\n\x14\x66\x65\x61ture_package_name\x18\x06 \x01(\tH\x01R\x12\x66\x65\x61turePackageName\x12\x32\n\x14\x66\x65\x61ture_service_name\x18\x07 \x01(\tH\x01R\x12\x66\x65\x61tureServiceName\x12>\n\x1cstate_update_entry_commit_id\x18\x08 \x01(\tR\x18stateUpdateEntryCommitId\x12\x31\n\x15join_key_column_names\x18\t \x03(\tR\x12joinKeyColumnNames\x12\x32\n\x15timestamp_column_name\x18\n \x01(\tR\x13timestampColumnName\x12\x38\n\x06schema\x18\x0b \x01(\x0b\x32 .tecton_proto.common.SparkSchemaR\x06schema\x12@\n\x04type\x18\x0c \x01(\x0e\x32,.tecton_proto.data.SavedFeatureDataFrameTypeR\x04typeB\x0f\n\rsource_fco_idB\x11\n\x0fsource_fco_name*?\n\x19SavedFeatureDataFrameType\x12\x0b\n\x07NOT_SET\x10\x00\x12\t\n\x05SAVED\x10\x01\x12\n\n\x06LOGGED\x10\x02\x42\x13\n\x0f\x63om.tecton.dataP\x01'
  ,
  dependencies=[google_dot_protobuf_dot_timestamp__pb2.DESCRIPTOR,tecton__proto_dot_common_dot_id__pb2.DESCRIPTOR,tecton__proto_dot_common_dot_spark__schema__pb2.DESCRIPTOR,])

_SAVEDFEATUREDATAFRAMETYPE = _descriptor.EnumDescriptor(
  name='SavedFeatureDataFrameType',
  full_name='tecton_proto.data.SavedFeatureDataFrameType',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='NOT_SET', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='SAVED', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='LOGGED', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=1188,
  serialized_end=1251,
)
_sym_db.RegisterEnumDescriptor(_SAVEDFEATUREDATAFRAMETYPE)

SavedFeatureDataFrameType = enum_type_wrapper.EnumTypeWrapper(_SAVEDFEATUREDATAFRAMETYPE)
NOT_SET = 0
SAVED = 1
LOGGED = 2



_SAVEDFEATUREDATAFRAMEINFO = _descriptor.Descriptor(
  name='SavedFeatureDataFrameInfo',
  full_name='tecton_proto.data.SavedFeatureDataFrameInfo',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='name', full_name='tecton_proto.data.SavedFeatureDataFrameInfo.name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='name', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='created_at', full_name='tecton_proto.data.SavedFeatureDataFrameInfo.created_at', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='createdAt', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='is_archived', full_name='tecton_proto.data.SavedFeatureDataFrameInfo.is_archived', index=2,
      number=3, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='isArchived', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='workspace', full_name='tecton_proto.data.SavedFeatureDataFrameInfo.workspace', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='workspace', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='is_data_deleted', full_name='tecton_proto.data.SavedFeatureDataFrameInfo.is_data_deleted', index=4,
      number=5, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='isDataDeleted', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=175,
  serialized_end=384,
)


_SAVEDFEATUREDATAFRAME = _descriptor.Descriptor(
  name='SavedFeatureDataFrame',
  full_name='tecton_proto.data.SavedFeatureDataFrame',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='saved_feature_dataframe_id', full_name='tecton_proto.data.SavedFeatureDataFrame.saved_feature_dataframe_id', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='savedFeatureDataframeId', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='info', full_name='tecton_proto.data.SavedFeatureDataFrame.info', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='info', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='dataframe_location', full_name='tecton_proto.data.SavedFeatureDataFrame.dataframe_location', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='dataframeLocation', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='feature_package_id', full_name='tecton_proto.data.SavedFeatureDataFrame.feature_package_id', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='featurePackageId', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='feature_service_id', full_name='tecton_proto.data.SavedFeatureDataFrame.feature_service_id', index=4,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='featureServiceId', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='feature_package_name', full_name='tecton_proto.data.SavedFeatureDataFrame.feature_package_name', index=5,
      number=6, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='featurePackageName', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='feature_service_name', full_name='tecton_proto.data.SavedFeatureDataFrame.feature_service_name', index=6,
      number=7, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='featureServiceName', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='state_update_entry_commit_id', full_name='tecton_proto.data.SavedFeatureDataFrame.state_update_entry_commit_id', index=7,
      number=8, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='stateUpdateEntryCommitId', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='join_key_column_names', full_name='tecton_proto.data.SavedFeatureDataFrame.join_key_column_names', index=8,
      number=9, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='joinKeyColumnNames', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='timestamp_column_name', full_name='tecton_proto.data.SavedFeatureDataFrame.timestamp_column_name', index=9,
      number=10, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='timestampColumnName', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='schema', full_name='tecton_proto.data.SavedFeatureDataFrame.schema', index=10,
      number=11, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='schema', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='type', full_name='tecton_proto.data.SavedFeatureDataFrame.type', index=11,
      number=12, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='type', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='source_fco_id', full_name='tecton_proto.data.SavedFeatureDataFrame.source_fco_id',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='source_fco_name', full_name='tecton_proto.data.SavedFeatureDataFrame.source_fco_name',
      index=1, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=387,
  serialized_end=1186,
)

_SAVEDFEATUREDATAFRAMEINFO.fields_by_name['created_at'].message_type = google_dot_protobuf_dot_timestamp__pb2._TIMESTAMP
_SAVEDFEATUREDATAFRAME.fields_by_name['saved_feature_dataframe_id'].message_type = tecton__proto_dot_common_dot_id__pb2._ID
_SAVEDFEATUREDATAFRAME.fields_by_name['info'].message_type = _SAVEDFEATUREDATAFRAMEINFO
_SAVEDFEATUREDATAFRAME.fields_by_name['feature_package_id'].message_type = tecton__proto_dot_common_dot_id__pb2._ID
_SAVEDFEATUREDATAFRAME.fields_by_name['feature_service_id'].message_type = tecton__proto_dot_common_dot_id__pb2._ID
_SAVEDFEATUREDATAFRAME.fields_by_name['schema'].message_type = tecton__proto_dot_common_dot_spark__schema__pb2._SPARKSCHEMA
_SAVEDFEATUREDATAFRAME.fields_by_name['type'].enum_type = _SAVEDFEATUREDATAFRAMETYPE
_SAVEDFEATUREDATAFRAME.oneofs_by_name['source_fco_id'].fields.append(
  _SAVEDFEATUREDATAFRAME.fields_by_name['feature_package_id'])
_SAVEDFEATUREDATAFRAME.fields_by_name['feature_package_id'].containing_oneof = _SAVEDFEATUREDATAFRAME.oneofs_by_name['source_fco_id']
_SAVEDFEATUREDATAFRAME.oneofs_by_name['source_fco_id'].fields.append(
  _SAVEDFEATUREDATAFRAME.fields_by_name['feature_service_id'])
_SAVEDFEATUREDATAFRAME.fields_by_name['feature_service_id'].containing_oneof = _SAVEDFEATUREDATAFRAME.oneofs_by_name['source_fco_id']
_SAVEDFEATUREDATAFRAME.oneofs_by_name['source_fco_name'].fields.append(
  _SAVEDFEATUREDATAFRAME.fields_by_name['feature_package_name'])
_SAVEDFEATUREDATAFRAME.fields_by_name['feature_package_name'].containing_oneof = _SAVEDFEATUREDATAFRAME.oneofs_by_name['source_fco_name']
_SAVEDFEATUREDATAFRAME.oneofs_by_name['source_fco_name'].fields.append(
  _SAVEDFEATUREDATAFRAME.fields_by_name['feature_service_name'])
_SAVEDFEATUREDATAFRAME.fields_by_name['feature_service_name'].containing_oneof = _SAVEDFEATUREDATAFRAME.oneofs_by_name['source_fco_name']
DESCRIPTOR.message_types_by_name['SavedFeatureDataFrameInfo'] = _SAVEDFEATUREDATAFRAMEINFO
DESCRIPTOR.message_types_by_name['SavedFeatureDataFrame'] = _SAVEDFEATUREDATAFRAME
DESCRIPTOR.enum_types_by_name['SavedFeatureDataFrameType'] = _SAVEDFEATUREDATAFRAMETYPE
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

SavedFeatureDataFrameInfo = _reflection.GeneratedProtocolMessageType('SavedFeatureDataFrameInfo', (_message.Message,), {
  'DESCRIPTOR' : _SAVEDFEATUREDATAFRAMEINFO,
  '__module__' : 'tecton_proto.data.saved_feature_data_frame_pb2'
  # @@protoc_insertion_point(class_scope:tecton_proto.data.SavedFeatureDataFrameInfo)
  })
_sym_db.RegisterMessage(SavedFeatureDataFrameInfo)

SavedFeatureDataFrame = _reflection.GeneratedProtocolMessageType('SavedFeatureDataFrame', (_message.Message,), {
  'DESCRIPTOR' : _SAVEDFEATUREDATAFRAME,
  '__module__' : 'tecton_proto.data.saved_feature_data_frame_pb2'
  # @@protoc_insertion_point(class_scope:tecton_proto.data.SavedFeatureDataFrame)
  })
_sym_db.RegisterMessage(SavedFeatureDataFrame)


DESCRIPTOR._options = None
# @@protoc_insertion_point(module_scope)
