# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: tecton_proto/data/remote_spark.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from tecton_proto.args import data_source_pb2 as tecton__proto_dot_args_dot_data__source__pb2
from tecton_proto.args import data_source_config_pb2 as tecton__proto_dot_args_dot_data__source__config__pb2
from tecton_proto.args import user_defined_function_pb2 as tecton__proto_dot_args_dot_user__defined__function__pb2
from tecton_proto.args import feature_view_pb2 as tecton__proto_dot_args_dot_feature__view__pb2
from tecton_proto.common import id_pb2 as tecton__proto_dot_common_dot_id__pb2
from tecton_proto.common import schema_pb2 as tecton__proto_dot_common_dot_schema__pb2
from tecton_proto.common import spark_schema_pb2 as tecton__proto_dot_common_dot_spark__schema__pb2
from tecton_proto.data import feature_view_pb2 as tecton__proto_dot_data_dot_feature__view__pb2
from tecton_proto.data import virtual_data_source_pb2 as tecton__proto_dot_data_dot_virtual__data__source__pb2
from tecton_proto.data import new_transformation_pb2 as tecton__proto_dot_data_dot_new__transformation__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='tecton_proto/data/remote_spark.proto',
  package='tecton_proto.data',
  syntax='proto2',
  serialized_options=b'\n\017com.tecton.dataP\001',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n$tecton_proto/data/remote_spark.proto\x12\x11tecton_proto.data\x1a#tecton_proto/args/data_source.proto\x1a*tecton_proto/args/data_source_config.proto\x1a-tecton_proto/args/user_defined_function.proto\x1a$tecton_proto/args/feature_view.proto\x1a\x1ctecton_proto/common/id.proto\x1a tecton_proto/common/schema.proto\x1a&tecton_proto/common/spark_schema.proto\x1a$tecton_proto/data/feature_view.proto\x1a+tecton_proto/data/virtual_data_source.proto\x1a*tecton_proto/data/new_transformation.proto\"\xf2\x01\n\x12GetHiveTableSchema\x12\x1a\n\x08\x64\x61tabase\x18\x01 \x01(\tR\x08\x64\x61tabase\x12\x14\n\x05table\x18\x02 \x01(\tR\x05table\x12(\n\x0ftimestampColumn\x18\x03 \x01(\tR\x0ftimestampColumn\x12(\n\x0ftimestampFormat\x18\x04 \x01(\tR\x0ftimestampFormat\x12V\n\x12rawBatchTranslator\x18\x05 \x01(\x0b\x32&.tecton_proto.args.UserDefinedFunctionR\x12rawBatchTranslator\"\xd6\x01\n\x16GetRedshiftTableSchema\x12\x1a\n\x08\x65ndpoint\x18\x01 \x01(\tR\x08\x65ndpoint\x12\x14\n\x05table\x18\x02 \x01(\tR\x05table\x12\x14\n\x05query\x18\x03 \x01(\tR\x05query\x12V\n\x12rawBatchTranslator\x18\x04 \x01(\x0b\x32&.tecton_proto.args.UserDefinedFunctionR\x12rawBatchTranslator\x12\x1c\n\ttemps3dir\x18\x05 \x01(\tR\ttemps3dir\"f\n\x12GetSnowflakeSchema\x12P\n\rsnowflakeArgs\x18\x01 \x01(\x0b\x32*.tecton_proto.args.SnowflakeDataSourceArgsR\rsnowflakeArgs\"\x8d\x03\n\x13GetFileSourceSchema\x12\x10\n\x03uri\x18\x01 \x01(\tR\x03uri\x12\x1e\n\nfileFormat\x18\x02 \x01(\tR\nfileFormat\x12\x30\n\x13\x63onvertToGlueFormat\x18\x03 \x01(\x08R\x13\x63onvertToGlueFormat\x12V\n\x12rawBatchTranslator\x18\x04 \x01(\x0b\x32&.tecton_proto.args.UserDefinedFunctionR\x12rawBatchTranslator\x12\x1c\n\tschemaUri\x18\x05 \x01(\tR\tschemaUri\x12(\n\x0ftimestampColumn\x18\x06 \x01(\tR\x0ftimestampColumn\x12(\n\x0ftimestampFormat\x18\x07 \x01(\tR\x0ftimestampFormat\x12H\n\x0eschemaOverride\x18\x08 \x01(\x0b\x32 .tecton_proto.common.SparkSchemaR\x0eschemaOverride\"\x92\x01\n\x16GetKinesisSourceSchema\x12\x1e\n\nstreamName\x18\x01 \x01(\tR\nstreamName\x12X\n\x13rawStreamTranslator\x18\x02 \x01(\x0b\x32&.tecton_proto.args.UserDefinedFunctionR\x13rawStreamTranslator\"\xea\x01\n\x14GetKafkaSourceSchema\x12X\n\x13rawStreamTranslator\x18\x01 \x01(\x0b\x32&.tecton_proto.args.UserDefinedFunctionR\x13rawStreamTranslator\x12\x32\n\x15ssl_keystore_location\x18\x02 \x01(\tR\x13sslKeystoreLocation\x12\x44\n\x1fssl_keystore_password_secret_id\x18\x03 \x01(\tR\x1bsslKeystorePasswordSecretId\"\xb4\x03\n#GetFeatureViewMaterializationSchema\x12V\n\x14virtual_data_sources\x18\x02 \x03(\x0b\x32$.tecton_proto.data.VirtualDataSourceR\x12virtualDataSources\x12N\n\x0ftransformations\x18\x03 \x03(\x0b\x32$.tecton_proto.data.NewTransformationR\x0ftransformations\x12#\n\rtimestamp_key\x18\x04 \x01(\tR\x0ctimestampKey\x12\x1b\n\tjoin_keys\x18\x05 \x03(\tR\x08joinKeys\x12V\n\x12temporal_aggregate\x18\x06 \x01(\x0b\x32\'.tecton_proto.data.NewTemporalAggregateR\x11temporalAggregate\x12\x45\n\x0c\x66\x65\x61ture_view\x18\x07 \x01(\x0b\x32\".tecton_proto.args.FeatureViewArgsR\x0b\x66\x65\x61tureViewJ\x04\x08\x01\x10\x02\"\x91\x02\n\x14GetFeatureViewSchema\x12V\n\x14virtual_data_sources\x18\x02 \x03(\x0b\x32$.tecton_proto.data.VirtualDataSourceR\x12virtualDataSources\x12N\n\x0ftransformations\x18\x03 \x03(\x0b\x32$.tecton_proto.data.NewTransformationR\x0ftransformations\x12\x45\n\x0c\x66\x65\x61ture_view\x18\x05 \x01(\x0b\x32\".tecton_proto.args.FeatureViewArgsR\x0b\x66\x65\x61tureViewJ\x04\x08\x01\x10\x02J\x04\x08\x04\x10\x05\"\x8c\x02\n\x15GetQueryPlanInfoForFV\x12V\n\x14virtual_data_sources\x18\x02 \x03(\x0b\x32$.tecton_proto.data.VirtualDataSourceR\x12virtualDataSources\x12N\n\x0ftransformations\x18\x03 \x03(\x0b\x32$.tecton_proto.data.NewTransformationR\x0ftransformations\x12\x45\n\x0c\x66\x65\x61ture_view\x18\x04 \x01(\x0b\x32\".tecton_proto.args.FeatureViewArgsR\x0b\x66\x65\x61tureViewJ\x04\x08\x01\x10\x02\"\xd0\x08\n\x0e\x45xecuteRequest\x12W\n\x12getHiveTableSchema\x18\x01 \x01(\x0b\x32%.tecton_proto.data.GetHiveTableSchemaH\x00R\x12getHiveTableSchema\x12\x63\n\x16getRedshiftTableSchema\x18\x02 \x01(\x0b\x32).tecton_proto.data.GetRedshiftTableSchemaH\x00R\x16getRedshiftTableSchema\x12Z\n\x13getFileSourceSchema\x18\x03 \x01(\x0b\x32&.tecton_proto.data.GetFileSourceSchemaH\x00R\x13getFileSourceSchema\x12\x63\n\x16getKinesisSourceSchema\x18\x04 \x01(\x0b\x32).tecton_proto.data.GetKinesisSourceSchemaH\x00R\x16getKinesisSourceSchema\x12]\n\x14getKafkaSourceSchema\x18\x05 \x01(\x0b\x32\'.tecton_proto.data.GetKafkaSourceSchemaH\x00R\x14getKafkaSourceSchema\x12]\n\x14getFeatureViewSchema\x18\x0e \x01(\x0b\x32\'.tecton_proto.data.GetFeatureViewSchemaH\x00R\x14getFeatureViewSchema\x12\x8a\x01\n#getFeatureViewMaterializationSchema\x18\x0f \x01(\x0b\x32\x36.tecton_proto.data.GetFeatureViewMaterializationSchemaH\x00R#getFeatureViewMaterializationSchema\x12W\n\x12getSnowflakeSchema\x18\x0c \x01(\x0b\x32%.tecton_proto.data.GetSnowflakeSchemaH\x00R\x12getSnowflakeSchema\x12`\n\x15getQueryPlanInfoForFV\x18\r \x01(\x0b\x32(.tecton_proto.data.GetQueryPlanInfoForFVH\x00R\x15getQueryPlanInfoForFV\x12H\n\x07\x65nvVars\x18\x10 \x03(\x0b\x32..tecton_proto.data.ExecuteRequest.EnvVarsEntryR\x07\x65nvVars\x1a:\n\x0c\x45nvVarsEntry\x12\x10\n\x03key\x18\x01 \x01(\tR\x03key\x12\x14\n\x05value\x18\x02 \x01(\tR\x05value:\x02\x38\x01\x42\t\n\x07requestJ\x04\x08\x06\x10\x07J\x04\x08\x07\x10\x08J\x04\x08\x08\x10\tJ\x04\x08\t\x10\nJ\x04\x08\n\x10\x0bJ\x04\x08\x0b\x10\x0cJ\x04\x08\x11\x10\x12\"x\n\rQueryPlanInfo\x12\x1b\n\thas_joins\x18\x01 \x01(\x08R\x08hasJoins\x12)\n\x10has_aggregations\x18\x02 \x01(\x08R\x0fhasAggregations\x12\x1f\n\x0btable_names\x18\x03 \x03(\tR\ntableNames\"\xb4\x02\n\rExecuteResult\x12&\n\runcaughtError\x18\x01 \x01(\tH\x00R\runcaughtError\x12*\n\x0fvalidationError\x18\x05 \x01(\tH\x00R\x0fvalidationError\x12\x44\n\x0bsparkSchema\x18\x02 \x01(\x0b\x32 .tecton_proto.common.SparkSchemaH\x00R\x0bsparkSchema\x12H\n\rqueryPlanInfo\x18\x03 \x01(\x0b\x32 .tecton_proto.data.QueryPlanInfoH\x00R\rqueryPlanInfo\x12\x35\n\x06schema\x18\x04 \x01(\x0b\x32\x1b.tecton_proto.common.SchemaH\x00R\x06schemaB\x08\n\x06resultB\x13\n\x0f\x63om.tecton.dataP\x01'
  ,
  dependencies=[tecton__proto_dot_args_dot_data__source__pb2.DESCRIPTOR,tecton__proto_dot_args_dot_data__source__config__pb2.DESCRIPTOR,tecton__proto_dot_args_dot_user__defined__function__pb2.DESCRIPTOR,tecton__proto_dot_args_dot_feature__view__pb2.DESCRIPTOR,tecton__proto_dot_common_dot_id__pb2.DESCRIPTOR,tecton__proto_dot_common_dot_schema__pb2.DESCRIPTOR,tecton__proto_dot_common_dot_spark__schema__pb2.DESCRIPTOR,tecton__proto_dot_data_dot_feature__view__pb2.DESCRIPTOR,tecton__proto_dot_data_dot_virtual__data__source__pb2.DESCRIPTOR,tecton__proto_dot_data_dot_new__transformation__pb2.DESCRIPTOR,])




_GETHIVETABLESCHEMA = _descriptor.Descriptor(
  name='GetHiveTableSchema',
  full_name='tecton_proto.data.GetHiveTableSchema',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='database', full_name='tecton_proto.data.GetHiveTableSchema.database', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='database', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='table', full_name='tecton_proto.data.GetHiveTableSchema.table', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='table', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='timestampColumn', full_name='tecton_proto.data.GetHiveTableSchema.timestampColumn', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='timestampColumn', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='timestampFormat', full_name='tecton_proto.data.GetHiveTableSchema.timestampFormat', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='timestampFormat', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='rawBatchTranslator', full_name='tecton_proto.data.GetHiveTableSchema.rawBatchTranslator', index=4,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='rawBatchTranslator', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=457,
  serialized_end=699,
)


_GETREDSHIFTTABLESCHEMA = _descriptor.Descriptor(
  name='GetRedshiftTableSchema',
  full_name='tecton_proto.data.GetRedshiftTableSchema',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='endpoint', full_name='tecton_proto.data.GetRedshiftTableSchema.endpoint', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='endpoint', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='table', full_name='tecton_proto.data.GetRedshiftTableSchema.table', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='table', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='query', full_name='tecton_proto.data.GetRedshiftTableSchema.query', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='query', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='rawBatchTranslator', full_name='tecton_proto.data.GetRedshiftTableSchema.rawBatchTranslator', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='rawBatchTranslator', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='temps3dir', full_name='tecton_proto.data.GetRedshiftTableSchema.temps3dir', index=4,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='temps3dir', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=702,
  serialized_end=916,
)


_GETSNOWFLAKESCHEMA = _descriptor.Descriptor(
  name='GetSnowflakeSchema',
  full_name='tecton_proto.data.GetSnowflakeSchema',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='snowflakeArgs', full_name='tecton_proto.data.GetSnowflakeSchema.snowflakeArgs', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='snowflakeArgs', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=918,
  serialized_end=1020,
)


_GETFILESOURCESCHEMA = _descriptor.Descriptor(
  name='GetFileSourceSchema',
  full_name='tecton_proto.data.GetFileSourceSchema',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='uri', full_name='tecton_proto.data.GetFileSourceSchema.uri', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='uri', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='fileFormat', full_name='tecton_proto.data.GetFileSourceSchema.fileFormat', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='fileFormat', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='convertToGlueFormat', full_name='tecton_proto.data.GetFileSourceSchema.convertToGlueFormat', index=2,
      number=3, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='convertToGlueFormat', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='rawBatchTranslator', full_name='tecton_proto.data.GetFileSourceSchema.rawBatchTranslator', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='rawBatchTranslator', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='schemaUri', full_name='tecton_proto.data.GetFileSourceSchema.schemaUri', index=4,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='schemaUri', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='timestampColumn', full_name='tecton_proto.data.GetFileSourceSchema.timestampColumn', index=5,
      number=6, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='timestampColumn', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='timestampFormat', full_name='tecton_proto.data.GetFileSourceSchema.timestampFormat', index=6,
      number=7, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='timestampFormat', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='schemaOverride', full_name='tecton_proto.data.GetFileSourceSchema.schemaOverride', index=7,
      number=8, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='schemaOverride', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1023,
  serialized_end=1420,
)


_GETKINESISSOURCESCHEMA = _descriptor.Descriptor(
  name='GetKinesisSourceSchema',
  full_name='tecton_proto.data.GetKinesisSourceSchema',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='streamName', full_name='tecton_proto.data.GetKinesisSourceSchema.streamName', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='streamName', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='rawStreamTranslator', full_name='tecton_proto.data.GetKinesisSourceSchema.rawStreamTranslator', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='rawStreamTranslator', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1423,
  serialized_end=1569,
)


_GETKAFKASOURCESCHEMA = _descriptor.Descriptor(
  name='GetKafkaSourceSchema',
  full_name='tecton_proto.data.GetKafkaSourceSchema',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='rawStreamTranslator', full_name='tecton_proto.data.GetKafkaSourceSchema.rawStreamTranslator', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='rawStreamTranslator', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='ssl_keystore_location', full_name='tecton_proto.data.GetKafkaSourceSchema.ssl_keystore_location', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='sslKeystoreLocation', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='ssl_keystore_password_secret_id', full_name='tecton_proto.data.GetKafkaSourceSchema.ssl_keystore_password_secret_id', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='sslKeystorePasswordSecretId', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1572,
  serialized_end=1806,
)


_GETFEATUREVIEWMATERIALIZATIONSCHEMA = _descriptor.Descriptor(
  name='GetFeatureViewMaterializationSchema',
  full_name='tecton_proto.data.GetFeatureViewMaterializationSchema',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='virtual_data_sources', full_name='tecton_proto.data.GetFeatureViewMaterializationSchema.virtual_data_sources', index=0,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='virtualDataSources', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='transformations', full_name='tecton_proto.data.GetFeatureViewMaterializationSchema.transformations', index=1,
      number=3, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='transformations', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='timestamp_key', full_name='tecton_proto.data.GetFeatureViewMaterializationSchema.timestamp_key', index=2,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='timestampKey', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='join_keys', full_name='tecton_proto.data.GetFeatureViewMaterializationSchema.join_keys', index=3,
      number=5, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='joinKeys', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='temporal_aggregate', full_name='tecton_proto.data.GetFeatureViewMaterializationSchema.temporal_aggregate', index=4,
      number=6, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='temporalAggregate', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='feature_view', full_name='tecton_proto.data.GetFeatureViewMaterializationSchema.feature_view', index=5,
      number=7, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='featureView', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1809,
  serialized_end=2245,
)


_GETFEATUREVIEWSCHEMA = _descriptor.Descriptor(
  name='GetFeatureViewSchema',
  full_name='tecton_proto.data.GetFeatureViewSchema',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='virtual_data_sources', full_name='tecton_proto.data.GetFeatureViewSchema.virtual_data_sources', index=0,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='virtualDataSources', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='transformations', full_name='tecton_proto.data.GetFeatureViewSchema.transformations', index=1,
      number=3, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='transformations', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='feature_view', full_name='tecton_proto.data.GetFeatureViewSchema.feature_view', index=2,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='featureView', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2248,
  serialized_end=2521,
)


_GETQUERYPLANINFOFORFV = _descriptor.Descriptor(
  name='GetQueryPlanInfoForFV',
  full_name='tecton_proto.data.GetQueryPlanInfoForFV',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='virtual_data_sources', full_name='tecton_proto.data.GetQueryPlanInfoForFV.virtual_data_sources', index=0,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='virtualDataSources', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='transformations', full_name='tecton_proto.data.GetQueryPlanInfoForFV.transformations', index=1,
      number=3, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='transformations', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='feature_view', full_name='tecton_proto.data.GetQueryPlanInfoForFV.feature_view', index=2,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='featureView', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2524,
  serialized_end=2792,
)


_EXECUTEREQUEST_ENVVARSENTRY = _descriptor.Descriptor(
  name='EnvVarsEntry',
  full_name='tecton_proto.data.ExecuteRequest.EnvVarsEntry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='tecton_proto.data.ExecuteRequest.EnvVarsEntry.key', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='key', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='value', full_name='tecton_proto.data.ExecuteRequest.EnvVarsEntry.value', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='value', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'8\001',
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3788,
  serialized_end=3846,
)

_EXECUTEREQUEST = _descriptor.Descriptor(
  name='ExecuteRequest',
  full_name='tecton_proto.data.ExecuteRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='getHiveTableSchema', full_name='tecton_proto.data.ExecuteRequest.getHiveTableSchema', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='getHiveTableSchema', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='getRedshiftTableSchema', full_name='tecton_proto.data.ExecuteRequest.getRedshiftTableSchema', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='getRedshiftTableSchema', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='getFileSourceSchema', full_name='tecton_proto.data.ExecuteRequest.getFileSourceSchema', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='getFileSourceSchema', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='getKinesisSourceSchema', full_name='tecton_proto.data.ExecuteRequest.getKinesisSourceSchema', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='getKinesisSourceSchema', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='getKafkaSourceSchema', full_name='tecton_proto.data.ExecuteRequest.getKafkaSourceSchema', index=4,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='getKafkaSourceSchema', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='getFeatureViewSchema', full_name='tecton_proto.data.ExecuteRequest.getFeatureViewSchema', index=5,
      number=14, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='getFeatureViewSchema', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='getFeatureViewMaterializationSchema', full_name='tecton_proto.data.ExecuteRequest.getFeatureViewMaterializationSchema', index=6,
      number=15, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='getFeatureViewMaterializationSchema', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='getSnowflakeSchema', full_name='tecton_proto.data.ExecuteRequest.getSnowflakeSchema', index=7,
      number=12, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='getSnowflakeSchema', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='getQueryPlanInfoForFV', full_name='tecton_proto.data.ExecuteRequest.getQueryPlanInfoForFV', index=8,
      number=13, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='getQueryPlanInfoForFV', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='envVars', full_name='tecton_proto.data.ExecuteRequest.envVars', index=9,
      number=16, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='envVars', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_EXECUTEREQUEST_ENVVARSENTRY, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='request', full_name='tecton_proto.data.ExecuteRequest.request',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=2795,
  serialized_end=3899,
)


_QUERYPLANINFO = _descriptor.Descriptor(
  name='QueryPlanInfo',
  full_name='tecton_proto.data.QueryPlanInfo',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='has_joins', full_name='tecton_proto.data.QueryPlanInfo.has_joins', index=0,
      number=1, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='hasJoins', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='has_aggregations', full_name='tecton_proto.data.QueryPlanInfo.has_aggregations', index=1,
      number=2, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='hasAggregations', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='table_names', full_name='tecton_proto.data.QueryPlanInfo.table_names', index=2,
      number=3, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='tableNames', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3901,
  serialized_end=4021,
)


_EXECUTERESULT = _descriptor.Descriptor(
  name='ExecuteResult',
  full_name='tecton_proto.data.ExecuteResult',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='uncaughtError', full_name='tecton_proto.data.ExecuteResult.uncaughtError', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='uncaughtError', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='validationError', full_name='tecton_proto.data.ExecuteResult.validationError', index=1,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='validationError', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='sparkSchema', full_name='tecton_proto.data.ExecuteResult.sparkSchema', index=2,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='sparkSchema', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='queryPlanInfo', full_name='tecton_proto.data.ExecuteResult.queryPlanInfo', index=3,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='queryPlanInfo', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='schema', full_name='tecton_proto.data.ExecuteResult.schema', index=4,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='schema', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='result', full_name='tecton_proto.data.ExecuteResult.result',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=4024,
  serialized_end=4332,
)

_GETHIVETABLESCHEMA.fields_by_name['rawBatchTranslator'].message_type = tecton__proto_dot_args_dot_user__defined__function__pb2._USERDEFINEDFUNCTION
_GETREDSHIFTTABLESCHEMA.fields_by_name['rawBatchTranslator'].message_type = tecton__proto_dot_args_dot_user__defined__function__pb2._USERDEFINEDFUNCTION
_GETSNOWFLAKESCHEMA.fields_by_name['snowflakeArgs'].message_type = tecton__proto_dot_args_dot_data__source__pb2._SNOWFLAKEDATASOURCEARGS
_GETFILESOURCESCHEMA.fields_by_name['rawBatchTranslator'].message_type = tecton__proto_dot_args_dot_user__defined__function__pb2._USERDEFINEDFUNCTION
_GETFILESOURCESCHEMA.fields_by_name['schemaOverride'].message_type = tecton__proto_dot_common_dot_spark__schema__pb2._SPARKSCHEMA
_GETKINESISSOURCESCHEMA.fields_by_name['rawStreamTranslator'].message_type = tecton__proto_dot_args_dot_user__defined__function__pb2._USERDEFINEDFUNCTION
_GETKAFKASOURCESCHEMA.fields_by_name['rawStreamTranslator'].message_type = tecton__proto_dot_args_dot_user__defined__function__pb2._USERDEFINEDFUNCTION
_GETFEATUREVIEWMATERIALIZATIONSCHEMA.fields_by_name['virtual_data_sources'].message_type = tecton__proto_dot_data_dot_virtual__data__source__pb2._VIRTUALDATASOURCE
_GETFEATUREVIEWMATERIALIZATIONSCHEMA.fields_by_name['transformations'].message_type = tecton__proto_dot_data_dot_new__transformation__pb2._NEWTRANSFORMATION
_GETFEATUREVIEWMATERIALIZATIONSCHEMA.fields_by_name['temporal_aggregate'].message_type = tecton__proto_dot_data_dot_feature__view__pb2._NEWTEMPORALAGGREGATE
_GETFEATUREVIEWMATERIALIZATIONSCHEMA.fields_by_name['feature_view'].message_type = tecton__proto_dot_args_dot_feature__view__pb2._FEATUREVIEWARGS
_GETFEATUREVIEWSCHEMA.fields_by_name['virtual_data_sources'].message_type = tecton__proto_dot_data_dot_virtual__data__source__pb2._VIRTUALDATASOURCE
_GETFEATUREVIEWSCHEMA.fields_by_name['transformations'].message_type = tecton__proto_dot_data_dot_new__transformation__pb2._NEWTRANSFORMATION
_GETFEATUREVIEWSCHEMA.fields_by_name['feature_view'].message_type = tecton__proto_dot_args_dot_feature__view__pb2._FEATUREVIEWARGS
_GETQUERYPLANINFOFORFV.fields_by_name['virtual_data_sources'].message_type = tecton__proto_dot_data_dot_virtual__data__source__pb2._VIRTUALDATASOURCE
_GETQUERYPLANINFOFORFV.fields_by_name['transformations'].message_type = tecton__proto_dot_data_dot_new__transformation__pb2._NEWTRANSFORMATION
_GETQUERYPLANINFOFORFV.fields_by_name['feature_view'].message_type = tecton__proto_dot_args_dot_feature__view__pb2._FEATUREVIEWARGS
_EXECUTEREQUEST_ENVVARSENTRY.containing_type = _EXECUTEREQUEST
_EXECUTEREQUEST.fields_by_name['getHiveTableSchema'].message_type = _GETHIVETABLESCHEMA
_EXECUTEREQUEST.fields_by_name['getRedshiftTableSchema'].message_type = _GETREDSHIFTTABLESCHEMA
_EXECUTEREQUEST.fields_by_name['getFileSourceSchema'].message_type = _GETFILESOURCESCHEMA
_EXECUTEREQUEST.fields_by_name['getKinesisSourceSchema'].message_type = _GETKINESISSOURCESCHEMA
_EXECUTEREQUEST.fields_by_name['getKafkaSourceSchema'].message_type = _GETKAFKASOURCESCHEMA
_EXECUTEREQUEST.fields_by_name['getFeatureViewSchema'].message_type = _GETFEATUREVIEWSCHEMA
_EXECUTEREQUEST.fields_by_name['getFeatureViewMaterializationSchema'].message_type = _GETFEATUREVIEWMATERIALIZATIONSCHEMA
_EXECUTEREQUEST.fields_by_name['getSnowflakeSchema'].message_type = _GETSNOWFLAKESCHEMA
_EXECUTEREQUEST.fields_by_name['getQueryPlanInfoForFV'].message_type = _GETQUERYPLANINFOFORFV
_EXECUTEREQUEST.fields_by_name['envVars'].message_type = _EXECUTEREQUEST_ENVVARSENTRY
_EXECUTEREQUEST.oneofs_by_name['request'].fields.append(
  _EXECUTEREQUEST.fields_by_name['getHiveTableSchema'])
_EXECUTEREQUEST.fields_by_name['getHiveTableSchema'].containing_oneof = _EXECUTEREQUEST.oneofs_by_name['request']
_EXECUTEREQUEST.oneofs_by_name['request'].fields.append(
  _EXECUTEREQUEST.fields_by_name['getRedshiftTableSchema'])
_EXECUTEREQUEST.fields_by_name['getRedshiftTableSchema'].containing_oneof = _EXECUTEREQUEST.oneofs_by_name['request']
_EXECUTEREQUEST.oneofs_by_name['request'].fields.append(
  _EXECUTEREQUEST.fields_by_name['getFileSourceSchema'])
_EXECUTEREQUEST.fields_by_name['getFileSourceSchema'].containing_oneof = _EXECUTEREQUEST.oneofs_by_name['request']
_EXECUTEREQUEST.oneofs_by_name['request'].fields.append(
  _EXECUTEREQUEST.fields_by_name['getKinesisSourceSchema'])
_EXECUTEREQUEST.fields_by_name['getKinesisSourceSchema'].containing_oneof = _EXECUTEREQUEST.oneofs_by_name['request']
_EXECUTEREQUEST.oneofs_by_name['request'].fields.append(
  _EXECUTEREQUEST.fields_by_name['getKafkaSourceSchema'])
_EXECUTEREQUEST.fields_by_name['getKafkaSourceSchema'].containing_oneof = _EXECUTEREQUEST.oneofs_by_name['request']
_EXECUTEREQUEST.oneofs_by_name['request'].fields.append(
  _EXECUTEREQUEST.fields_by_name['getFeatureViewSchema'])
_EXECUTEREQUEST.fields_by_name['getFeatureViewSchema'].containing_oneof = _EXECUTEREQUEST.oneofs_by_name['request']
_EXECUTEREQUEST.oneofs_by_name['request'].fields.append(
  _EXECUTEREQUEST.fields_by_name['getFeatureViewMaterializationSchema'])
_EXECUTEREQUEST.fields_by_name['getFeatureViewMaterializationSchema'].containing_oneof = _EXECUTEREQUEST.oneofs_by_name['request']
_EXECUTEREQUEST.oneofs_by_name['request'].fields.append(
  _EXECUTEREQUEST.fields_by_name['getSnowflakeSchema'])
_EXECUTEREQUEST.fields_by_name['getSnowflakeSchema'].containing_oneof = _EXECUTEREQUEST.oneofs_by_name['request']
_EXECUTEREQUEST.oneofs_by_name['request'].fields.append(
  _EXECUTEREQUEST.fields_by_name['getQueryPlanInfoForFV'])
_EXECUTEREQUEST.fields_by_name['getQueryPlanInfoForFV'].containing_oneof = _EXECUTEREQUEST.oneofs_by_name['request']
_EXECUTERESULT.fields_by_name['sparkSchema'].message_type = tecton__proto_dot_common_dot_spark__schema__pb2._SPARKSCHEMA
_EXECUTERESULT.fields_by_name['queryPlanInfo'].message_type = _QUERYPLANINFO
_EXECUTERESULT.fields_by_name['schema'].message_type = tecton__proto_dot_common_dot_schema__pb2._SCHEMA
_EXECUTERESULT.oneofs_by_name['result'].fields.append(
  _EXECUTERESULT.fields_by_name['uncaughtError'])
_EXECUTERESULT.fields_by_name['uncaughtError'].containing_oneof = _EXECUTERESULT.oneofs_by_name['result']
_EXECUTERESULT.oneofs_by_name['result'].fields.append(
  _EXECUTERESULT.fields_by_name['validationError'])
_EXECUTERESULT.fields_by_name['validationError'].containing_oneof = _EXECUTERESULT.oneofs_by_name['result']
_EXECUTERESULT.oneofs_by_name['result'].fields.append(
  _EXECUTERESULT.fields_by_name['sparkSchema'])
_EXECUTERESULT.fields_by_name['sparkSchema'].containing_oneof = _EXECUTERESULT.oneofs_by_name['result']
_EXECUTERESULT.oneofs_by_name['result'].fields.append(
  _EXECUTERESULT.fields_by_name['queryPlanInfo'])
_EXECUTERESULT.fields_by_name['queryPlanInfo'].containing_oneof = _EXECUTERESULT.oneofs_by_name['result']
_EXECUTERESULT.oneofs_by_name['result'].fields.append(
  _EXECUTERESULT.fields_by_name['schema'])
_EXECUTERESULT.fields_by_name['schema'].containing_oneof = _EXECUTERESULT.oneofs_by_name['result']
DESCRIPTOR.message_types_by_name['GetHiveTableSchema'] = _GETHIVETABLESCHEMA
DESCRIPTOR.message_types_by_name['GetRedshiftTableSchema'] = _GETREDSHIFTTABLESCHEMA
DESCRIPTOR.message_types_by_name['GetSnowflakeSchema'] = _GETSNOWFLAKESCHEMA
DESCRIPTOR.message_types_by_name['GetFileSourceSchema'] = _GETFILESOURCESCHEMA
DESCRIPTOR.message_types_by_name['GetKinesisSourceSchema'] = _GETKINESISSOURCESCHEMA
DESCRIPTOR.message_types_by_name['GetKafkaSourceSchema'] = _GETKAFKASOURCESCHEMA
DESCRIPTOR.message_types_by_name['GetFeatureViewMaterializationSchema'] = _GETFEATUREVIEWMATERIALIZATIONSCHEMA
DESCRIPTOR.message_types_by_name['GetFeatureViewSchema'] = _GETFEATUREVIEWSCHEMA
DESCRIPTOR.message_types_by_name['GetQueryPlanInfoForFV'] = _GETQUERYPLANINFOFORFV
DESCRIPTOR.message_types_by_name['ExecuteRequest'] = _EXECUTEREQUEST
DESCRIPTOR.message_types_by_name['QueryPlanInfo'] = _QUERYPLANINFO
DESCRIPTOR.message_types_by_name['ExecuteResult'] = _EXECUTERESULT
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

GetHiveTableSchema = _reflection.GeneratedProtocolMessageType('GetHiveTableSchema', (_message.Message,), {
  'DESCRIPTOR' : _GETHIVETABLESCHEMA,
  '__module__' : 'tecton_proto.data.remote_spark_pb2'
  # @@protoc_insertion_point(class_scope:tecton_proto.data.GetHiveTableSchema)
  })
_sym_db.RegisterMessage(GetHiveTableSchema)

GetRedshiftTableSchema = _reflection.GeneratedProtocolMessageType('GetRedshiftTableSchema', (_message.Message,), {
  'DESCRIPTOR' : _GETREDSHIFTTABLESCHEMA,
  '__module__' : 'tecton_proto.data.remote_spark_pb2'
  # @@protoc_insertion_point(class_scope:tecton_proto.data.GetRedshiftTableSchema)
  })
_sym_db.RegisterMessage(GetRedshiftTableSchema)

GetSnowflakeSchema = _reflection.GeneratedProtocolMessageType('GetSnowflakeSchema', (_message.Message,), {
  'DESCRIPTOR' : _GETSNOWFLAKESCHEMA,
  '__module__' : 'tecton_proto.data.remote_spark_pb2'
  # @@protoc_insertion_point(class_scope:tecton_proto.data.GetSnowflakeSchema)
  })
_sym_db.RegisterMessage(GetSnowflakeSchema)

GetFileSourceSchema = _reflection.GeneratedProtocolMessageType('GetFileSourceSchema', (_message.Message,), {
  'DESCRIPTOR' : _GETFILESOURCESCHEMA,
  '__module__' : 'tecton_proto.data.remote_spark_pb2'
  # @@protoc_insertion_point(class_scope:tecton_proto.data.GetFileSourceSchema)
  })
_sym_db.RegisterMessage(GetFileSourceSchema)

GetKinesisSourceSchema = _reflection.GeneratedProtocolMessageType('GetKinesisSourceSchema', (_message.Message,), {
  'DESCRIPTOR' : _GETKINESISSOURCESCHEMA,
  '__module__' : 'tecton_proto.data.remote_spark_pb2'
  # @@protoc_insertion_point(class_scope:tecton_proto.data.GetKinesisSourceSchema)
  })
_sym_db.RegisterMessage(GetKinesisSourceSchema)

GetKafkaSourceSchema = _reflection.GeneratedProtocolMessageType('GetKafkaSourceSchema', (_message.Message,), {
  'DESCRIPTOR' : _GETKAFKASOURCESCHEMA,
  '__module__' : 'tecton_proto.data.remote_spark_pb2'
  # @@protoc_insertion_point(class_scope:tecton_proto.data.GetKafkaSourceSchema)
  })
_sym_db.RegisterMessage(GetKafkaSourceSchema)

GetFeatureViewMaterializationSchema = _reflection.GeneratedProtocolMessageType('GetFeatureViewMaterializationSchema', (_message.Message,), {
  'DESCRIPTOR' : _GETFEATUREVIEWMATERIALIZATIONSCHEMA,
  '__module__' : 'tecton_proto.data.remote_spark_pb2'
  # @@protoc_insertion_point(class_scope:tecton_proto.data.GetFeatureViewMaterializationSchema)
  })
_sym_db.RegisterMessage(GetFeatureViewMaterializationSchema)

GetFeatureViewSchema = _reflection.GeneratedProtocolMessageType('GetFeatureViewSchema', (_message.Message,), {
  'DESCRIPTOR' : _GETFEATUREVIEWSCHEMA,
  '__module__' : 'tecton_proto.data.remote_spark_pb2'
  # @@protoc_insertion_point(class_scope:tecton_proto.data.GetFeatureViewSchema)
  })
_sym_db.RegisterMessage(GetFeatureViewSchema)

GetQueryPlanInfoForFV = _reflection.GeneratedProtocolMessageType('GetQueryPlanInfoForFV', (_message.Message,), {
  'DESCRIPTOR' : _GETQUERYPLANINFOFORFV,
  '__module__' : 'tecton_proto.data.remote_spark_pb2'
  # @@protoc_insertion_point(class_scope:tecton_proto.data.GetQueryPlanInfoForFV)
  })
_sym_db.RegisterMessage(GetQueryPlanInfoForFV)

ExecuteRequest = _reflection.GeneratedProtocolMessageType('ExecuteRequest', (_message.Message,), {

  'EnvVarsEntry' : _reflection.GeneratedProtocolMessageType('EnvVarsEntry', (_message.Message,), {
    'DESCRIPTOR' : _EXECUTEREQUEST_ENVVARSENTRY,
    '__module__' : 'tecton_proto.data.remote_spark_pb2'
    # @@protoc_insertion_point(class_scope:tecton_proto.data.ExecuteRequest.EnvVarsEntry)
    })
  ,
  'DESCRIPTOR' : _EXECUTEREQUEST,
  '__module__' : 'tecton_proto.data.remote_spark_pb2'
  # @@protoc_insertion_point(class_scope:tecton_proto.data.ExecuteRequest)
  })
_sym_db.RegisterMessage(ExecuteRequest)
_sym_db.RegisterMessage(ExecuteRequest.EnvVarsEntry)

QueryPlanInfo = _reflection.GeneratedProtocolMessageType('QueryPlanInfo', (_message.Message,), {
  'DESCRIPTOR' : _QUERYPLANINFO,
  '__module__' : 'tecton_proto.data.remote_spark_pb2'
  # @@protoc_insertion_point(class_scope:tecton_proto.data.QueryPlanInfo)
  })
_sym_db.RegisterMessage(QueryPlanInfo)

ExecuteResult = _reflection.GeneratedProtocolMessageType('ExecuteResult', (_message.Message,), {
  'DESCRIPTOR' : _EXECUTERESULT,
  '__module__' : 'tecton_proto.data.remote_spark_pb2'
  # @@protoc_insertion_point(class_scope:tecton_proto.data.ExecuteResult)
  })
_sym_db.RegisterMessage(ExecuteResult)


DESCRIPTOR._options = None
_EXECUTEREQUEST_ENVVARSENTRY._options = None
# @@protoc_insertion_point(module_scope)
