# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: tecton_proto/online_store/feature_value.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor.FileDescriptor(
  name='tecton_proto/online_store/feature_value.proto',
  package='tecton_proto.online_store',
  syntax='proto2',
  serialized_options=b'\n\026com.tecton.onlinestoreP\001',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n-tecton_proto/online_store/feature_value.proto\x12\x19tecton_proto.online_store\"\xdf\x02\n\x0c\x46\x65\x61tureValue\x12H\n\x0b\x61rray_value\x18\x01 \x01(\x0b\x32%.tecton_proto.online_store.ArrayValueH\x00R\narrayValue\x12%\n\rfloat64_value\x18\x02 \x01(\x01H\x00R\x0c\x66loat64Value\x12%\n\rfloat32_value\x18\x03 \x01(\x02H\x00R\x0c\x66loat32Value\x12!\n\x0bint64_value\x18\x04 \x01(\x03H\x00R\nint64Value\x12\x1f\n\nbool_value\x18\x05 \x01(\x08H\x00R\tboolValue\x12#\n\x0cstring_value\x18\x06 \x01(\tH\x00R\x0bstringValue\x12\x45\n\nnull_value\x18\x07 \x01(\x0b\x32$.tecton_proto.online_store.NullValueH\x00R\tnullValueB\x07\n\x05value\"b\n\x10\x46\x65\x61tureValueList\x12N\n\x0e\x66\x65\x61ture_values\x18\x01 \x03(\x0b\x32\'.tecton_proto.online_store.FeatureValueR\rfeatureValues\"\xaa\x01\n\rRedisTAFVData\x12\x1f\n\x0b\x61nchor_time\x18\x01 \x01(\x03R\nanchorTime\x12(\n\x10written_by_batch\x18\x02 \x01(\x08R\x0ewrittenByBatch\x12N\n\x0e\x66\x65\x61ture_values\x18\x03 \x03(\x0b\x32\'.tecton_proto.online_store.FeatureValueR\rfeatureValues\"\x0b\n\tNullValue\"\x9f\x02\n\nArrayValue\x12#\n\rstring_values\x18\x01 \x03(\tR\x0cstringValues\x12H\n\x0c\x61rray_values\x18\x02 \x03(\x0b\x32%.tecton_proto.online_store.ArrayValueR\x0b\x61rrayValues\x12%\n\x0cint64_values\x18\x06 \x03(\x03\x42\x02\x10\x01R\x0bint64Values\x12)\n\x0e\x66loat32_values\x18\x07 \x03(\x02\x42\x02\x10\x01R\rfloat32Values\x12)\n\x0e\x66loat64_values\x18\x08 \x03(\x01\x42\x02\x10\x01R\rfloat64Values\x12%\n\x0cnull_indices\x18\t \x03(\x05\x42\x02\x10\x01R\x0bnullIndicesB\x1a\n\x16\x63om.tecton.onlinestoreP\x01'
)




_FEATUREVALUE = _descriptor.Descriptor(
  name='FeatureValue',
  full_name='tecton_proto.online_store.FeatureValue',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='array_value', full_name='tecton_proto.online_store.FeatureValue.array_value', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='arrayValue', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='float64_value', full_name='tecton_proto.online_store.FeatureValue.float64_value', index=1,
      number=2, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='float64Value', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='float32_value', full_name='tecton_proto.online_store.FeatureValue.float32_value', index=2,
      number=3, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='float32Value', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='int64_value', full_name='tecton_proto.online_store.FeatureValue.int64_value', index=3,
      number=4, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='int64Value', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='bool_value', full_name='tecton_proto.online_store.FeatureValue.bool_value', index=4,
      number=5, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='boolValue', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='string_value', full_name='tecton_proto.online_store.FeatureValue.string_value', index=5,
      number=6, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='stringValue', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='null_value', full_name='tecton_proto.online_store.FeatureValue.null_value', index=6,
      number=7, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='nullValue', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='value', full_name='tecton_proto.online_store.FeatureValue.value',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=77,
  serialized_end=428,
)


_FEATUREVALUELIST = _descriptor.Descriptor(
  name='FeatureValueList',
  full_name='tecton_proto.online_store.FeatureValueList',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='feature_values', full_name='tecton_proto.online_store.FeatureValueList.feature_values', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='featureValues', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=430,
  serialized_end=528,
)


_REDISTAFVDATA = _descriptor.Descriptor(
  name='RedisTAFVData',
  full_name='tecton_proto.online_store.RedisTAFVData',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='anchor_time', full_name='tecton_proto.online_store.RedisTAFVData.anchor_time', index=0,
      number=1, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='anchorTime', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='written_by_batch', full_name='tecton_proto.online_store.RedisTAFVData.written_by_batch', index=1,
      number=2, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='writtenByBatch', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='feature_values', full_name='tecton_proto.online_store.RedisTAFVData.feature_values', index=2,
      number=3, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='featureValues', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=531,
  serialized_end=701,
)


_NULLVALUE = _descriptor.Descriptor(
  name='NullValue',
  full_name='tecton_proto.online_store.NullValue',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=703,
  serialized_end=714,
)


_ARRAYVALUE = _descriptor.Descriptor(
  name='ArrayValue',
  full_name='tecton_proto.online_store.ArrayValue',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='string_values', full_name='tecton_proto.online_store.ArrayValue.string_values', index=0,
      number=1, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='stringValues', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='array_values', full_name='tecton_proto.online_store.ArrayValue.array_values', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='arrayValues', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='int64_values', full_name='tecton_proto.online_store.ArrayValue.int64_values', index=2,
      number=6, type=3, cpp_type=2, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\020\001', json_name='int64Values', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='float32_values', full_name='tecton_proto.online_store.ArrayValue.float32_values', index=3,
      number=7, type=2, cpp_type=6, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\020\001', json_name='float32Values', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='float64_values', full_name='tecton_proto.online_store.ArrayValue.float64_values', index=4,
      number=8, type=1, cpp_type=5, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\020\001', json_name='float64Values', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='null_indices', full_name='tecton_proto.online_store.ArrayValue.null_indices', index=5,
      number=9, type=5, cpp_type=1, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\020\001', json_name='nullIndices', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=717,
  serialized_end=1004,
)

_FEATUREVALUE.fields_by_name['array_value'].message_type = _ARRAYVALUE
_FEATUREVALUE.fields_by_name['null_value'].message_type = _NULLVALUE
_FEATUREVALUE.oneofs_by_name['value'].fields.append(
  _FEATUREVALUE.fields_by_name['array_value'])
_FEATUREVALUE.fields_by_name['array_value'].containing_oneof = _FEATUREVALUE.oneofs_by_name['value']
_FEATUREVALUE.oneofs_by_name['value'].fields.append(
  _FEATUREVALUE.fields_by_name['float64_value'])
_FEATUREVALUE.fields_by_name['float64_value'].containing_oneof = _FEATUREVALUE.oneofs_by_name['value']
_FEATUREVALUE.oneofs_by_name['value'].fields.append(
  _FEATUREVALUE.fields_by_name['float32_value'])
_FEATUREVALUE.fields_by_name['float32_value'].containing_oneof = _FEATUREVALUE.oneofs_by_name['value']
_FEATUREVALUE.oneofs_by_name['value'].fields.append(
  _FEATUREVALUE.fields_by_name['int64_value'])
_FEATUREVALUE.fields_by_name['int64_value'].containing_oneof = _FEATUREVALUE.oneofs_by_name['value']
_FEATUREVALUE.oneofs_by_name['value'].fields.append(
  _FEATUREVALUE.fields_by_name['bool_value'])
_FEATUREVALUE.fields_by_name['bool_value'].containing_oneof = _FEATUREVALUE.oneofs_by_name['value']
_FEATUREVALUE.oneofs_by_name['value'].fields.append(
  _FEATUREVALUE.fields_by_name['string_value'])
_FEATUREVALUE.fields_by_name['string_value'].containing_oneof = _FEATUREVALUE.oneofs_by_name['value']
_FEATUREVALUE.oneofs_by_name['value'].fields.append(
  _FEATUREVALUE.fields_by_name['null_value'])
_FEATUREVALUE.fields_by_name['null_value'].containing_oneof = _FEATUREVALUE.oneofs_by_name['value']
_FEATUREVALUELIST.fields_by_name['feature_values'].message_type = _FEATUREVALUE
_REDISTAFVDATA.fields_by_name['feature_values'].message_type = _FEATUREVALUE
_ARRAYVALUE.fields_by_name['array_values'].message_type = _ARRAYVALUE
DESCRIPTOR.message_types_by_name['FeatureValue'] = _FEATUREVALUE
DESCRIPTOR.message_types_by_name['FeatureValueList'] = _FEATUREVALUELIST
DESCRIPTOR.message_types_by_name['RedisTAFVData'] = _REDISTAFVDATA
DESCRIPTOR.message_types_by_name['NullValue'] = _NULLVALUE
DESCRIPTOR.message_types_by_name['ArrayValue'] = _ARRAYVALUE
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

FeatureValue = _reflection.GeneratedProtocolMessageType('FeatureValue', (_message.Message,), {
  'DESCRIPTOR' : _FEATUREVALUE,
  '__module__' : 'tecton_proto.online_store.feature_value_pb2'
  # @@protoc_insertion_point(class_scope:tecton_proto.online_store.FeatureValue)
  })
_sym_db.RegisterMessage(FeatureValue)

FeatureValueList = _reflection.GeneratedProtocolMessageType('FeatureValueList', (_message.Message,), {
  'DESCRIPTOR' : _FEATUREVALUELIST,
  '__module__' : 'tecton_proto.online_store.feature_value_pb2'
  # @@protoc_insertion_point(class_scope:tecton_proto.online_store.FeatureValueList)
  })
_sym_db.RegisterMessage(FeatureValueList)

RedisTAFVData = _reflection.GeneratedProtocolMessageType('RedisTAFVData', (_message.Message,), {
  'DESCRIPTOR' : _REDISTAFVDATA,
  '__module__' : 'tecton_proto.online_store.feature_value_pb2'
  # @@protoc_insertion_point(class_scope:tecton_proto.online_store.RedisTAFVData)
  })
_sym_db.RegisterMessage(RedisTAFVData)

NullValue = _reflection.GeneratedProtocolMessageType('NullValue', (_message.Message,), {
  'DESCRIPTOR' : _NULLVALUE,
  '__module__' : 'tecton_proto.online_store.feature_value_pb2'
  # @@protoc_insertion_point(class_scope:tecton_proto.online_store.NullValue)
  })
_sym_db.RegisterMessage(NullValue)

ArrayValue = _reflection.GeneratedProtocolMessageType('ArrayValue', (_message.Message,), {
  'DESCRIPTOR' : _ARRAYVALUE,
  '__module__' : 'tecton_proto.online_store.feature_value_pb2'
  # @@protoc_insertion_point(class_scope:tecton_proto.online_store.ArrayValue)
  })
_sym_db.RegisterMessage(ArrayValue)


DESCRIPTOR._options = None
_ARRAYVALUE.fields_by_name['int64_values']._options = None
_ARRAYVALUE.fields_by_name['float32_values']._options = None
_ARRAYVALUE.fields_by_name['float64_values']._options = None
_ARRAYVALUE.fields_by_name['null_indices']._options = None
# @@protoc_insertion_point(module_scope)
