# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: tecton_proto/data/summary.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from tecton_proto.data import fco_metadata_pb2 as tecton__proto_dot_data_dot_fco__metadata__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='tecton_proto/data/summary.proto',
  package='tecton_proto.data',
  syntax='proto2',
  serialized_options=b'\n\017com.tecton.dataP\001',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n\x1ftecton_proto/data/summary.proto\x12\x11tecton_proto.data\x1a$tecton_proto/data/fco_metadata.proto\"\xcd\x01\n\x0bSummaryItem\x12\x10\n\x03key\x18\x01 \x01(\tR\x03key\x12!\n\x0c\x64isplay_name\x18\x02 \x01(\tR\x0b\x64isplayName\x12\x14\n\x05value\x18\x03 \x01(\tR\x05value\x12!\n\x0cmulti_values\x18\x04 \x03(\tR\x0bmultiValues\x12P\n\x14nested_summary_items\x18\x05 \x03(\x0b\x32\x1e.tecton_proto.data.SummaryItemR\x12nestedSummaryItems\"\x94\x01\n\nFcoSummary\x12\x41\n\x0c\x66\x63o_metadata\x18\x01 \x01(\x0b\x32\x1e.tecton_proto.data.FcoMetadataR\x0b\x66\x63oMetadata\x12\x43\n\rsummary_items\x18\x02 \x03(\x0b\x32\x1e.tecton_proto.data.SummaryItemR\x0csummaryItemsB\x13\n\x0f\x63om.tecton.dataP\x01'
  ,
  dependencies=[tecton__proto_dot_data_dot_fco__metadata__pb2.DESCRIPTOR,])




_SUMMARYITEM = _descriptor.Descriptor(
  name='SummaryItem',
  full_name='tecton_proto.data.SummaryItem',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='tecton_proto.data.SummaryItem.key', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='key', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='display_name', full_name='tecton_proto.data.SummaryItem.display_name', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='displayName', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='value', full_name='tecton_proto.data.SummaryItem.value', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='value', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='multi_values', full_name='tecton_proto.data.SummaryItem.multi_values', index=3,
      number=4, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='multiValues', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='nested_summary_items', full_name='tecton_proto.data.SummaryItem.nested_summary_items', index=4,
      number=5, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='nestedSummaryItems', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=93,
  serialized_end=298,
)


_FCOSUMMARY = _descriptor.Descriptor(
  name='FcoSummary',
  full_name='tecton_proto.data.FcoSummary',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='fco_metadata', full_name='tecton_proto.data.FcoSummary.fco_metadata', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='fcoMetadata', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='summary_items', full_name='tecton_proto.data.FcoSummary.summary_items', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='summaryItems', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=301,
  serialized_end=449,
)

_SUMMARYITEM.fields_by_name['nested_summary_items'].message_type = _SUMMARYITEM
_FCOSUMMARY.fields_by_name['fco_metadata'].message_type = tecton__proto_dot_data_dot_fco__metadata__pb2._FCOMETADATA
_FCOSUMMARY.fields_by_name['summary_items'].message_type = _SUMMARYITEM
DESCRIPTOR.message_types_by_name['SummaryItem'] = _SUMMARYITEM
DESCRIPTOR.message_types_by_name['FcoSummary'] = _FCOSUMMARY
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

SummaryItem = _reflection.GeneratedProtocolMessageType('SummaryItem', (_message.Message,), {
  'DESCRIPTOR' : _SUMMARYITEM,
  '__module__' : 'tecton_proto.data.summary_pb2'
  # @@protoc_insertion_point(class_scope:tecton_proto.data.SummaryItem)
  })
_sym_db.RegisterMessage(SummaryItem)

FcoSummary = _reflection.GeneratedProtocolMessageType('FcoSummary', (_message.Message,), {
  'DESCRIPTOR' : _FCOSUMMARY,
  '__module__' : 'tecton_proto.data.summary_pb2'
  # @@protoc_insertion_point(class_scope:tecton_proto.data.FcoSummary)
  })
_sym_db.RegisterMessage(FcoSummary)


DESCRIPTOR._options = None
# @@protoc_insertion_point(module_scope)
