# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: tecton_proto/data/user_deployment_settings.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from tecton_proto.common import secret_pb2 as tecton__proto_dot_common_dot_secret__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='tecton_proto/data/user_deployment_settings.proto',
  package='tecton_proto.data',
  syntax='proto2',
  serialized_options=b'\n\017com.tecton.dataP\001',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n0tecton_proto/data/user_deployment_settings.proto\x12\x11tecton_proto.data\x1a tecton_proto/common/secret.proto\"\xa3\x02\n\x16UserDeploymentSettings\x12G\n user_deployment_settings_version\x18\x01 \x01(\x05R\x1duserDeploymentSettingsVersion\x12R\n\x11\x64\x61tabricks_config\x18\x02 \x01(\x0b\x32#.tecton_proto.data.DatabricksConfigH\x00R\x10\x64\x61tabricksConfig\x12T\n\x13user_spark_settings\x18\x03 \x01(\x0b\x32$.tecton_proto.data.UserSparkSettingsR\x11userSparkSettingsB\x16\n\x14\x64\x61ta_platform_config\"q\n\x10\x44\x61tabricksConfig\x12#\n\rworkspace_url\x18\x01 \x01(\tR\x0cworkspaceUrl\x12\x38\n\tapi_token\x18\x02 \x01(\x0b\x32\x1b.tecton_proto.common.SecretR\x08\x61piToken\"\xd7\x01\n\x11UserSparkSettings\x12\x30\n\x14instance_profile_arn\x18\x01 \x01(\tR\x12instanceProfileArn\x12R\n\nspark_conf\x18\x02 \x03(\x0b\x32\x33.tecton_proto.data.UserSparkSettings.SparkConfEntryR\tsparkConf\x1a<\n\x0eSparkConfEntry\x12\x10\n\x03key\x18\x01 \x01(\tR\x03key\x12\x14\n\x05value\x18\x02 \x01(\tR\x05value:\x02\x38\x01\x42\x13\n\x0f\x63om.tecton.dataP\x01'
  ,
  dependencies=[tecton__proto_dot_common_dot_secret__pb2.DESCRIPTOR,])




_USERDEPLOYMENTSETTINGS = _descriptor.Descriptor(
  name='UserDeploymentSettings',
  full_name='tecton_proto.data.UserDeploymentSettings',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='user_deployment_settings_version', full_name='tecton_proto.data.UserDeploymentSettings.user_deployment_settings_version', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='userDeploymentSettingsVersion', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='databricks_config', full_name='tecton_proto.data.UserDeploymentSettings.databricks_config', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='databricksConfig', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='user_spark_settings', full_name='tecton_proto.data.UserDeploymentSettings.user_spark_settings', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='userSparkSettings', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='data_platform_config', full_name='tecton_proto.data.UserDeploymentSettings.data_platform_config',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=106,
  serialized_end=397,
)


_DATABRICKSCONFIG = _descriptor.Descriptor(
  name='DatabricksConfig',
  full_name='tecton_proto.data.DatabricksConfig',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='workspace_url', full_name='tecton_proto.data.DatabricksConfig.workspace_url', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='workspaceUrl', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='api_token', full_name='tecton_proto.data.DatabricksConfig.api_token', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='apiToken', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=399,
  serialized_end=512,
)


_USERSPARKSETTINGS_SPARKCONFENTRY = _descriptor.Descriptor(
  name='SparkConfEntry',
  full_name='tecton_proto.data.UserSparkSettings.SparkConfEntry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='tecton_proto.data.UserSparkSettings.SparkConfEntry.key', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='key', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='value', full_name='tecton_proto.data.UserSparkSettings.SparkConfEntry.value', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='value', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'8\001',
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=670,
  serialized_end=730,
)

_USERSPARKSETTINGS = _descriptor.Descriptor(
  name='UserSparkSettings',
  full_name='tecton_proto.data.UserSparkSettings',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='instance_profile_arn', full_name='tecton_proto.data.UserSparkSettings.instance_profile_arn', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='instanceProfileArn', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='spark_conf', full_name='tecton_proto.data.UserSparkSettings.spark_conf', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='sparkConf', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_USERSPARKSETTINGS_SPARKCONFENTRY, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=515,
  serialized_end=730,
)

_USERDEPLOYMENTSETTINGS.fields_by_name['databricks_config'].message_type = _DATABRICKSCONFIG
_USERDEPLOYMENTSETTINGS.fields_by_name['user_spark_settings'].message_type = _USERSPARKSETTINGS
_USERDEPLOYMENTSETTINGS.oneofs_by_name['data_platform_config'].fields.append(
  _USERDEPLOYMENTSETTINGS.fields_by_name['databricks_config'])
_USERDEPLOYMENTSETTINGS.fields_by_name['databricks_config'].containing_oneof = _USERDEPLOYMENTSETTINGS.oneofs_by_name['data_platform_config']
_DATABRICKSCONFIG.fields_by_name['api_token'].message_type = tecton__proto_dot_common_dot_secret__pb2._SECRET
_USERSPARKSETTINGS_SPARKCONFENTRY.containing_type = _USERSPARKSETTINGS
_USERSPARKSETTINGS.fields_by_name['spark_conf'].message_type = _USERSPARKSETTINGS_SPARKCONFENTRY
DESCRIPTOR.message_types_by_name['UserDeploymentSettings'] = _USERDEPLOYMENTSETTINGS
DESCRIPTOR.message_types_by_name['DatabricksConfig'] = _DATABRICKSCONFIG
DESCRIPTOR.message_types_by_name['UserSparkSettings'] = _USERSPARKSETTINGS
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

UserDeploymentSettings = _reflection.GeneratedProtocolMessageType('UserDeploymentSettings', (_message.Message,), {
  'DESCRIPTOR' : _USERDEPLOYMENTSETTINGS,
  '__module__' : 'tecton_proto.data.user_deployment_settings_pb2'
  # @@protoc_insertion_point(class_scope:tecton_proto.data.UserDeploymentSettings)
  })
_sym_db.RegisterMessage(UserDeploymentSettings)

DatabricksConfig = _reflection.GeneratedProtocolMessageType('DatabricksConfig', (_message.Message,), {
  'DESCRIPTOR' : _DATABRICKSCONFIG,
  '__module__' : 'tecton_proto.data.user_deployment_settings_pb2'
  # @@protoc_insertion_point(class_scope:tecton_proto.data.DatabricksConfig)
  })
_sym_db.RegisterMessage(DatabricksConfig)

UserSparkSettings = _reflection.GeneratedProtocolMessageType('UserSparkSettings', (_message.Message,), {

  'SparkConfEntry' : _reflection.GeneratedProtocolMessageType('SparkConfEntry', (_message.Message,), {
    'DESCRIPTOR' : _USERSPARKSETTINGS_SPARKCONFENTRY,
    '__module__' : 'tecton_proto.data.user_deployment_settings_pb2'
    # @@protoc_insertion_point(class_scope:tecton_proto.data.UserSparkSettings.SparkConfEntry)
    })
  ,
  'DESCRIPTOR' : _USERSPARKSETTINGS,
  '__module__' : 'tecton_proto.data.user_deployment_settings_pb2'
  # @@protoc_insertion_point(class_scope:tecton_proto.data.UserSparkSettings)
  })
_sym_db.RegisterMessage(UserSparkSettings)
_sym_db.RegisterMessage(UserSparkSettings.SparkConfEntry)


DESCRIPTOR._options = None
_USERSPARKSETTINGS_SPARKCONFENTRY._options = None
# @@protoc_insertion_point(module_scope)
