# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: tecton_proto/args/basic_info.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from tecton_proto.args import diff_options_pb2 as tecton__proto_dot_args_dot_diff__options__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='tecton_proto/args/basic_info.proto',
  package='tecton_proto.args',
  syntax='proto2',
  serialized_options=b'\n\017com.tecton.argsP\001',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n\"tecton_proto/args/basic_info.proto\x12\x11tecton_proto.args\x1a$tecton_proto/args/diff_options.proto\"\x86\x02\n\tBasicInfo\x12\x12\n\x04name\x18\x01 \x01(\tR\x04name\x12\'\n\x0b\x64\x65scription\x18\x02 \x01(\tB\x05\x92M\x02\x08\x01R\x0b\x64\x65scription\x12\x1b\n\x05owner\x18\x06 \x01(\tB\x05\x92M\x02\x08\x01R\x05owner\x12\x1d\n\x06\x66\x61mily\x18\x04 \x01(\tB\x05\x92M\x02\x08\x01R\x06\x66\x61mily\x12\x41\n\x04tags\x18\x05 \x03(\x0b\x32&.tecton_proto.args.BasicInfo.TagsEntryB\x05\x92M\x02\x08\x01R\x04tags\x1a\x37\n\tTagsEntry\x12\x10\n\x03key\x18\x01 \x01(\tR\x03key\x12\x14\n\x05value\x18\x02 \x01(\tR\x05value:\x02\x38\x01J\x04\x08\x03\x10\x04\x42\x13\n\x0f\x63om.tecton.argsP\x01'
  ,
  dependencies=[tecton__proto_dot_args_dot_diff__options__pb2.DESCRIPTOR,])




_BASICINFO_TAGSENTRY = _descriptor.Descriptor(
  name='TagsEntry',
  full_name='tecton_proto.args.BasicInfo.TagsEntry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='tecton_proto.args.BasicInfo.TagsEntry.key', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='key', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='value', full_name='tecton_proto.args.BasicInfo.TagsEntry.value', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='value', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'8\001',
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=297,
  serialized_end=352,
)

_BASICINFO = _descriptor.Descriptor(
  name='BasicInfo',
  full_name='tecton_proto.args.BasicInfo',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='name', full_name='tecton_proto.args.BasicInfo.name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='name', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='description', full_name='tecton_proto.args.BasicInfo.description', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\222M\002\010\001', json_name='description', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='owner', full_name='tecton_proto.args.BasicInfo.owner', index=2,
      number=6, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\222M\002\010\001', json_name='owner', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='family', full_name='tecton_proto.args.BasicInfo.family', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\222M\002\010\001', json_name='family', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='tags', full_name='tecton_proto.args.BasicInfo.tags', index=4,
      number=5, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\222M\002\010\001', json_name='tags', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_BASICINFO_TAGSENTRY, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=96,
  serialized_end=358,
)

_BASICINFO_TAGSENTRY.containing_type = _BASICINFO
_BASICINFO.fields_by_name['tags'].message_type = _BASICINFO_TAGSENTRY
DESCRIPTOR.message_types_by_name['BasicInfo'] = _BASICINFO
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

BasicInfo = _reflection.GeneratedProtocolMessageType('BasicInfo', (_message.Message,), {

  'TagsEntry' : _reflection.GeneratedProtocolMessageType('TagsEntry', (_message.Message,), {
    'DESCRIPTOR' : _BASICINFO_TAGSENTRY,
    '__module__' : 'tecton_proto.args.basic_info_pb2'
    # @@protoc_insertion_point(class_scope:tecton_proto.args.BasicInfo.TagsEntry)
    })
  ,
  'DESCRIPTOR' : _BASICINFO,
  '__module__' : 'tecton_proto.args.basic_info_pb2'
  # @@protoc_insertion_point(class_scope:tecton_proto.args.BasicInfo)
  })
_sym_db.RegisterMessage(BasicInfo)
_sym_db.RegisterMessage(BasicInfo.TagsEntry)


DESCRIPTOR._options = None
_BASICINFO_TAGSENTRY._options = None
_BASICINFO.fields_by_name['description']._options = None
_BASICINFO.fields_by_name['owner']._options = None
_BASICINFO.fields_by_name['family']._options = None
_BASICINFO.fields_by_name['tags']._options = None
# @@protoc_insertion_point(module_scope)
