# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: tecton_proto/args/feature_service.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from tecton_proto.common import id_pb2 as tecton__proto_dot_common_dot_id__pb2
from tecton_proto.args import basic_info_pb2 as tecton__proto_dot_args_dot_basic__info__pb2
from tecton_proto.args import diff_options_pb2 as tecton__proto_dot_args_dot_diff__options__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='tecton_proto/args/feature_service.proto',
  package='tecton_proto.args',
  syntax='proto2',
  serialized_options=b'\n\017com.tecton.argsP\001',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n\'tecton_proto/args/feature_service.proto\x12\x11tecton_proto.args\x1a\x1ctecton_proto/common/id.proto\x1a\"tecton_proto/args/basic_info.proto\x1a$tecton_proto/args/diff_options.proto\"d\n\x11LoggingConfigArgs\x12\x1f\n\x0bsample_rate\x18\x01 \x01(\x02R\nsampleRate\x12.\n\x13log_effective_times\x18\x02 \x01(\x08R\x11logEffectiveTimes\"V\n\nColumnPair\x12!\n\x0cspine_column\x18\x01 \x01(\tR\x0bspineColumn\x12%\n\x0e\x66\x65\x61ture_column\x18\x02 \x01(\tR\rfeatureColumn\"\xec\x01\n\x1c\x46\x65\x61tureServiceFeaturePackage\x12\x45\n\x12\x66\x65\x61ture_package_id\x18\x01 \x01(\x0b\x32\x17.tecton_proto.common.IdR\x10\x66\x65\x61turePackageId\x12K\n\x12override_join_keys\x18\x02 \x03(\x0b\x32\x1d.tecton_proto.args.ColumnPairR\x10overrideJoinKeys\x12\x1c\n\tnamespace\x18\x03 \x01(\tR\tnamespace\x12\x1a\n\x08\x66\x65\x61tures\x18\x04 \x03(\tR\x08\x66\x65\x61tures\"\xed\x02\n\x12\x46\x65\x61tureServiceArgs\x12\x45\n\x12\x66\x65\x61ture_service_id\x18\x01 \x01(\x0b\x32\x17.tecton_proto.common.IdR\x10\x66\x65\x61tureServiceId\x12\x37\n\x04info\x18\x02 \x01(\x0b\x32\x1c.tecton_proto.args.BasicInfoB\x05\x92M\x02\x10\x01R\x04info\x12Z\n\x10\x66\x65\x61ture_packages\x18\x03 \x03(\x0b\x32/.tecton_proto.args.FeatureServiceFeaturePackageR\x0f\x66\x65\x61turePackages\x12;\n\x16online_serving_enabled\x18\x04 \x01(\x08\x42\x05\x92M\x02\x08\x01R\x14onlineServingEnabled\x12>\n\x07logging\x18\x05 \x01(\x0b\x32$.tecton_proto.args.LoggingConfigArgsR\x07loggingB\x13\n\x0f\x63om.tecton.argsP\x01'
  ,
  dependencies=[tecton__proto_dot_common_dot_id__pb2.DESCRIPTOR,tecton__proto_dot_args_dot_basic__info__pb2.DESCRIPTOR,tecton__proto_dot_args_dot_diff__options__pb2.DESCRIPTOR,])




_LOGGINGCONFIGARGS = _descriptor.Descriptor(
  name='LoggingConfigArgs',
  full_name='tecton_proto.args.LoggingConfigArgs',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='sample_rate', full_name='tecton_proto.args.LoggingConfigArgs.sample_rate', index=0,
      number=1, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='sampleRate', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='log_effective_times', full_name='tecton_proto.args.LoggingConfigArgs.log_effective_times', index=1,
      number=2, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='logEffectiveTimes', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=166,
  serialized_end=266,
)


_COLUMNPAIR = _descriptor.Descriptor(
  name='ColumnPair',
  full_name='tecton_proto.args.ColumnPair',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='spine_column', full_name='tecton_proto.args.ColumnPair.spine_column', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='spineColumn', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='feature_column', full_name='tecton_proto.args.ColumnPair.feature_column', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='featureColumn', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=268,
  serialized_end=354,
)


_FEATURESERVICEFEATUREPACKAGE = _descriptor.Descriptor(
  name='FeatureServiceFeaturePackage',
  full_name='tecton_proto.args.FeatureServiceFeaturePackage',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='feature_package_id', full_name='tecton_proto.args.FeatureServiceFeaturePackage.feature_package_id', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='featurePackageId', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='override_join_keys', full_name='tecton_proto.args.FeatureServiceFeaturePackage.override_join_keys', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='overrideJoinKeys', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='namespace', full_name='tecton_proto.args.FeatureServiceFeaturePackage.namespace', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='namespace', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='features', full_name='tecton_proto.args.FeatureServiceFeaturePackage.features', index=3,
      number=4, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='features', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=357,
  serialized_end=593,
)


_FEATURESERVICEARGS = _descriptor.Descriptor(
  name='FeatureServiceArgs',
  full_name='tecton_proto.args.FeatureServiceArgs',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='feature_service_id', full_name='tecton_proto.args.FeatureServiceArgs.feature_service_id', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='featureServiceId', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='info', full_name='tecton_proto.args.FeatureServiceArgs.info', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\222M\002\020\001', json_name='info', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='feature_packages', full_name='tecton_proto.args.FeatureServiceArgs.feature_packages', index=2,
      number=3, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='featurePackages', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='online_serving_enabled', full_name='tecton_proto.args.FeatureServiceArgs.online_serving_enabled', index=3,
      number=4, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\222M\002\010\001', json_name='onlineServingEnabled', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='logging', full_name='tecton_proto.args.FeatureServiceArgs.logging', index=4,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='logging', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=596,
  serialized_end=961,
)

_FEATURESERVICEFEATUREPACKAGE.fields_by_name['feature_package_id'].message_type = tecton__proto_dot_common_dot_id__pb2._ID
_FEATURESERVICEFEATUREPACKAGE.fields_by_name['override_join_keys'].message_type = _COLUMNPAIR
_FEATURESERVICEARGS.fields_by_name['feature_service_id'].message_type = tecton__proto_dot_common_dot_id__pb2._ID
_FEATURESERVICEARGS.fields_by_name['info'].message_type = tecton__proto_dot_args_dot_basic__info__pb2._BASICINFO
_FEATURESERVICEARGS.fields_by_name['feature_packages'].message_type = _FEATURESERVICEFEATUREPACKAGE
_FEATURESERVICEARGS.fields_by_name['logging'].message_type = _LOGGINGCONFIGARGS
DESCRIPTOR.message_types_by_name['LoggingConfigArgs'] = _LOGGINGCONFIGARGS
DESCRIPTOR.message_types_by_name['ColumnPair'] = _COLUMNPAIR
DESCRIPTOR.message_types_by_name['FeatureServiceFeaturePackage'] = _FEATURESERVICEFEATUREPACKAGE
DESCRIPTOR.message_types_by_name['FeatureServiceArgs'] = _FEATURESERVICEARGS
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

LoggingConfigArgs = _reflection.GeneratedProtocolMessageType('LoggingConfigArgs', (_message.Message,), {
  'DESCRIPTOR' : _LOGGINGCONFIGARGS,
  '__module__' : 'tecton_proto.args.feature_service_pb2'
  # @@protoc_insertion_point(class_scope:tecton_proto.args.LoggingConfigArgs)
  })
_sym_db.RegisterMessage(LoggingConfigArgs)

ColumnPair = _reflection.GeneratedProtocolMessageType('ColumnPair', (_message.Message,), {
  'DESCRIPTOR' : _COLUMNPAIR,
  '__module__' : 'tecton_proto.args.feature_service_pb2'
  # @@protoc_insertion_point(class_scope:tecton_proto.args.ColumnPair)
  })
_sym_db.RegisterMessage(ColumnPair)

FeatureServiceFeaturePackage = _reflection.GeneratedProtocolMessageType('FeatureServiceFeaturePackage', (_message.Message,), {
  'DESCRIPTOR' : _FEATURESERVICEFEATUREPACKAGE,
  '__module__' : 'tecton_proto.args.feature_service_pb2'
  # @@protoc_insertion_point(class_scope:tecton_proto.args.FeatureServiceFeaturePackage)
  })
_sym_db.RegisterMessage(FeatureServiceFeaturePackage)

FeatureServiceArgs = _reflection.GeneratedProtocolMessageType('FeatureServiceArgs', (_message.Message,), {
  'DESCRIPTOR' : _FEATURESERVICEARGS,
  '__module__' : 'tecton_proto.args.feature_service_pb2'
  # @@protoc_insertion_point(class_scope:tecton_proto.args.FeatureServiceArgs)
  })
_sym_db.RegisterMessage(FeatureServiceArgs)


DESCRIPTOR._options = None
_FEATURESERVICEARGS.fields_by_name['info']._options = None
_FEATURESERVICEARGS.fields_by_name['online_serving_enabled']._options = None
# @@protoc_insertion_point(module_scope)
