# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: tecton_proto/data/new_transformation.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from tecton_proto.args import user_defined_function_pb2 as tecton__proto_dot_args_dot_user__defined__function__pb2
from tecton_proto.data import fco_metadata_pb2 as tecton__proto_dot_data_dot_fco__metadata__pb2
from tecton_proto.args import new_transformation_pb2 as tecton__proto_dot_args_dot_new__transformation__pb2
from tecton_proto.common import id_pb2 as tecton__proto_dot_common_dot_id__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='tecton_proto/data/new_transformation.proto',
  package='tecton_proto.data',
  syntax='proto2',
  serialized_options=b'\n\017com.tecton.dataP\001',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n*tecton_proto/data/new_transformation.proto\x12\x11tecton_proto.data\x1a-tecton_proto/args/user_defined_function.proto\x1a$tecton_proto/data/fco_metadata.proto\x1a*tecton_proto/args/new_transformation.proto\x1a\x1ctecton_proto/common/id.proto\"\xc1\x02\n\x11NewTransformation\x12\x44\n\x11transformation_id\x18\x01 \x01(\x0b\x32\x17.tecton_proto.common.IdR\x10transformationId\x12\x41\n\x0c\x66\x63o_metadata\x18\x02 \x01(\x0b\x32\x1e.tecton_proto.data.FcoMetadataR\x0b\x66\x63oMetadata\x12V\n\x13transformation_mode\x18\x03 \x01(\x0e\x32%.tecton_proto.args.TransformationModeR\x12transformationMode\x12K\n\ruser_function\x18\x04 \x01(\x0b\x32&.tecton_proto.args.UserDefinedFunctionR\x0cuserFunctionB\x13\n\x0f\x63om.tecton.dataP\x01'
  ,
  dependencies=[tecton__proto_dot_args_dot_user__defined__function__pb2.DESCRIPTOR,tecton__proto_dot_data_dot_fco__metadata__pb2.DESCRIPTOR,tecton__proto_dot_args_dot_new__transformation__pb2.DESCRIPTOR,tecton__proto_dot_common_dot_id__pb2.DESCRIPTOR,])




_NEWTRANSFORMATION = _descriptor.Descriptor(
  name='NewTransformation',
  full_name='tecton_proto.data.NewTransformation',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='transformation_id', full_name='tecton_proto.data.NewTransformation.transformation_id', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='transformationId', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='fco_metadata', full_name='tecton_proto.data.NewTransformation.fco_metadata', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='fcoMetadata', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='transformation_mode', full_name='tecton_proto.data.NewTransformation.transformation_mode', index=2,
      number=3, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='transformationMode', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='user_function', full_name='tecton_proto.data.NewTransformation.user_function', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='userFunction', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=225,
  serialized_end=546,
)

_NEWTRANSFORMATION.fields_by_name['transformation_id'].message_type = tecton__proto_dot_common_dot_id__pb2._ID
_NEWTRANSFORMATION.fields_by_name['fco_metadata'].message_type = tecton__proto_dot_data_dot_fco__metadata__pb2._FCOMETADATA
_NEWTRANSFORMATION.fields_by_name['transformation_mode'].enum_type = tecton__proto_dot_args_dot_new__transformation__pb2._TRANSFORMATIONMODE
_NEWTRANSFORMATION.fields_by_name['user_function'].message_type = tecton__proto_dot_args_dot_user__defined__function__pb2._USERDEFINEDFUNCTION
DESCRIPTOR.message_types_by_name['NewTransformation'] = _NEWTRANSFORMATION
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

NewTransformation = _reflection.GeneratedProtocolMessageType('NewTransformation', (_message.Message,), {
  'DESCRIPTOR' : _NEWTRANSFORMATION,
  '__module__' : 'tecton_proto.data.new_transformation_pb2'
  # @@protoc_insertion_point(class_scope:tecton_proto.data.NewTransformation)
  })
_sym_db.RegisterMessage(NewTransformation)


DESCRIPTOR._options = None
# @@protoc_insertion_point(module_scope)
