# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: tecton_proto/data/serving_status.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2
from tecton_proto.common import id_pb2 as tecton__proto_dot_common_dot_id__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='tecton_proto/data/serving_status.proto',
  package='tecton_proto.data',
  syntax='proto2',
  serialized_options=b'\n\017com.tecton.dataP\001',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n&tecton_proto/data/serving_status.proto\x12\x11tecton_proto.data\x1a\x1fgoogle/protobuf/timestamp.proto\x1a\x1ctecton_proto/common/id.proto\"m\n\rServingStatus\x12\x44\n\rserving_state\x18\x01 \x01(\x0e\x32\x1f.tecton_proto.data.ServingStateR\x0cservingState\x12\x16\n\x06\x65rrors\x18\x02 \x03(\tR\x06\x65rrors\"\xcd\x01\n\x0bStatusRange\x12\x43\n\x0f\x62\x65gin_inclusive\x18\x01 \x01(\x0b\x32\x1a.google.protobuf.TimestampR\x0e\x62\x65ginInclusive\x12?\n\rend_exclusive\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.TimestampR\x0c\x65ndExclusive\x12\x38\n\x06status\x18\x03 \x01(\x0b\x32 .tecton_proto.data.ServingStatusR\x06status\"\xc5\x01\n FeatureViewMaterializationRanges\x12?\n\x0f\x66\x65\x61ture_view_id\x18\x01 \x01(\x0b\x32\x17.tecton_proto.common.IdR\rfeatureViewId\x12`\n\x1c\x62\x61tch_materialization_ranges\x18\x02 \x03(\x0b\x32\x1e.tecton_proto.data.StatusRangeR\x1a\x62\x61tchMaterializationRanges\"\xc8\x04\n\x14ServingStatusSummary\x12X\n\x18offline_readiness_ranges\x18\x01 \x03(\x0b\x32\x1e.tecton_proto.data.StatusRangeR\x16offlineReadinessRanges\x12u\n\x1c\x62\x61tch_materialization_ranges\x18\x04 \x03(\x0b\x32\x33.tecton_proto.data.FeatureViewMaterializationRangesR\x1a\x62\x61tchMaterializationRanges\x12L\n\x14streaming_start_time\x18\x05 \x01(\x0b\x32\x1a.google.protobuf.TimestampR\x12streamingStartTime\x12Z\n\x18streaming_serving_status\x18\x02 \x01(\x0b\x32 .tecton_proto.data.ServingStatusR\x16streamingServingStatus\x12O\n\x16most_recent_ready_time\x18\x03 \x01(\x0b\x32\x1a.google.protobuf.TimestampR\x13mostRecentReadyTime\x12\x64\n!most_recent_batch_processing_time\x18\x06 \x01(\x0b\x32\x1a.google.protobuf.TimestampR\x1dmostRecentBatchProcessingTime\"\xc7\x01\n\x1f\x46\x65\x61tureViewServingStatusSummary\x12?\n\x0f\x66\x65\x61ture_view_id\x18\x03 \x01(\x0b\x32\x17.tecton_proto.common.IdR\rfeatureViewId\x12]\n\x16serving_status_summary\x18\x02 \x01(\x0b\x32\'.tecton_proto.data.ServingStatusSummaryR\x14servingStatusSummaryJ\x04\x08\x01\x10\x02\"\xa6\x02\n FullFeatureServiceServingSummary\x12{\n&feature_service_serving_status_summary\x18\x02 \x01(\x0b\x32\'.tecton_proto.data.ServingStatusSummaryR\"featureServiceServingStatusSummary\x12\x84\x01\n%feature_view_serving_status_summaries\x18\x03 \x03(\x0b\x32\x32.tecton_proto.data.FeatureViewServingStatusSummaryR!featureViewServingStatusSummaries*\xcd\x01\n\x0cServingState\x12\x19\n\x15SERVING_STATE_UNKNOWN\x10\x00\x12\x1a\n\x16SERVING_STATE_DISABLED\x10\x01\x12!\n\x1dSERVING_STATE_NOT_ENOUGH_DATA\x10\x02\x12\x19\n\x15SERVING_STATE_PENDING\x10\x03\x12\x14\n\x10SERVING_STATE_OK\x10\x04\x12\x17\n\x13SERVING_STATE_ERROR\x10\x05\x12\x19\n\x15SERVING_STATE_RUNNING\x10\x06\x42\x13\n\x0f\x63om.tecton.dataP\x01'
  ,
  dependencies=[google_dot_protobuf_dot_timestamp__pb2.DESCRIPTOR,tecton__proto_dot_common_dot_id__pb2.DESCRIPTOR,])

_SERVINGSTATE = _descriptor.EnumDescriptor(
  name='ServingState',
  full_name='tecton_proto.data.ServingState',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='SERVING_STATE_UNKNOWN', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='SERVING_STATE_DISABLED', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='SERVING_STATE_NOT_ENOUGH_DATA', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='SERVING_STATE_PENDING', index=3, number=3,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='SERVING_STATE_OK', index=4, number=4,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='SERVING_STATE_ERROR', index=5, number=5,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='SERVING_STATE_RUNNING', index=6, number=6,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=1730,
  serialized_end=1935,
)
_sym_db.RegisterEnumDescriptor(_SERVINGSTATE)

ServingState = enum_type_wrapper.EnumTypeWrapper(_SERVINGSTATE)
SERVING_STATE_UNKNOWN = 0
SERVING_STATE_DISABLED = 1
SERVING_STATE_NOT_ENOUGH_DATA = 2
SERVING_STATE_PENDING = 3
SERVING_STATE_OK = 4
SERVING_STATE_ERROR = 5
SERVING_STATE_RUNNING = 6



_SERVINGSTATUS = _descriptor.Descriptor(
  name='ServingStatus',
  full_name='tecton_proto.data.ServingStatus',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='serving_state', full_name='tecton_proto.data.ServingStatus.serving_state', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='servingState', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='errors', full_name='tecton_proto.data.ServingStatus.errors', index=1,
      number=2, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='errors', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=124,
  serialized_end=233,
)


_STATUSRANGE = _descriptor.Descriptor(
  name='StatusRange',
  full_name='tecton_proto.data.StatusRange',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='begin_inclusive', full_name='tecton_proto.data.StatusRange.begin_inclusive', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='beginInclusive', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='end_exclusive', full_name='tecton_proto.data.StatusRange.end_exclusive', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='endExclusive', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='status', full_name='tecton_proto.data.StatusRange.status', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='status', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=236,
  serialized_end=441,
)


_FEATUREVIEWMATERIALIZATIONRANGES = _descriptor.Descriptor(
  name='FeatureViewMaterializationRanges',
  full_name='tecton_proto.data.FeatureViewMaterializationRanges',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='feature_view_id', full_name='tecton_proto.data.FeatureViewMaterializationRanges.feature_view_id', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='featureViewId', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='batch_materialization_ranges', full_name='tecton_proto.data.FeatureViewMaterializationRanges.batch_materialization_ranges', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='batchMaterializationRanges', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=444,
  serialized_end=641,
)


_SERVINGSTATUSSUMMARY = _descriptor.Descriptor(
  name='ServingStatusSummary',
  full_name='tecton_proto.data.ServingStatusSummary',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='offline_readiness_ranges', full_name='tecton_proto.data.ServingStatusSummary.offline_readiness_ranges', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='offlineReadinessRanges', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='batch_materialization_ranges', full_name='tecton_proto.data.ServingStatusSummary.batch_materialization_ranges', index=1,
      number=4, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='batchMaterializationRanges', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='streaming_start_time', full_name='tecton_proto.data.ServingStatusSummary.streaming_start_time', index=2,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='streamingStartTime', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='streaming_serving_status', full_name='tecton_proto.data.ServingStatusSummary.streaming_serving_status', index=3,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='streamingServingStatus', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='most_recent_ready_time', full_name='tecton_proto.data.ServingStatusSummary.most_recent_ready_time', index=4,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='mostRecentReadyTime', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='most_recent_batch_processing_time', full_name='tecton_proto.data.ServingStatusSummary.most_recent_batch_processing_time', index=5,
      number=6, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='mostRecentBatchProcessingTime', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=644,
  serialized_end=1228,
)


_FEATUREVIEWSERVINGSTATUSSUMMARY = _descriptor.Descriptor(
  name='FeatureViewServingStatusSummary',
  full_name='tecton_proto.data.FeatureViewServingStatusSummary',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='feature_view_id', full_name='tecton_proto.data.FeatureViewServingStatusSummary.feature_view_id', index=0,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='featureViewId', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='serving_status_summary', full_name='tecton_proto.data.FeatureViewServingStatusSummary.serving_status_summary', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='servingStatusSummary', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1231,
  serialized_end=1430,
)


_FULLFEATURESERVICESERVINGSUMMARY = _descriptor.Descriptor(
  name='FullFeatureServiceServingSummary',
  full_name='tecton_proto.data.FullFeatureServiceServingSummary',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='feature_service_serving_status_summary', full_name='tecton_proto.data.FullFeatureServiceServingSummary.feature_service_serving_status_summary', index=0,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='featureServiceServingStatusSummary', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='feature_view_serving_status_summaries', full_name='tecton_proto.data.FullFeatureServiceServingSummary.feature_view_serving_status_summaries', index=1,
      number=3, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='featureViewServingStatusSummaries', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1433,
  serialized_end=1727,
)

_SERVINGSTATUS.fields_by_name['serving_state'].enum_type = _SERVINGSTATE
_STATUSRANGE.fields_by_name['begin_inclusive'].message_type = google_dot_protobuf_dot_timestamp__pb2._TIMESTAMP
_STATUSRANGE.fields_by_name['end_exclusive'].message_type = google_dot_protobuf_dot_timestamp__pb2._TIMESTAMP
_STATUSRANGE.fields_by_name['status'].message_type = _SERVINGSTATUS
_FEATUREVIEWMATERIALIZATIONRANGES.fields_by_name['feature_view_id'].message_type = tecton__proto_dot_common_dot_id__pb2._ID
_FEATUREVIEWMATERIALIZATIONRANGES.fields_by_name['batch_materialization_ranges'].message_type = _STATUSRANGE
_SERVINGSTATUSSUMMARY.fields_by_name['offline_readiness_ranges'].message_type = _STATUSRANGE
_SERVINGSTATUSSUMMARY.fields_by_name['batch_materialization_ranges'].message_type = _FEATUREVIEWMATERIALIZATIONRANGES
_SERVINGSTATUSSUMMARY.fields_by_name['streaming_start_time'].message_type = google_dot_protobuf_dot_timestamp__pb2._TIMESTAMP
_SERVINGSTATUSSUMMARY.fields_by_name['streaming_serving_status'].message_type = _SERVINGSTATUS
_SERVINGSTATUSSUMMARY.fields_by_name['most_recent_ready_time'].message_type = google_dot_protobuf_dot_timestamp__pb2._TIMESTAMP
_SERVINGSTATUSSUMMARY.fields_by_name['most_recent_batch_processing_time'].message_type = google_dot_protobuf_dot_timestamp__pb2._TIMESTAMP
_FEATUREVIEWSERVINGSTATUSSUMMARY.fields_by_name['feature_view_id'].message_type = tecton__proto_dot_common_dot_id__pb2._ID
_FEATUREVIEWSERVINGSTATUSSUMMARY.fields_by_name['serving_status_summary'].message_type = _SERVINGSTATUSSUMMARY
_FULLFEATURESERVICESERVINGSUMMARY.fields_by_name['feature_service_serving_status_summary'].message_type = _SERVINGSTATUSSUMMARY
_FULLFEATURESERVICESERVINGSUMMARY.fields_by_name['feature_view_serving_status_summaries'].message_type = _FEATUREVIEWSERVINGSTATUSSUMMARY
DESCRIPTOR.message_types_by_name['ServingStatus'] = _SERVINGSTATUS
DESCRIPTOR.message_types_by_name['StatusRange'] = _STATUSRANGE
DESCRIPTOR.message_types_by_name['FeatureViewMaterializationRanges'] = _FEATUREVIEWMATERIALIZATIONRANGES
DESCRIPTOR.message_types_by_name['ServingStatusSummary'] = _SERVINGSTATUSSUMMARY
DESCRIPTOR.message_types_by_name['FeatureViewServingStatusSummary'] = _FEATUREVIEWSERVINGSTATUSSUMMARY
DESCRIPTOR.message_types_by_name['FullFeatureServiceServingSummary'] = _FULLFEATURESERVICESERVINGSUMMARY
DESCRIPTOR.enum_types_by_name['ServingState'] = _SERVINGSTATE
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

ServingStatus = _reflection.GeneratedProtocolMessageType('ServingStatus', (_message.Message,), {
  'DESCRIPTOR' : _SERVINGSTATUS,
  '__module__' : 'tecton_proto.data.serving_status_pb2'
  # @@protoc_insertion_point(class_scope:tecton_proto.data.ServingStatus)
  })
_sym_db.RegisterMessage(ServingStatus)

StatusRange = _reflection.GeneratedProtocolMessageType('StatusRange', (_message.Message,), {
  'DESCRIPTOR' : _STATUSRANGE,
  '__module__' : 'tecton_proto.data.serving_status_pb2'
  # @@protoc_insertion_point(class_scope:tecton_proto.data.StatusRange)
  })
_sym_db.RegisterMessage(StatusRange)

FeatureViewMaterializationRanges = _reflection.GeneratedProtocolMessageType('FeatureViewMaterializationRanges', (_message.Message,), {
  'DESCRIPTOR' : _FEATUREVIEWMATERIALIZATIONRANGES,
  '__module__' : 'tecton_proto.data.serving_status_pb2'
  # @@protoc_insertion_point(class_scope:tecton_proto.data.FeatureViewMaterializationRanges)
  })
_sym_db.RegisterMessage(FeatureViewMaterializationRanges)

ServingStatusSummary = _reflection.GeneratedProtocolMessageType('ServingStatusSummary', (_message.Message,), {
  'DESCRIPTOR' : _SERVINGSTATUSSUMMARY,
  '__module__' : 'tecton_proto.data.serving_status_pb2'
  # @@protoc_insertion_point(class_scope:tecton_proto.data.ServingStatusSummary)
  })
_sym_db.RegisterMessage(ServingStatusSummary)

FeatureViewServingStatusSummary = _reflection.GeneratedProtocolMessageType('FeatureViewServingStatusSummary', (_message.Message,), {
  'DESCRIPTOR' : _FEATUREVIEWSERVINGSTATUSSUMMARY,
  '__module__' : 'tecton_proto.data.serving_status_pb2'
  # @@protoc_insertion_point(class_scope:tecton_proto.data.FeatureViewServingStatusSummary)
  })
_sym_db.RegisterMessage(FeatureViewServingStatusSummary)

FullFeatureServiceServingSummary = _reflection.GeneratedProtocolMessageType('FullFeatureServiceServingSummary', (_message.Message,), {
  'DESCRIPTOR' : _FULLFEATURESERVICESERVINGSUMMARY,
  '__module__' : 'tecton_proto.data.serving_status_pb2'
  # @@protoc_insertion_point(class_scope:tecton_proto.data.FullFeatureServiceServingSummary)
  })
_sym_db.RegisterMessage(FullFeatureServiceServingSummary)


DESCRIPTOR._options = None
# @@protoc_insertion_point(module_scope)
