BUILD_STATUS = {'BUILD_ID': 'uncommitted-buildkite-agent-1646850889', 'BUILD_TIMESTAMP': '1646850888', 'GIT_COMMIT': '759be48e5ee0e01be2d1b2368e03cb04c1694d25', 'BUILD_EMBED_LABEL': '', 'BUILD_HOST': 'buildkite-agent-default-13', 'BUILD_USER': 'buildkite-agent'}
