# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: tecton_proto/common/spark_schema.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor.FileDescriptor(
  name='tecton_proto/common/spark_schema.proto',
  package='tecton_proto.common',
  syntax='proto2',
  serialized_options=b'\n\021com.tecton.commonP\001',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n&tecton_proto/common/spark_schema.proto\x12\x13tecton_proto.common\"K\n\nSparkField\x12\x12\n\x04name\x18\x01 \x01(\tR\x04name\x12)\n\x10structfield_json\x18\x02 \x01(\tR\x0fstructfieldJson\"F\n\x0bSparkSchema\x12\x37\n\x06\x66ields\x18\x01 \x03(\x0b\x32\x1f.tecton_proto.common.SparkFieldR\x06\x66ieldsB\x15\n\x11\x63om.tecton.commonP\x01'
)




_SPARKFIELD = _descriptor.Descriptor(
  name='SparkField',
  full_name='tecton_proto.common.SparkField',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='name', full_name='tecton_proto.common.SparkField.name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='name', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='structfield_json', full_name='tecton_proto.common.SparkField.structfield_json', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='structfieldJson', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=63,
  serialized_end=138,
)


_SPARKSCHEMA = _descriptor.Descriptor(
  name='SparkSchema',
  full_name='tecton_proto.common.SparkSchema',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='fields', full_name='tecton_proto.common.SparkSchema.fields', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='fields', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=140,
  serialized_end=210,
)

_SPARKSCHEMA.fields_by_name['fields'].message_type = _SPARKFIELD
DESCRIPTOR.message_types_by_name['SparkField'] = _SPARKFIELD
DESCRIPTOR.message_types_by_name['SparkSchema'] = _SPARKSCHEMA
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

SparkField = _reflection.GeneratedProtocolMessageType('SparkField', (_message.Message,), {
  'DESCRIPTOR' : _SPARKFIELD,
  '__module__' : 'tecton_proto.common.spark_schema_pb2'
  # @@protoc_insertion_point(class_scope:tecton_proto.common.SparkField)
  })
_sym_db.RegisterMessage(SparkField)

SparkSchema = _reflection.GeneratedProtocolMessageType('SparkSchema', (_message.Message,), {
  'DESCRIPTOR' : _SPARKSCHEMA,
  '__module__' : 'tecton_proto.common.spark_schema_pb2'
  # @@protoc_insertion_point(class_scope:tecton_proto.common.SparkSchema)
  })
_sym_db.RegisterMessage(SparkSchema)


DESCRIPTOR._options = None
# @@protoc_insertion_point(module_scope)
