# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: tecton_proto/args/repo_metadata.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from tecton_proto.common import id_pb2 as tecton__proto_dot_common_dot_id__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='tecton_proto/args/repo_metadata.proto',
  package='tecton_proto.args',
  syntax='proto2',
  serialized_options=b'\n\017com.tecton.argsP\001',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n%tecton_proto/args/repo_metadata.proto\x12\x11tecton_proto.args\x1a\x1ctecton_proto/common/id.proto\"\xa6\x01\n\nSourceInfo\x12.\n\x06\x66\x63o_id\x18\x01 \x01(\x0b\x32\x17.tecton_proto.common.IdR\x05\x66\x63oId\x12\x14\n\x05scope\x18\x03 \x01(\tR\x05scope\x12#\n\rsource_lineno\x18\x04 \x01(\tR\x0csourceLineno\x12\'\n\x0fsource_filename\x18\x05 \x01(\tR\x0esourceFilenameJ\x04\x08\x02\x10\x03\"W\n\x15\x46\x65\x61tureRepoSourceInfo\x12>\n\x0bsource_info\x18\x01 \x03(\x0b\x32\x1d.tecton_proto.args.SourceInfoR\nsourceInfoB\x13\n\x0f\x63om.tecton.argsP\x01'
  ,
  dependencies=[tecton__proto_dot_common_dot_id__pb2.DESCRIPTOR,])




_SOURCEINFO = _descriptor.Descriptor(
  name='SourceInfo',
  full_name='tecton_proto.args.SourceInfo',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='fco_id', full_name='tecton_proto.args.SourceInfo.fco_id', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='fcoId', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='scope', full_name='tecton_proto.args.SourceInfo.scope', index=1,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='scope', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='source_lineno', full_name='tecton_proto.args.SourceInfo.source_lineno', index=2,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='sourceLineno', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='source_filename', full_name='tecton_proto.args.SourceInfo.source_filename', index=3,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='sourceFilename', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=91,
  serialized_end=257,
)


_FEATUREREPOSOURCEINFO = _descriptor.Descriptor(
  name='FeatureRepoSourceInfo',
  full_name='tecton_proto.args.FeatureRepoSourceInfo',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='source_info', full_name='tecton_proto.args.FeatureRepoSourceInfo.source_info', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='sourceInfo', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=259,
  serialized_end=346,
)

_SOURCEINFO.fields_by_name['fco_id'].message_type = tecton__proto_dot_common_dot_id__pb2._ID
_FEATUREREPOSOURCEINFO.fields_by_name['source_info'].message_type = _SOURCEINFO
DESCRIPTOR.message_types_by_name['SourceInfo'] = _SOURCEINFO
DESCRIPTOR.message_types_by_name['FeatureRepoSourceInfo'] = _FEATUREREPOSOURCEINFO
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

SourceInfo = _reflection.GeneratedProtocolMessageType('SourceInfo', (_message.Message,), {
  'DESCRIPTOR' : _SOURCEINFO,
  '__module__' : 'tecton_proto.args.repo_metadata_pb2'
  # @@protoc_insertion_point(class_scope:tecton_proto.args.SourceInfo)
  })
_sym_db.RegisterMessage(SourceInfo)

FeatureRepoSourceInfo = _reflection.GeneratedProtocolMessageType('FeatureRepoSourceInfo', (_message.Message,), {
  'DESCRIPTOR' : _FEATUREREPOSOURCEINFO,
  '__module__' : 'tecton_proto.args.repo_metadata_pb2'
  # @@protoc_insertion_point(class_scope:tecton_proto.args.FeatureRepoSourceInfo)
  })
_sym_db.RegisterMessage(FeatureRepoSourceInfo)


DESCRIPTOR._options = None
# @@protoc_insertion_point(module_scope)
