# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: tecton_proto/args/data_source.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import duration_pb2 as google_dot_protobuf_dot_duration__pb2
from tecton_proto.args import data_source_config_pb2 as tecton__proto_dot_args_dot_data__source__config__pb2
from tecton_proto.args import diff_options_pb2 as tecton__proto_dot_args_dot_diff__options__pb2
from tecton_proto.args import user_defined_function_pb2 as tecton__proto_dot_args_dot_user__defined__function__pb2
from tecton_proto.common import spark_schema_pb2 as tecton__proto_dot_common_dot_spark__schema__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='tecton_proto/args/data_source.proto',
  package='tecton_proto.args',
  syntax='proto2',
  serialized_options=b'\n\017com.tecton.argsP\001',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n#tecton_proto/args/data_source.proto\x12\x11tecton_proto.args\x1a\x1egoogle/protobuf/duration.proto\x1a*tecton_proto/args/data_source_config.proto\x1a$tecton_proto/args/diff_options.proto\x1a-tecton_proto/args/user_defined_function.proto\x1a&tecton_proto/common/spark_schema.proto\"{\n\x1b\x44\x61tetimePartitionColumnArgs\x12\x1f\n\x0b\x63olumn_name\x18\x01 \x01(\tR\ncolumnName\x12\x1a\n\x08\x64\x61tepart\x18\x02 \x01(\tR\x08\x64\x61tepart\x12\x1f\n\x0bzero_padded\x18\x03 \x01(\x08R\nzeroPadded\"\xd0\x03\n\x12HiveDataSourceArgs\x12\x14\n\x05table\x18\x01 \x01(\tR\x05table\x12\x1a\n\x08\x64\x61tabase\x18\x02 \x01(\tR\x08\x64\x61tabase\x12\x32\n\x15\x64\x61te_partition_column\x18\x03 \x01(\tR\x13\x64\x61tePartitionColumn\x12\x32\n\x15timestamp_column_name\x18\x04 \x01(\tR\x13timestampColumnName\x12)\n\x10timestamp_format\x18\x05 \x01(\tR\x0ftimestampFormat\x12\'\n\x0fskip_validation\x18\x06 \x01(\x08R\x0eskipValidation\x12l\n\x1a\x64\x61tetime_partition_columns\x18\x07 \x03(\x0b\x32..tecton_proto.args.DatetimePartitionColumnArgsR\x18\x64\x61tetimePartitionColumns\x12X\n\x14raw_batch_translator\x18\t \x01(\x0b\x32&.tecton_proto.args.UserDefinedFunctionR\x12rawBatchTranslatorJ\x04\x08\x08\x10\t\"\xac\x03\n\x12\x46ileDataSourceArgs\x12\x10\n\x03uri\x18\x01 \x01(\tR\x03uri\x12\x1f\n\x0b\x66ile_format\x18\x02 \x01(\tR\nfileFormat\x12\x33\n\x16\x63onvert_to_glue_format\x18\x03 \x01(\x08R\x13\x63onvertToGlueFormat\x12X\n\x14raw_batch_translator\x18\x04 \x01(\x0b\x32&.tecton_proto.args.UserDefinedFunctionR\x12rawBatchTranslator\x12$\n\nschema_uri\x18\x05 \x01(\tB\x05\x92M\x02\x08\x01R\tschemaUri\x12\x32\n\x15timestamp_column_name\x18\x06 \x01(\tR\x13timestampColumnName\x12)\n\x10timestamp_format\x18\x07 \x01(\tR\x0ftimestampFormat\x12I\n\x0fschema_override\x18\t \x01(\x0b\x32 .tecton_proto.common.SparkSchemaR\x0eschemaOverrideJ\x04\x08\x08\x10\t\"0\n\x06Option\x12\x10\n\x03key\x18\x01 \x01(\tR\x03key\x12\x14\n\x05value\x18\x02 \x01(\tR\x05value\"\x98\x04\n\x15KinesisDataSourceArgs\x12\x1f\n\x0bstream_name\x18\x01 \x01(\tR\nstreamName\x12\x16\n\x06region\x18\x02 \x01(\tR\x06region\x12Z\n\x15raw_stream_translator\x18\x03 \x01(\x0b\x32&.tecton_proto.args.UserDefinedFunctionR\x13rawStreamTranslator\x12#\n\rtimestamp_key\x18\x04 \x01(\tR\x0ctimestampKey\x12o\n\x1f\x64\x65\x66\x61ult_initial_stream_position\x18\x05 \x01(\x0e\x32(.tecton_proto.args.InitialStreamPositionR\x1c\x64\x65\x66\x61ultInitialStreamPosition\x12\x64\n!default_watermark_delay_threshold\x18\x06 \x01(\x0b\x32\x19.google.protobuf.DurationR\x1e\x64\x65\x66\x61ultWatermarkDelayThreshold\x12\x33\n\x15\x64\x65\x64uplication_columns\x18\x07 \x03(\tR\x14\x64\x65\x64uplicationColumns\x12\x33\n\x07options\x18\x08 \x03(\x0b\x32\x19.tecton_proto.args.OptionR\x07optionsJ\x04\x08\t\x10\n\"\xcd\x05\n\x13KafkaDataSourceArgs\x12\x36\n\x17kafka_bootstrap_servers\x18\x01 \x01(\tR\x15kafkaBootstrapServers\x12\x16\n\x06topics\x18\x02 \x01(\tR\x06topics\x12Z\n\x15raw_stream_translator\x18\x03 \x01(\x0b\x32&.tecton_proto.args.UserDefinedFunctionR\x13rawStreamTranslator\x12#\n\rtimestamp_key\x18\x04 \x01(\tR\x0ctimestampKey\x12\x64\n!default_watermark_delay_threshold\x18\x05 \x01(\x0b\x32\x19.google.protobuf.DurationR\x1e\x64\x65\x66\x61ultWatermarkDelayThreshold\x12\x33\n\x07options\x18\x06 \x03(\x0b\x32\x19.tecton_proto.args.OptionR\x07options\x12\x39\n\x15ssl_keystore_location\x18\x07 \x01(\tB\x05\x92M\x02\x08\x01R\x13sslKeystoreLocation\x12K\n\x1fssl_keystore_password_secret_id\x18\x08 \x01(\tB\x05\x92M\x02\x08\x01R\x1bsslKeystorePasswordSecretId\x12=\n\x17ssl_truststore_location\x18\t \x01(\tB\x05\x92M\x02\x08\x01R\x15sslTruststoreLocation\x12O\n!ssl_truststore_password_secret_id\x18\n \x01(\tB\x05\x92M\x02\x08\x01R\x1dsslTruststorePasswordSecretId\x12\x32\n\x11security_protocol\x18\x0b \x01(\tB\x05\x92M\x02\x08\x01R\x10securityProtocol\"\xf3\x01\n\x16RedshiftDataSourceArgs\x12\x1a\n\x08\x65ndpoint\x18\x01 \x01(\tR\x08\x65ndpoint\x12\x16\n\x05table\x18\x02 \x01(\tH\x00R\x05table\x12\x16\n\x05query\x18\x05 \x01(\tH\x00R\x05query\x12X\n\x14raw_batch_translator\x18\x03 \x01(\x0b\x32&.tecton_proto.args.UserDefinedFunctionR\x12rawBatchTranslator\x12#\n\rtimestamp_key\x18\x06 \x01(\tR\x0ctimestampKeyB\x08\n\x06sourceJ\x04\x08\x04\x10\x05\"\xd1\x02\n\x17SnowflakeDataSourceArgs\x12\x10\n\x03url\x18\x01 \x01(\tR\x03url\x12\x12\n\x04role\x18\x02 \x01(\tR\x04role\x12\x1a\n\x08\x64\x61tabase\x18\x03 \x01(\tR\x08\x64\x61tabase\x12\x16\n\x06schema\x18\x04 \x01(\tR\x06schema\x12#\n\twarehouse\x18\x05 \x01(\tB\x05\x92M\x02\x08\x01R\twarehouse\x12\x16\n\x05table\x18\x06 \x01(\tH\x00R\x05table\x12\x16\n\x05query\x18\x07 \x01(\tH\x00R\x05query\x12X\n\x14raw_batch_translator\x18\x08 \x01(\x0b\x32&.tecton_proto.args.UserDefinedFunctionR\x12rawBatchTranslator\x12#\n\rtimestamp_key\x18\t \x01(\tR\x0ctimestampKeyB\x08\n\x06sourceB\x13\n\x0f\x63om.tecton.argsP\x01'
  ,
  dependencies=[google_dot_protobuf_dot_duration__pb2.DESCRIPTOR,tecton__proto_dot_args_dot_data__source__config__pb2.DESCRIPTOR,tecton__proto_dot_args_dot_diff__options__pb2.DESCRIPTOR,tecton__proto_dot_args_dot_user__defined__function__pb2.DESCRIPTOR,tecton__proto_dot_common_dot_spark__schema__pb2.DESCRIPTOR,])




_DATETIMEPARTITIONCOLUMNARGS = _descriptor.Descriptor(
  name='DatetimePartitionColumnArgs',
  full_name='tecton_proto.args.DatetimePartitionColumnArgs',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='column_name', full_name='tecton_proto.args.DatetimePartitionColumnArgs.column_name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='columnName', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='datepart', full_name='tecton_proto.args.DatetimePartitionColumnArgs.datepart', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='datepart', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='zero_padded', full_name='tecton_proto.args.DatetimePartitionColumnArgs.zero_padded', index=2,
      number=3, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='zeroPadded', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=259,
  serialized_end=382,
)


_HIVEDATASOURCEARGS = _descriptor.Descriptor(
  name='HiveDataSourceArgs',
  full_name='tecton_proto.args.HiveDataSourceArgs',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='table', full_name='tecton_proto.args.HiveDataSourceArgs.table', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='table', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='database', full_name='tecton_proto.args.HiveDataSourceArgs.database', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='database', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='date_partition_column', full_name='tecton_proto.args.HiveDataSourceArgs.date_partition_column', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='datePartitionColumn', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='timestamp_column_name', full_name='tecton_proto.args.HiveDataSourceArgs.timestamp_column_name', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='timestampColumnName', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='timestamp_format', full_name='tecton_proto.args.HiveDataSourceArgs.timestamp_format', index=4,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='timestampFormat', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='skip_validation', full_name='tecton_proto.args.HiveDataSourceArgs.skip_validation', index=5,
      number=6, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='skipValidation', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='datetime_partition_columns', full_name='tecton_proto.args.HiveDataSourceArgs.datetime_partition_columns', index=6,
      number=7, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='datetimePartitionColumns', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='raw_batch_translator', full_name='tecton_proto.args.HiveDataSourceArgs.raw_batch_translator', index=7,
      number=9, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='rawBatchTranslator', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=385,
  serialized_end=849,
)


_FILEDATASOURCEARGS = _descriptor.Descriptor(
  name='FileDataSourceArgs',
  full_name='tecton_proto.args.FileDataSourceArgs',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='uri', full_name='tecton_proto.args.FileDataSourceArgs.uri', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='uri', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='file_format', full_name='tecton_proto.args.FileDataSourceArgs.file_format', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='fileFormat', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='convert_to_glue_format', full_name='tecton_proto.args.FileDataSourceArgs.convert_to_glue_format', index=2,
      number=3, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='convertToGlueFormat', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='raw_batch_translator', full_name='tecton_proto.args.FileDataSourceArgs.raw_batch_translator', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='rawBatchTranslator', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='schema_uri', full_name='tecton_proto.args.FileDataSourceArgs.schema_uri', index=4,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\222M\002\010\001', json_name='schemaUri', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='timestamp_column_name', full_name='tecton_proto.args.FileDataSourceArgs.timestamp_column_name', index=5,
      number=6, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='timestampColumnName', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='timestamp_format', full_name='tecton_proto.args.FileDataSourceArgs.timestamp_format', index=6,
      number=7, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='timestampFormat', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='schema_override', full_name='tecton_proto.args.FileDataSourceArgs.schema_override', index=7,
      number=9, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='schemaOverride', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=852,
  serialized_end=1280,
)


_OPTION = _descriptor.Descriptor(
  name='Option',
  full_name='tecton_proto.args.Option',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='tecton_proto.args.Option.key', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='key', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='value', full_name='tecton_proto.args.Option.value', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='value', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1282,
  serialized_end=1330,
)


_KINESISDATASOURCEARGS = _descriptor.Descriptor(
  name='KinesisDataSourceArgs',
  full_name='tecton_proto.args.KinesisDataSourceArgs',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='stream_name', full_name='tecton_proto.args.KinesisDataSourceArgs.stream_name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='streamName', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='region', full_name='tecton_proto.args.KinesisDataSourceArgs.region', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='region', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='raw_stream_translator', full_name='tecton_proto.args.KinesisDataSourceArgs.raw_stream_translator', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='rawStreamTranslator', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='timestamp_key', full_name='tecton_proto.args.KinesisDataSourceArgs.timestamp_key', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='timestampKey', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='default_initial_stream_position', full_name='tecton_proto.args.KinesisDataSourceArgs.default_initial_stream_position', index=4,
      number=5, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='defaultInitialStreamPosition', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='default_watermark_delay_threshold', full_name='tecton_proto.args.KinesisDataSourceArgs.default_watermark_delay_threshold', index=5,
      number=6, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='defaultWatermarkDelayThreshold', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='deduplication_columns', full_name='tecton_proto.args.KinesisDataSourceArgs.deduplication_columns', index=6,
      number=7, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='deduplicationColumns', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='options', full_name='tecton_proto.args.KinesisDataSourceArgs.options', index=7,
      number=8, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='options', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1333,
  serialized_end=1869,
)


_KAFKADATASOURCEARGS = _descriptor.Descriptor(
  name='KafkaDataSourceArgs',
  full_name='tecton_proto.args.KafkaDataSourceArgs',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='kafka_bootstrap_servers', full_name='tecton_proto.args.KafkaDataSourceArgs.kafka_bootstrap_servers', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='kafkaBootstrapServers', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='topics', full_name='tecton_proto.args.KafkaDataSourceArgs.topics', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='topics', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='raw_stream_translator', full_name='tecton_proto.args.KafkaDataSourceArgs.raw_stream_translator', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='rawStreamTranslator', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='timestamp_key', full_name='tecton_proto.args.KafkaDataSourceArgs.timestamp_key', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='timestampKey', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='default_watermark_delay_threshold', full_name='tecton_proto.args.KafkaDataSourceArgs.default_watermark_delay_threshold', index=4,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='defaultWatermarkDelayThreshold', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='options', full_name='tecton_proto.args.KafkaDataSourceArgs.options', index=5,
      number=6, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='options', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='ssl_keystore_location', full_name='tecton_proto.args.KafkaDataSourceArgs.ssl_keystore_location', index=6,
      number=7, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\222M\002\010\001', json_name='sslKeystoreLocation', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='ssl_keystore_password_secret_id', full_name='tecton_proto.args.KafkaDataSourceArgs.ssl_keystore_password_secret_id', index=7,
      number=8, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\222M\002\010\001', json_name='sslKeystorePasswordSecretId', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='ssl_truststore_location', full_name='tecton_proto.args.KafkaDataSourceArgs.ssl_truststore_location', index=8,
      number=9, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\222M\002\010\001', json_name='sslTruststoreLocation', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='ssl_truststore_password_secret_id', full_name='tecton_proto.args.KafkaDataSourceArgs.ssl_truststore_password_secret_id', index=9,
      number=10, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\222M\002\010\001', json_name='sslTruststorePasswordSecretId', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='security_protocol', full_name='tecton_proto.args.KafkaDataSourceArgs.security_protocol', index=10,
      number=11, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\222M\002\010\001', json_name='securityProtocol', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1872,
  serialized_end=2589,
)


_REDSHIFTDATASOURCEARGS = _descriptor.Descriptor(
  name='RedshiftDataSourceArgs',
  full_name='tecton_proto.args.RedshiftDataSourceArgs',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='endpoint', full_name='tecton_proto.args.RedshiftDataSourceArgs.endpoint', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='endpoint', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='table', full_name='tecton_proto.args.RedshiftDataSourceArgs.table', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='table', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='query', full_name='tecton_proto.args.RedshiftDataSourceArgs.query', index=2,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='query', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='raw_batch_translator', full_name='tecton_proto.args.RedshiftDataSourceArgs.raw_batch_translator', index=3,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='rawBatchTranslator', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='timestamp_key', full_name='tecton_proto.args.RedshiftDataSourceArgs.timestamp_key', index=4,
      number=6, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='timestampKey', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='source', full_name='tecton_proto.args.RedshiftDataSourceArgs.source',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=2592,
  serialized_end=2835,
)


_SNOWFLAKEDATASOURCEARGS = _descriptor.Descriptor(
  name='SnowflakeDataSourceArgs',
  full_name='tecton_proto.args.SnowflakeDataSourceArgs',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='url', full_name='tecton_proto.args.SnowflakeDataSourceArgs.url', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='url', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='role', full_name='tecton_proto.args.SnowflakeDataSourceArgs.role', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='role', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='database', full_name='tecton_proto.args.SnowflakeDataSourceArgs.database', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='database', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='schema', full_name='tecton_proto.args.SnowflakeDataSourceArgs.schema', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='schema', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='warehouse', full_name='tecton_proto.args.SnowflakeDataSourceArgs.warehouse', index=4,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\222M\002\010\001', json_name='warehouse', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='table', full_name='tecton_proto.args.SnowflakeDataSourceArgs.table', index=5,
      number=6, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='table', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='query', full_name='tecton_proto.args.SnowflakeDataSourceArgs.query', index=6,
      number=7, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='query', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='raw_batch_translator', full_name='tecton_proto.args.SnowflakeDataSourceArgs.raw_batch_translator', index=7,
      number=8, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='rawBatchTranslator', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='timestamp_key', full_name='tecton_proto.args.SnowflakeDataSourceArgs.timestamp_key', index=8,
      number=9, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='timestampKey', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='source', full_name='tecton_proto.args.SnowflakeDataSourceArgs.source',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=2838,
  serialized_end=3175,
)

_HIVEDATASOURCEARGS.fields_by_name['datetime_partition_columns'].message_type = _DATETIMEPARTITIONCOLUMNARGS
_HIVEDATASOURCEARGS.fields_by_name['raw_batch_translator'].message_type = tecton__proto_dot_args_dot_user__defined__function__pb2._USERDEFINEDFUNCTION
_FILEDATASOURCEARGS.fields_by_name['raw_batch_translator'].message_type = tecton__proto_dot_args_dot_user__defined__function__pb2._USERDEFINEDFUNCTION
_FILEDATASOURCEARGS.fields_by_name['schema_override'].message_type = tecton__proto_dot_common_dot_spark__schema__pb2._SPARKSCHEMA
_KINESISDATASOURCEARGS.fields_by_name['raw_stream_translator'].message_type = tecton__proto_dot_args_dot_user__defined__function__pb2._USERDEFINEDFUNCTION
_KINESISDATASOURCEARGS.fields_by_name['default_initial_stream_position'].enum_type = tecton__proto_dot_args_dot_data__source__config__pb2._INITIALSTREAMPOSITION
_KINESISDATASOURCEARGS.fields_by_name['default_watermark_delay_threshold'].message_type = google_dot_protobuf_dot_duration__pb2._DURATION
_KINESISDATASOURCEARGS.fields_by_name['options'].message_type = _OPTION
_KAFKADATASOURCEARGS.fields_by_name['raw_stream_translator'].message_type = tecton__proto_dot_args_dot_user__defined__function__pb2._USERDEFINEDFUNCTION
_KAFKADATASOURCEARGS.fields_by_name['default_watermark_delay_threshold'].message_type = google_dot_protobuf_dot_duration__pb2._DURATION
_KAFKADATASOURCEARGS.fields_by_name['options'].message_type = _OPTION
_REDSHIFTDATASOURCEARGS.fields_by_name['raw_batch_translator'].message_type = tecton__proto_dot_args_dot_user__defined__function__pb2._USERDEFINEDFUNCTION
_REDSHIFTDATASOURCEARGS.oneofs_by_name['source'].fields.append(
  _REDSHIFTDATASOURCEARGS.fields_by_name['table'])
_REDSHIFTDATASOURCEARGS.fields_by_name['table'].containing_oneof = _REDSHIFTDATASOURCEARGS.oneofs_by_name['source']
_REDSHIFTDATASOURCEARGS.oneofs_by_name['source'].fields.append(
  _REDSHIFTDATASOURCEARGS.fields_by_name['query'])
_REDSHIFTDATASOURCEARGS.fields_by_name['query'].containing_oneof = _REDSHIFTDATASOURCEARGS.oneofs_by_name['source']
_SNOWFLAKEDATASOURCEARGS.fields_by_name['raw_batch_translator'].message_type = tecton__proto_dot_args_dot_user__defined__function__pb2._USERDEFINEDFUNCTION
_SNOWFLAKEDATASOURCEARGS.oneofs_by_name['source'].fields.append(
  _SNOWFLAKEDATASOURCEARGS.fields_by_name['table'])
_SNOWFLAKEDATASOURCEARGS.fields_by_name['table'].containing_oneof = _SNOWFLAKEDATASOURCEARGS.oneofs_by_name['source']
_SNOWFLAKEDATASOURCEARGS.oneofs_by_name['source'].fields.append(
  _SNOWFLAKEDATASOURCEARGS.fields_by_name['query'])
_SNOWFLAKEDATASOURCEARGS.fields_by_name['query'].containing_oneof = _SNOWFLAKEDATASOURCEARGS.oneofs_by_name['source']
DESCRIPTOR.message_types_by_name['DatetimePartitionColumnArgs'] = _DATETIMEPARTITIONCOLUMNARGS
DESCRIPTOR.message_types_by_name['HiveDataSourceArgs'] = _HIVEDATASOURCEARGS
DESCRIPTOR.message_types_by_name['FileDataSourceArgs'] = _FILEDATASOURCEARGS
DESCRIPTOR.message_types_by_name['Option'] = _OPTION
DESCRIPTOR.message_types_by_name['KinesisDataSourceArgs'] = _KINESISDATASOURCEARGS
DESCRIPTOR.message_types_by_name['KafkaDataSourceArgs'] = _KAFKADATASOURCEARGS
DESCRIPTOR.message_types_by_name['RedshiftDataSourceArgs'] = _REDSHIFTDATASOURCEARGS
DESCRIPTOR.message_types_by_name['SnowflakeDataSourceArgs'] = _SNOWFLAKEDATASOURCEARGS
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

DatetimePartitionColumnArgs = _reflection.GeneratedProtocolMessageType('DatetimePartitionColumnArgs', (_message.Message,), {
  'DESCRIPTOR' : _DATETIMEPARTITIONCOLUMNARGS,
  '__module__' : 'tecton_proto.args.data_source_pb2'
  # @@protoc_insertion_point(class_scope:tecton_proto.args.DatetimePartitionColumnArgs)
  })
_sym_db.RegisterMessage(DatetimePartitionColumnArgs)

HiveDataSourceArgs = _reflection.GeneratedProtocolMessageType('HiveDataSourceArgs', (_message.Message,), {
  'DESCRIPTOR' : _HIVEDATASOURCEARGS,
  '__module__' : 'tecton_proto.args.data_source_pb2'
  # @@protoc_insertion_point(class_scope:tecton_proto.args.HiveDataSourceArgs)
  })
_sym_db.RegisterMessage(HiveDataSourceArgs)

FileDataSourceArgs = _reflection.GeneratedProtocolMessageType('FileDataSourceArgs', (_message.Message,), {
  'DESCRIPTOR' : _FILEDATASOURCEARGS,
  '__module__' : 'tecton_proto.args.data_source_pb2'
  # @@protoc_insertion_point(class_scope:tecton_proto.args.FileDataSourceArgs)
  })
_sym_db.RegisterMessage(FileDataSourceArgs)

Option = _reflection.GeneratedProtocolMessageType('Option', (_message.Message,), {
  'DESCRIPTOR' : _OPTION,
  '__module__' : 'tecton_proto.args.data_source_pb2'
  # @@protoc_insertion_point(class_scope:tecton_proto.args.Option)
  })
_sym_db.RegisterMessage(Option)

KinesisDataSourceArgs = _reflection.GeneratedProtocolMessageType('KinesisDataSourceArgs', (_message.Message,), {
  'DESCRIPTOR' : _KINESISDATASOURCEARGS,
  '__module__' : 'tecton_proto.args.data_source_pb2'
  # @@protoc_insertion_point(class_scope:tecton_proto.args.KinesisDataSourceArgs)
  })
_sym_db.RegisterMessage(KinesisDataSourceArgs)

KafkaDataSourceArgs = _reflection.GeneratedProtocolMessageType('KafkaDataSourceArgs', (_message.Message,), {
  'DESCRIPTOR' : _KAFKADATASOURCEARGS,
  '__module__' : 'tecton_proto.args.data_source_pb2'
  # @@protoc_insertion_point(class_scope:tecton_proto.args.KafkaDataSourceArgs)
  })
_sym_db.RegisterMessage(KafkaDataSourceArgs)

RedshiftDataSourceArgs = _reflection.GeneratedProtocolMessageType('RedshiftDataSourceArgs', (_message.Message,), {
  'DESCRIPTOR' : _REDSHIFTDATASOURCEARGS,
  '__module__' : 'tecton_proto.args.data_source_pb2'
  # @@protoc_insertion_point(class_scope:tecton_proto.args.RedshiftDataSourceArgs)
  })
_sym_db.RegisterMessage(RedshiftDataSourceArgs)

SnowflakeDataSourceArgs = _reflection.GeneratedProtocolMessageType('SnowflakeDataSourceArgs', (_message.Message,), {
  'DESCRIPTOR' : _SNOWFLAKEDATASOURCEARGS,
  '__module__' : 'tecton_proto.args.data_source_pb2'
  # @@protoc_insertion_point(class_scope:tecton_proto.args.SnowflakeDataSourceArgs)
  })
_sym_db.RegisterMessage(SnowflakeDataSourceArgs)


DESCRIPTOR._options = None
_FILEDATASOURCEARGS.fields_by_name['schema_uri']._options = None
_KAFKADATASOURCEARGS.fields_by_name['ssl_keystore_location']._options = None
_KAFKADATASOURCEARGS.fields_by_name['ssl_keystore_password_secret_id']._options = None
_KAFKADATASOURCEARGS.fields_by_name['ssl_truststore_location']._options = None
_KAFKADATASOURCEARGS.fields_by_name['ssl_truststore_password_secret_id']._options = None
_KAFKADATASOURCEARGS.fields_by_name['security_protocol']._options = None
_SNOWFLAKEDATASOURCEARGS.fields_by_name['warehouse']._options = None
# @@protoc_insertion_point(module_scope)
