# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: tecton_proto/args/fco_args.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from tecton_proto.args import entity_pb2 as tecton__proto_dot_args_dot_entity__pb2
from tecton_proto.args import virtual_data_source_pb2 as tecton__proto_dot_args_dot_virtual__data__source__pb2
from tecton_proto.args import feature_view_pb2 as tecton__proto_dot_args_dot_feature__view__pb2
from tecton_proto.args import feature_service_pb2 as tecton__proto_dot_args_dot_feature__service__pb2
from tecton_proto.args import new_transformation_pb2 as tecton__proto_dot_args_dot_new__transformation__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='tecton_proto/args/fco_args.proto',
  package='tecton_proto.args',
  syntax='proto2',
  serialized_options=b'\n\017com.tecton.argsP\001',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n tecton_proto/args/fco_args.proto\x12\x11tecton_proto.args\x1a\x1etecton_proto/args/entity.proto\x1a+tecton_proto/args/virtual_data_source.proto\x1a$tecton_proto/args/feature_view.proto\x1a\'tecton_proto/args/feature_service.proto\x1a*tecton_proto/args/new_transformation.proto\"\xa8\x03\n\x07\x46\x63oArgs\x12Z\n\x13virtual_data_source\x18\x01 \x01(\x0b\x32(.tecton_proto.args.VirtualDataSourceArgsH\x00R\x11virtualDataSource\x12\x37\n\x06\x65ntity\x18\x02 \x01(\x0b\x32\x1d.tecton_proto.args.EntityArgsH\x00R\x06\x65ntity\x12G\n\x0c\x66\x65\x61ture_view\x18\x06 \x01(\x0b\x32\".tecton_proto.args.FeatureViewArgsH\x00R\x0b\x66\x65\x61tureView\x12P\n\x0f\x66\x65\x61ture_service\x18\x04 \x01(\x0b\x32%.tecton_proto.args.FeatureServiceArgsH\x00R\x0e\x66\x65\x61tureService\x12Y\n\x12new_transformation\x18\x07 \x01(\x0b\x32(.tecton_proto.args.NewTransformationArgsH\x00R\x11newTransformationB\x06\n\x04\x61rgsJ\x04\x08\x03\x10\x04J\x04\x08\x05\x10\x06\x42\x13\n\x0f\x63om.tecton.argsP\x01'
  ,
  dependencies=[tecton__proto_dot_args_dot_entity__pb2.DESCRIPTOR,tecton__proto_dot_args_dot_virtual__data__source__pb2.DESCRIPTOR,tecton__proto_dot_args_dot_feature__view__pb2.DESCRIPTOR,tecton__proto_dot_args_dot_feature__service__pb2.DESCRIPTOR,tecton__proto_dot_args_dot_new__transformation__pb2.DESCRIPTOR,])




_FCOARGS = _descriptor.Descriptor(
  name='FcoArgs',
  full_name='tecton_proto.args.FcoArgs',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='virtual_data_source', full_name='tecton_proto.args.FcoArgs.virtual_data_source', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='virtualDataSource', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='entity', full_name='tecton_proto.args.FcoArgs.entity', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='entity', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='feature_view', full_name='tecton_proto.args.FcoArgs.feature_view', index=2,
      number=6, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='featureView', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='feature_service', full_name='tecton_proto.args.FcoArgs.feature_service', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='featureService', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='new_transformation', full_name='tecton_proto.args.FcoArgs.new_transformation', index=4,
      number=7, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='newTransformation', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='args', full_name='tecton_proto.args.FcoArgs.args',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=256,
  serialized_end=680,
)

_FCOARGS.fields_by_name['virtual_data_source'].message_type = tecton__proto_dot_args_dot_virtual__data__source__pb2._VIRTUALDATASOURCEARGS
_FCOARGS.fields_by_name['entity'].message_type = tecton__proto_dot_args_dot_entity__pb2._ENTITYARGS
_FCOARGS.fields_by_name['feature_view'].message_type = tecton__proto_dot_args_dot_feature__view__pb2._FEATUREVIEWARGS
_FCOARGS.fields_by_name['feature_service'].message_type = tecton__proto_dot_args_dot_feature__service__pb2._FEATURESERVICEARGS
_FCOARGS.fields_by_name['new_transformation'].message_type = tecton__proto_dot_args_dot_new__transformation__pb2._NEWTRANSFORMATIONARGS
_FCOARGS.oneofs_by_name['args'].fields.append(
  _FCOARGS.fields_by_name['virtual_data_source'])
_FCOARGS.fields_by_name['virtual_data_source'].containing_oneof = _FCOARGS.oneofs_by_name['args']
_FCOARGS.oneofs_by_name['args'].fields.append(
  _FCOARGS.fields_by_name['entity'])
_FCOARGS.fields_by_name['entity'].containing_oneof = _FCOARGS.oneofs_by_name['args']
_FCOARGS.oneofs_by_name['args'].fields.append(
  _FCOARGS.fields_by_name['feature_view'])
_FCOARGS.fields_by_name['feature_view'].containing_oneof = _FCOARGS.oneofs_by_name['args']
_FCOARGS.oneofs_by_name['args'].fields.append(
  _FCOARGS.fields_by_name['feature_service'])
_FCOARGS.fields_by_name['feature_service'].containing_oneof = _FCOARGS.oneofs_by_name['args']
_FCOARGS.oneofs_by_name['args'].fields.append(
  _FCOARGS.fields_by_name['new_transformation'])
_FCOARGS.fields_by_name['new_transformation'].containing_oneof = _FCOARGS.oneofs_by_name['args']
DESCRIPTOR.message_types_by_name['FcoArgs'] = _FCOARGS
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

FcoArgs = _reflection.GeneratedProtocolMessageType('FcoArgs', (_message.Message,), {
  'DESCRIPTOR' : _FCOARGS,
  '__module__' : 'tecton_proto.args.fco_args_pb2'
  # @@protoc_insertion_point(class_scope:tecton_proto.args.FcoArgs)
  })
_sym_db.RegisterMessage(FcoArgs)


DESCRIPTOR._options = None
# @@protoc_insertion_point(module_scope)
